/*= R&S UPV Audio Analyzer Include File =====================================*/

/*===========================================================================*/
/*  Please do not use global variables or arrays in the include file of      */
/*  instrument drivers that will be submitted for inclusion into the         */
/*  LabWindows Instrument Driver Library.                                    */
/*===========================================================================*/

#ifndef __RSUPV_HEADER
#define __RSUPV_HEADER

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

#include <visa.h>
/*****************************************************************************/
/*= RSIB interface support ==================================================*/
/*                                                                           */
/* The RSIB interface is a R&S defined protocol for remote control of R&S    */
/* spectrum and network analyzers. In addition to the standard VISA          */
/* attributes, the RSIB passport supports the following manufacturer specific*/
/* attributes:                                                               */
/*                                                                           */
/*****************************************************************************/
#ifndef __RSVIRSIB_H__
    #define RS_ATTR_RSIB_SRE     (0x3FFC0001UL)     /* Switch a device to local or remote */
    #define RS_ATTR_RSIB_LOC     (0x3FFC0002UL)     /* Switch a device temporarily to local */
    #define RS_ATTR_RSIB_VER     (0x3FFC0003UL)     /* Passport Release Version */
#endif

#define VI_WARN_NSUP_ID_QUERY     (          0x3FFC0101L)
#define VI_WARN_NSUP_RESET        (          0x3FFC0102L)
#define VI_WARN_NSUP_SELF_TEST    (          0x3FFC0103L)
#define VI_WARN_NSUP_ERROR_QUERY  (          0x3FFC0104L)
#define VI_WARN_NSUP_REV_QUERY    (          0x3FFC0105L)

#define VI_ERROR_PARAMETER1       (_VI_ERROR+0x3FFC0001L)
#define VI_ERROR_PARAMETER2       (_VI_ERROR+0x3FFC0002L)
#define VI_ERROR_PARAMETER3       (_VI_ERROR+0x3FFC0003L)
#define VI_ERROR_PARAMETER4       (_VI_ERROR+0x3FFC0004L)
#define VI_ERROR_PARAMETER5       (_VI_ERROR+0x3FFC0005L)
#define VI_ERROR_PARAMETER6       (_VI_ERROR+0x3FFC0006L)
#define VI_ERROR_PARAMETER7       (_VI_ERROR+0x3FFC0007L)
#define VI_ERROR_PARAMETER8       (_VI_ERROR+0x3FFC0008L)
#define VI_ERROR_FAIL_ID_QUERY    (_VI_ERROR+0x3FFC0011L)
#define VI_ERROR_INV_RESPONSE     (_VI_ERROR+0x3FFC0012L)
/*****************************************************************************/
/*= Instrument Driver Specific Error/Warning Codes ==========================*/
/*****************************************************************************/
#define VI_ERROR_INSTR_FILE_OPEN                (_VI_ERROR+0x3FFC0800L)
#define VI_ERROR_INSTR_FILE_WRITE               (_VI_ERROR+0x3FFC0801L)
#define VI_ERROR_INSTR_INTERPRETING_RESPONSE    (_VI_ERROR+0x3FFC0803L)
#define VI_ERROR_INSTR_PARAMETER9               (_VI_ERROR+0x3FFC0809L)
#define VI_ERROR_INSTR_PARAMETER10              (_VI_ERROR+0x3FFC080AL)
#define VI_ERROR_INSTR_PARAMETER11              (_VI_ERROR+0x3FFC080BL)
#define VI_ERROR_INSTR_PARAMETER12              (_VI_ERROR+0x3FFC080CL)
#define VI_ERROR_INSTR_PARAMETER13              (_VI_ERROR+0x3FFC080DL)
#define VI_ERROR_INSTR_PARAMETER14              (_VI_ERROR+0x3FFC080EL)
#define VI_ERROR_INSTR_PARAMETER15              (_VI_ERROR+0x3FFC080FL)

/*****************************************************************************/
/*= Define Instrument Specific Error/Warning Codes Here =====================*/
/*****************************************************************************/

#define VI_WARNING_INSTR_OFFSET                     (0x3FFC0900L)
#define VI_ERROR_INSTR_OFFSET                       (_VI_ERROR+0x3FFC0900L)

#define RSUPV_ERROR_INSTRUMENT_ERROR                (VI_ERROR_INSTR_OFFSET + 0xF0L)
#define RSUPV_ERROR_INVALID_CONFIGURATION           (VI_ERROR_INSTR_OFFSET + 0xF1L)
#define RSUPV_ERROR_INSTRUMENT_OPTION               (VI_ERROR_INSTR_OFFSET + 0xF2L)
#define RSUPV_ERROR_INSTRUMENT_DATA_NOT_AVAILABLE   (VI_ERROR_INSTR_OFFSET + 0xF3L)
#define RSUPV_ERROR_SETTINGS_CONFLICT               (VI_ERROR_INSTR_OFFSET + 0xF4L)
#define RSUPV_WARNING_SMALL_BUFFER                  (VI_WARNING_INSTR_OFFSET + 0xF5L)
#define RSUPV_ERROR_INSTRUMENT_NSUP_MODEL           (VI_ERROR_INSTR_OFFSET + 0xF6L)
#define RSUPV_ERROR_INSTRUMENT_NSUP_FUNC            (VI_ERROR_INSTR_OFFSET + 0xF7L)
#define RSUPV_ERROR_NULL_POINTER_VALUE              (VI_ERROR_INSTR_OFFSET + 0xF8L)

/*****************************************************************************/
/*= Instrument specific defines =============================================*/
/*****************************************************************************/
#define RSUPV_INSTR_UPV           0
#define RSUPV_INSTR_UPP           1
    
#define RSUPV_MEASUREMENT_MODE_WAIT    2
/* === GENERATOR ============================================================= */

/* --- Numeric Entry Units --------------------------------------------------- */

#define RSUPV_UNIT_DEFAULT             -1
#define RSUPV_UNIT_PCT                  0
#define RSUPV_UNIT_PCTFRM               1
#define RSUPV_UNIT_PCTFS                2
#define RSUPV_UNIT_PCTON                3
#define RSUPV_UNIT_PCTPPR               4
#define RSUPV_UNIT_PCTUI                5
#define RSUPV_UNIT_PCTVVR               6
#define RSUPV_UNIT_BITS                 7
#define RSUPV_UNIT_CYC                  8
#define RSUPV_UNIT_DPCT                 9
#define RSUPV_UNIT_DPCTHZ               10
#define RSUPV_UNIT_DPCTV                11
#define RSUPV_UNIT_DPCTW                12
#define RSUPV_UNIT_DB                   13
#define RSUPV_UNIT_DBFS                 14
#define RSUPV_UNIT_DBM                  15
#define RSUPV_UNIT_DBON                 16
#define RSUPV_UNIT_DBR                  17
#define RSUPV_UNIT_DBU                  18
#define RSUPV_UNIT_DBUI                 19
#define RSUPV_UNIT_DBV                  20
#define RSUPV_UNIT_DDEG                 21
#define RSUPV_UNIT_DEC                  22
#define RSUPV_UNIT_DEG                  23
#define RSUPV_UNIT_DEGFRM               24
#define RSUPV_UNIT_DHZ                  25
#define RSUPV_UNIT_DRAD                 26
#define RSUPV_UNIT_DS                   27
#define RSUPV_UNIT_DV                   28
#define RSUPV_UNIT_DW                   29
#define RSUPV_UNIT_FFR                  30
#define RSUPV_UNIT_FS                   31
#define RSUPV_UNIT_HEX                  32
#define RSUPV_UNIT_HZ                   33
#define RSUPV_UNIT_LSBS                 34
#define RSUPV_UNIT_MLT                  35
#define RSUPV_UNIT_NS                   36
#define RSUPV_UNIT_OCT                  37
#define RSUPV_UNIT_OHM                  38
#define RSUPV_UNIT_PPR                  39
#define RSUPV_UNIT_PPMUI                40
#define RSUPV_UNIT_RAD                  41
#define RSUPV_UNIT_S                    42
#define RSUPV_UNIT_TOCT                 43
#define RSUPV_UNIT_UI                   44
#define RSUPV_UNIT_UIR                  45
#define RSUPV_UNIT_UIS                  46
#define RSUPV_UNIT_V                    47
#define RSUPV_UNIT_VVON                 48
#define RSUPV_UNIT_VVR                  49
#define RSUPV_UNIT_VPP                  50
#define RSUPV_UNIT_W                    51
#define RSUPV_UNIT_MV                   52
#define RSUPV_UNIT_UV                   53
#define RSUPV_UNIT_MW                   54
#define RSUPV_UNIT_UW                   55
#define RSUPV_UNIT_MVPP                 56
#define RSUPV_UNIT_UVPP                 57
#define RSUPV_UNIT_DMV                  58
#define RSUPV_UNIT_DUV                  59   
#define RSUPV_UNIT_FSBIT                60
#define RSUPV_UNIT_KHZ                  61
#define RSUPV_UNIT_DKHZ                 62
#define RSUPV_UNIT_MS                   63
#define RSUPV_UNIT_US                   64
#define RSUPV_UNIT_KCYC                 65
#define RSUPV_UNIT_MCYC                 66 
#define RSUPV_UNIT_DMS                  67
#define RSUPV_UNIT_DUS                  68
#define RSUPV_UNIT_MIN                  69      
#define RSUPV_UNIT_KOHM                 70
#define RSUPV_UNIT_DBMG                 71 
#define RSUPV_UNIT_CORR                 72
#define RSUPV_UNIT_POL                  73
	
/* --- Instrument ------------------------------------------------------------ */
                                        
#define RSUPV_GEN_ANALOG                0
#define RSUPV_GEN_DIGITAL_AUDIO         1
#define RSUPV_GEN_I2S                   2
#define RSUPV_GEN_IMPAIRMENT            3
#define RSUPV_GEN_U2C                   4
#define RSUPV_GEN_HDMI                  5
/* --- Channel --------------------------------------------------------------- */

#define RSUPV_GEN_CH_OFF                0
#define RSUPV_GEN_CH_1                  1
#define RSUPV_GEN_CH_2                  2
#define RSUPV_GEN_CH_21                 3
#define RSUPV_GEN_CH_2_180              4
#define RSUPV_GEN_CH_MULTI              5

/* --- Output Type ----------------------------------------------------------- */

#define RSUPV_GEN_OUTPUT_UNBAL          0
#define RSUPV_GEN_OUTPUT_BAL            1
#define RSUPV_GEN_OUTPUT_CTEST          2
/* --- Impedance ------------------------------------------------------------- */

#define RSUPV_GEN_IMPEDANCE_10          0
#define RSUPV_GEN_IMPEDANCE_200         1
#define RSUPV_GEN_IMPEDANCE_600         2
#define RSUPV_GEN_IMPEDANCE_25          3

/* --- Common ---------------------------------------------------------------- */

#define RSUPV_GEN_OUTPUT_COMM_FLOAT     0
#define RSUPV_GEN_OUTPUT_COMM_GND       1

/* --- Bandwidth ------------------------------------------------------------- */

#define RSUPV_GEN_BWIDTH_22             0
#define RSUPV_GEN_BWIDTH_40             1
#define RSUPV_GEN_BWIDTH_80             2
#define RSUPV_GEN_BWIDTH_AUTO           3   

/* --- Volt Range ------------------------------------------------------------ */

#define RSUPV_GEN_VOLT_RANG_AUTO        0
#define RSUPV_GEN_VOLT_RANG_FIX         1

/* --- Source Mode ----------------------------------------------------------- */

#define RSUPV_GEN_DIG_JITTER            1
#define RSUPV_GEN_DIG_COMMON            2

/* --- Sync To --------------------------------------------------------------- */

#define RSUPV_GEN_SYNC_INT_CLK          0
#define RSUPV_GEN_SYNC_AUDIO_IN         1
#define RSUPV_GEN_SYNC_AUX_IN           2
#define RSUPV_GEN_SYNC_IN               3
#define RSUPV_GEN_SYNC_IN_INV           4
#define RSUPV_GEN_SYNC_IN_EDAR          5
#define RSUPV_GEN_SYNC_IN_ECLK          6
#define RSUPV_GEN_SYNC_IN_EICL          7
#define RSUPV_GEN_SYNC_IN_HINT  		8
#define RSUPV_GEN_SYNC_IN_HAUX  		9

/* --- Sample Frequency ------------------------------------------------------ */

#define RSUPV_GEN_SAMPLE_FREQ_32        0
#define RSUPV_GEN_SAMPLE_FREQ_44        1
#define RSUPV_GEN_SAMPLE_FREQ_48        2
#define RSUPV_GEN_SAMPLE_FREQ_88        3
#define RSUPV_GEN_SAMPLE_FREQ_96        4
#define RSUPV_GEN_SAMPLE_FREQ_176       5
#define RSUPV_GEN_SAMPLE_FREQ_192       6
#define RSUPV_GEN_SAMPLE_FREQ_VAL       7
#define RSUPV_GEN_SAMPLE_FREQ_SYNC      8

/* --- Source Mode ----------------------------------------------------------- */

#define RSUPV_GEN_SYNC_OUTP_AUDIO_OUT   0
#define RSUPV_GEN_SYNC_OUTP_AUDIO_IN    1
#define RSUPV_GEN_SYNC_OUTP_AUX_IN      2
#define RSUPV_GEN_SYNC_OUTP_GEN_PLL     3
#define RSUPV_GEN_SYNC_OUTP_JITT_PLL    4
#define RSUPV_GEN_SYNC_OUTP_AUX         5
#define RSUPV_GEN_SYNC_OUTP_SYNC_IN     6
#define RSUPV_GEN_SYNC_OUTP_INT_CLK     7

/* --- Sync Out Type --------------------------------------------------------- */

#define RSUPV_GEN_OUTP_TYPE_WORD        0
#define RSUPV_GEN_OUTP_TYPE_BIPHASE     1

/* --- Aux Output ------------------------------------------------------------ */

#define RSUPV_GEN_AUX_OUTP_AUDIO_OUT        0
#define RSUPV_GEN_AUX_OUTP_AUDIO_IN         1
#define RSUPV_GEN_AUX_OUTP_AUDIO_RECLOCK    2
#define RSUPV_GEN_AUX_OUTP_AUDIO_REF_GEN    3
#define RSUPV_GEN_AUX_OUTP_INPUT            4

/* --- Ref Gen Data ---------------------------------------------------------- */

#define RSUPV_GEN_REF_DATA_ZERO         0
#define RSUPV_GEN_REF_DATA_ONE          1

/* --- Unbal Output ---------------------------------------------------------- */

#define RSUPV_GEN_UNBAL_OUTP_AUDIO_OUT  0
#define RSUPV_GEN_UNBAL_OUTP_AUDIO_IN   1

/* --- Cable Sim ------------------------------------------------------------- */

#define RSUPV_GEN_CABLE_SIM_OFF         0
#define RSUPV_GEN_CABLE_SIM_LONG        1

/* --- Impedance ------------------------------------------------------------- */
#define RSUPV_GEN_OUTP_BAL_IMP_R5    0
#define RSUPV_GEN_OUTP_BAL_IMP_R15   1
#define RSUPV_GEN_OUTP_BAL_IMP_R10   2
#define RSUPV_GEN_OUTP_BAL_IMP_R30   3
#define RSUPV_GEN_OUTP_BAL_IMP_R200  4
#define RSUPV_GEN_OUTP_BAL_IMP_R150  5
#define RSUPV_GEN_OUTP_BAL_IMP_R600  6
#define RSUPV_GEN_OUTP_BAL_IMP_R25   7
#define RSUPV_GEN_OUTP_BAL_IMP_R50   8
#define RSUPV_GEN_OUTP_BAL_IMP_USER  9
    
/* --- Function -------------------------------------------------------------- */

#define RSUPV_GEN_FUNC_SINE             0
#define RSUPV_GEN_FUNC_STEREO_SINE      1
#define RSUPV_GEN_FUNC_MULTISINE        2
#define RSUPV_GEN_FUNC_SINE_BURST       3
#define RSUPV_GEN_FUNC_SINE2_BURST      4
#define RSUPV_GEN_FUNC_MOD_DIST         5
#define RSUPV_GEN_FUNC_DFD              6
#define RSUPV_GEN_FUNC_DIM              7
#define RSUPV_GEN_FUNC_RANDOM           8
#define RSUPV_GEN_FUNC_ARB              9
#define RSUPV_GEN_FUNC_POLARITY         10
#define RSUPV_GEN_FUNC_MODULATION       11
#define RSUPV_GEN_FUNC_DC               12
#define RSUPV_GEN_FUNC_PLAY             13
#define RSUPV_GEN_FUNC_PLYA             14
#define RSUPV_GEN_FUNC_CHIRP			15
#define RSUPV_GEN_FUNC_SQUARE			16
#define RSUPV_GEN_FUNC_UNIVERSAL   		17
#define RSUPV_GEN_FUNC_LIPSYNC     		18

/* --- Mode ------------------------------------------------------------------ */

#define RSUPV_GEN_MODE_EQUAL            0
#define RSUPV_GEN_MODE_DEF              1
#define RSUPV_GEN_MODE_IEC_268          2
#define RSUPV_GEN_MODE_IEC_118          3
#define RSUPV_GEN_MODE_FM               4
#define RSUPV_GEN_MODE_AM               5

/* --- PDF ------------------------------------------------------------------- */

#define RSUPV_GEN_PDF_GAUSS             0
#define RSUPV_GEN_PDF_TRIANGLE          1
#define RSUPV_GEN_PDF_RECTANGLE         2

/* --- Sweep Ctrl ------------------------------------------------------------ */

#define RSUPV_GEN_SWEEP_OFF             0
#define RSUPV_GEN_SWEEP_AUTO_SWEEP      1
#define RSUPV_GEN_SWEEP_AUTO_LIST       2
#define RSUPV_GEN_SWEEP_MAN_SWEEP       3
#define RSUPV_GEN_SWEEP_MAN_LIST        4

/* --- Next Step ------------------------------------------------------------- */

#define RSUPV_GEN_SWEEP_NSTEP_ANLR_SYNC     0
#define RSUPV_GEN_SWEEP_NSTEP_DWELL_VAL     1
#define RSUPV_GEN_SWEEP_NSTEP_DWELL_FILE    2

/* --- Z Axis ---------------------------------------------------------------- */

#define RSUPV_GEN_SWEEP_AXIS_OFF            0
#define RSUPV_GEN_SWEEP_AXIS_VOLT           1
#define RSUPV_GEN_SWEEP_AXIS_FREQ           2
#define RSUPV_GEN_SWEEP_AXIS_ON_TIME        3
#define RSUPV_GEN_SWEEP_AXIS_INTERVAL       4
#define RSUPV_GEN_SWEEP_AXIS_PHASE          5

/* --- Spacing --------------------------------------------------------------- */

#define RSUPV_GEN_SWEEP_SPAC_LIN_POINT      0
#define RSUPV_GEN_SWEEP_SPAC_LIN_STEP       1
#define RSUPV_GEN_SWEEP_SPAC_LOG_POINT      2
#define RSUPV_GEN_SWEEP_SPAC_LOG_STEP       3
    
#define RSUPV_GEN_SWEEP_START               0
#define RSUPV_GEN_SWEEP_VALUE               1
#define RSUPV_GEN_SWEEP_MUTE                2

/* --- Spacing --------------------------------------------------------------- */

#define RSUPV_GEN_SPACING_ANLR_TR           0
#define RSUPV_GEN_SPACING_DEF               1

/* --- Crest Factor ---------------------------------------------------------- */

#define RSUPV_GEN_CR_FACTOR_OPT             0
#define RSUPV_GEN_CR_FACTOR_VAL             1
#define RSUPV_GEN_CR_FACTOR_DEF_PHASE       2

/* --- Filter --------------------------------------------------------------- */

#define RSUPV_GEN_FILTER_OFF                0
#define RSUPV_GEN_FILTER_UFIL1              1
#define RSUPV_GEN_FILTER_UFIL2              2
#define RSUPV_GEN_FILTER_UFIL3              3
#define RSUPV_GEN_FILTER_UFIL4              4
#define RSUPV_GEN_FILTER_UFIL5              5
#define RSUPV_GEN_FILTER_UFIL6              6
#define RSUPV_GEN_FILTER_UFIL7              7
#define RSUPV_GEN_FILTER_UFIL8              8
#define RSUPV_GEN_FILTER_UFIL9              9
#define RSUPV_GEN_FILTER_AWE                10
#define RSUPV_GEN_FILTER_CCIR               11
#define RSUPV_GEN_FILTER_CCIA               12
#define RSUPV_GEN_FILTER_CCIU               13
#define RSUPV_GEN_FILTER_CCIT               14
#define RSUPV_GEN_FILTER_CMES               15
#define RSUPV_GEN_FILTER_DCN                16
#define RSUPV_GEN_FILTER_DEMP17             17
#define RSUPV_GEN_FILTER_DEMP5015           18
#define RSUPV_GEN_FILTER_DEMP50             19
#define RSUPV_GEN_FILTER_DEMP75             20
#define RSUPV_GEN_FILTER_IECT               21
#define RSUPV_GEN_FILTER_JITT               22
#define RSUPV_GEN_FILTER_URUM               23
#define RSUPV_GEN_FILTER_WRUM               24
#define RSUPV_GEN_FILTER_PEMP17             25
#define RSUPV_GEN_FILTER_PEMP5015           26
#define RSUPV_GEN_FILTER_PEMP50             27
#define RSUPV_GEN_FILTER_PEMP75             28
#define RSUPV_GEN_FILTER_HP22               29
#define RSUPV_GEN_FILTER_HP400              30
#define RSUPV_GEN_FILTER_LP22               31
#define RSUPV_GEN_FILTER_LP30               32
#define RSUPV_GEN_FILTER_LP80               33
#define RSUPV_GEN_FILTER_AES17              34
#define RSUPV_GEN_FILTER_CWE                35

/* --- Freq Mode ------------------------------------------------------------ */

#define RSUPV_GEN_STEREO_FREQ_FQPH          0
#define RSUPV_GEN_STEREO_FREQ_FQFQ          1

/* --- Volt Mode ------------------------------------------------------------ */

#define RSUPV_GEN_STEREO_VOLT_VLRT          0
#define RSUPV_GEN_STEREO_VOLT_VLVL          1

/* --- Mode ----------------------------------------------------------------- */

#define RSUPV_GEN_DIM_SQUARE_IEC268         0
#define RSUPV_GEN_DIM_SQUARE_IEC118         1

/* --- Bandwidth ------------------------------------------------------------ */

#define RSUPV_GEN_DIM_BWIDTH_F30            0
#define RSUPV_GEN_DIM_BWIDTH_F100           1

/* --- Shape ---------------------------------------------------------------- */

#define RSUPV_GEN_RANDOM_SHAPE_WHITE        0
#define RSUPV_GEN_RANDOM_SHAPE_PINK         1
#define RSUPV_GEN_RANDOM_SHAPE_OCTAVE       2
#define RSUPV_GEN_RANDOM_SHAPE_FILE         3

/* --- Square/Sine ---------------------------------------------------------- */

#define RSUPV_GEN_DIM_DIMA                  0
#define RSUPV_GEN_DIM_DIMB                  1
#define RSUPV_GEN_DIM_DIMS                  2

/* --- Phase To Ref ---------------------------------------------------------- */

#define RSUPV_GEN_PHASE_REF_OFF             0
#define RSUPV_GEN_PHASE_REF_VAL             1

/* --- Domain ---------------------------------------------------------------- */

#define RSUPV_GEN_RANDOM_DOMAIN_FREQ        0
#define RSUPV_GEN_RANDOM_DOMAIN_TIME        1

/* --- I2S Sync To ----------------------------------------------------------- */

#define RSUPV_GEN_I2S_SYNC_INT_CLK          0
#define RSUPV_GEN_I2S_SYNC_EXT_MCLK         1
#define RSUPV_GEN_I2S_SYNC_EXT_WCLK         2
    
/* --- I2S Word Length ------------------------------------------------------- */

#define RSUPV_GEN_I2S_WLENGTH_16            0
#define RSUPV_GEN_I2S_WLENGTH_24            1
#define RSUPV_GEN_I2S_WLENGTH_32            2   
    
/* --- I2S Sample Frequency -------------------------------------------------- */

#define RSUPV_GEN_I2S_SAMPLE_FREQ_08        0
#define RSUPV_GEN_I2S_SAMPLE_FREQ_11        1
#define RSUPV_GEN_I2S_SAMPLE_FREQ_16        2
#define RSUPV_GEN_I2S_SAMPLE_FREQ_22        3
#define RSUPV_GEN_I2S_SAMPLE_FREQ_32        4
#define RSUPV_GEN_I2S_SAMPLE_FREQ_44        5
#define RSUPV_GEN_I2S_SAMPLE_FREQ_48        6
#define RSUPV_GEN_I2S_SAMPLE_FREQ_88        7
#define RSUPV_GEN_I2S_SAMPLE_FREQ_96        8
#define RSUPV_GEN_I2S_SAMPLE_FREQ_176       9
#define RSUPV_GEN_I2S_SAMPLE_FREQ_192       10
#define RSUPV_GEN_I2S_SAMPLE_FREQ_384       11
#define RSUPV_GEN_I2S_SAMPLE_FREQ_VAL       12
    
/* --- I2S MClk Ratio -------------------------------------------------------- */

#define RSUPV_GEN_I2S_MCLK_RATIO_64         0
#define RSUPV_GEN_I2S_MCLK_RATIO_96         1
#define RSUPV_GEN_I2S_MCLK_RATIO_128        2
#define RSUPV_GEN_I2S_MCLK_RATIO_192        3
#define RSUPV_GEN_I2S_MCLK_RATIO_256        4
#define RSUPV_GEN_I2S_MCLK_RATIO_384        5
#define RSUPV_GEN_I2S_MCLK_RATIO_512        6   
    
/* --- I2S Format ------------------------------------------------------------ */

#define RSUPV_GEN_I2S_FORMAT_SI2S           0
#define RSUPV_GEN_I2S_FORMAT_USER           1
    
/* --- I2S Fsync Shape ------------------------------------------------------- */

#define RSUPV_GEN_I2S_FSYNC_SHAPE_SQUARE    0
#define RSUPV_GEN_I2S_FSYNC_SHAPE_BIT       1
    
/* --- I2S Fsync Polarity ---------------------------------------------------- */

#define RSUPV_GEN_I2S_FSYNC_POLARITY_LFTL   0
#define RSUPV_GEN_I2S_FSYNC_POLARITY_LFTH   1
#define RSUPV_GEN_I2S_FSYNC_POLARITY_POS    2
#define RSUPV_GEN_I2S_FSYNC_POLARITY_NEG    3   
    
/* --- USI Dual Channel ------------------------------------------------------ */
#define RSUPV_CLOCK_CONTINUOUS 0
#define RSUPV_CLOCK_GATED      1

#define RSUPV_SAMPLE_FREQ_08    0
#define RSUPV_SAMPLE_FREQ_11    1
#define RSUPV_SAMPLE_FREQ_16    2
#define RSUPV_SAMPLE_FREQ_22    3
#define RSUPV_SAMPLE_FREQ_32    4
#define RSUPV_SAMPLE_FREQ_44    5
#define RSUPV_SAMPLE_FREQ_48    6
#define RSUPV_SAMPLE_FREQ_88    7
#define RSUPV_SAMPLE_FREQ_96    8
#define RSUPV_SAMPLE_FREQ_176   9
#define RSUPV_SAMPLE_FREQ_192   10
#define RSUPV_SAMPLE_FREQ_384   11
#define RSUPV_SAMPLE_FREQ_VAL   12
#define RSUPV_SAMPLE_FREQ_AUTO  13

#define RSUPV_DUAL_SYNC_INT_CLK  0
#define RSUPV_DUAL_SYNC_EXT_MCLK 1
#define RSUPV_DUAL_SYNC_EXT_FSYN 2
#define RSUPV_DUAL_SYNC_EXT_FAM  3
#define RSUPV_DUAL_SYNC_EXT_FBCL 4
    
#define RSUPV_DUAL_BIT_MSB 0
#define RSUPV_DUAL_BIT_LSB 1

#define RSUPV_SLOPE_RISING  0
#define RSUPV_SLOPE_FALLING 1

#define RSUPV_DUAL_FWIDTH_BIT    0
#define RSUPV_DUAL_FWIDTH_SLOT   1
#define RSUPV_DUAL_FWIDTH_SQUARE 2
#define RSUPV_DUAL_FWIDTH_VALUE  3

#define RSUPV_VAL_VOLTAGE_0V9 0
#define RSUPV_VAL_VOLTAGE_1V2 1
#define RSUPV_VAL_VOLTAGE_1V8 2
#define RSUPV_VAL_VOLTAGE_2V5 3
#define RSUPV_VAL_VOLTAGE_3V3 4
    
#define RSUPV_VAL_CODING_NONE 0
#define RSUPV_VAL_CODING_ALAW 1
#define RSUPV_VAL_CODING_ULAW 2

/* --- Play Analyzer Loop Channel -------------------------------------------- */

#define RSUPV_GEN_PLAY_ANLR_LOOP_CH_OFF     0
#define RSUPV_GEN_PLAY_ANLR_LOOP_CH_1       1
#define RSUPV_GEN_PLAY_ANLR_LOOP_CH_2       2
#define RSUPV_GEN_PLAY_ANLR_LOOP_CH_STEREO  3
#define RSUPV_GEN_PLAY_ANLR_LOOP_CH_CROSSED 4
    
/* --- Amplitude Variation --------------------------------------------------- */

#define RSUPV_GEN_AM_VARIATION_OFF          0
#define RSUPV_GEN_AM_VARIATION_SINE         1
#define RSUPV_GEN_AM_VARIATION_BURST        2
    
/* --- Generator Play Channel ------------------------------------------------ */

#define RSUPV_GEN_PLAY_CHAN_MLEFT           0
#define RSUPV_GEN_PLAY_CHAN_MRIGHT          1
#define RSUPV_GEN_PLAY_CHAN_STEREO          2
    
/* --- Generator Play Mode --------------------------------------------------- */

#define RSUPV_GEN_PLAY_MODE_TOCONT          0
#define RSUPV_GEN_PLAY_MODE_TOSING          1
#define RSUPV_GEN_PLAY_MODE_TICONT          2
#define RSUPV_GEN_PLAY_MODE_TISING          3
	
#define RSUPV_GEN_PLAY_REST_OFF             0
#define RSUPV_GEN_PLAY_REST_AUTO            1
#define RSUPV_GEN_PLAY_REST_ONCE            2

/* === ANALYZER ============================================================== */

/* --- Instrument ------------------------------------------------------------ */

#define RSUPV_ANALYZER_ANALOG               0
#define RSUPV_ANALYZER_DIGITAL              1
#define RSUPV_ANALYZER_I2S                  2   
#define RSUPV_ANALYZER_A8C                  3
#define RSUPV_ANALYZER_A16C                 4
#define RSUPV_ANALYZER_U2C                  5
#define RSUPV_ANALYZER_U8C                  6
#define RSUPV_ANALYZER_DIGBITS    			7
#define RSUPV_ANALYZER_HDMI    				8
	
/* --- Channel --------------------------------------------------------------- */

#define RSUPV_ANALYZER_CH_1                 0
#define RSUPV_ANALYZER_CH_2                 1
#define RSUPV_ANALYZER_CH_1AND2             2
#define RSUPV_ANALYZER_CH_21                3
#define RSUPV_ANALYZER_CH_12                4
#define RSUPV_ANALYZER_CH_BOTH              5
#define RSUPV_ANALYZER_CH_MULTI             6

/* --- Bandwidth ------------------------------------------------------------- */

#define RSUPV_ANALYZER_BWIDTH_22            0
#define RSUPV_ANALYZER_BWIDTH_40            1
#define RSUPV_ANALYZER_BWIDTH_80            2
#define RSUPV_ANALYZER_BWIDTH_250           3

/* --- Pre Filter ----------------------------------------------------------- */

#define RSUPV_ANALYZER_PREFILTER_OFF        0
#define RSUPV_ANALYZER_PREFILTER_UFIL1      1
#define RSUPV_ANALYZER_PREFILTER_UFIL2      2
#define RSUPV_ANALYZER_PREFILTER_UFIL3      3
#define RSUPV_ANALYZER_PREFILTER_UFIL4      4
#define RSUPV_ANALYZER_PREFILTER_UFIL5      5
#define RSUPV_ANALYZER_PREFILTER_UFIL6      6
#define RSUPV_ANALYZER_PREFILTER_UFIL7      7
#define RSUPV_ANALYZER_PREFILTER_UFIL8      8
#define RSUPV_ANALYZER_PREFILTER_UFIL9      9
#define RSUPV_ANALYZER_PREFILTER_AWE        10
#define RSUPV_ANALYZER_PREFILTER_CARM       11
#define RSUPV_ANALYZER_PREFILTER_CCIU       12
#define RSUPV_ANALYZER_PREFILTER_CCIR       13
#define RSUPV_ANALYZER_PREFILTER_CCIT       14
#define RSUPV_ANALYZER_PREFILTER_CMES       15
#define RSUPV_ANALYZER_PREFILTER_DCN        16
#define RSUPV_ANALYZER_PREFILTER_DEMP17     17
#define RSUPV_ANALYZER_PREFILTER_DEMP5015   18
#define RSUPV_ANALYZER_PREFILTER_DEMP50     19
#define RSUPV_ANALYZER_PREFILTER_DEMP75     20
#define RSUPV_ANALYZER_PREFILTER_IECT       21
#define RSUPV_ANALYZER_PREFILTER_JITT       22
#define RSUPV_ANALYZER_PREFILTER_URUM       23
#define RSUPV_ANALYZER_PREFILTER_WRUM       24
#define RSUPV_ANALYZER_PREFILTER_PEMP17     25
#define RSUPV_ANALYZER_PREFILTER_PEMP5015   26
#define RSUPV_ANALYZER_PREFILTER_PEMP50     27
#define RSUPV_ANALYZER_PREFILTER_PEMP75     28
#define RSUPV_ANALYZER_PREFILTER_HP22       29
#define RSUPV_ANALYZER_PREFILTER_HP400      30
#define RSUPV_ANALYZER_PREFILTER_LP22       31
#define RSUPV_ANALYZER_PREFILTER_LP30       32
#define RSUPV_ANALYZER_PREFILTER_LP80       33  
#define RSUPV_ANALYZER_PREFILTER_AES17      34
#define RSUPV_ANALYZER_PREFILTER_CWE        35
/* --- Start Condition ------------------------------------------------------ */

#define RSUPV_ANALYZER_START_CONDITION_AUTO 0
#define RSUPV_ANALYZER_START_CONDITION_TIM  1
#define RSUPV_ANALYZER_START_CONDITION_TCH  2
#define RSUPV_ANALYZER_START_CONDITION_CH1F 3
#define RSUPV_ANALYZER_START_CONDITION_CH2F 4
#define RSUPV_ANALYZER_START_CONDITION_CH1R 5
#define RSUPV_ANALYZER_START_CONDITION_CH2R 6
#define RSUPV_ANALYZER_START_CONDITION_CH1L 7
#define RSUPV_ANALYZER_START_CONDITION_CH2L 8
#define RSUPV_ANALYZER_START_CONDITION_CH1T 9
#define RSUPV_ANALYZER_START_CONDITION_CH2T 10
#define RSUPV_ANALYZER_START_CONDITION_CH1E 11
#define RSUPV_ANALYZER_START_CONDITION_CH2E 12
#define RSUPV_ANALYZER_START_CONDITION_FREQ 13
#define RSUPV_ANALYZER_START_CONDITION_RAP  14
#define RSUPV_ANALYZER_START_CONDITION_LEV  15
#define RSUPV_ANALYZER_START_CONDITION_TRIG 16
#define RSUPV_ANALYZER_START_CONDITION_EDG  17
    
/* --- Trigger Settling Mode ------------------------------------------------ */
	
#define RSUPV_ANALYZER_TRIG_SETTLING_OFF  0
#define RSUPV_ANALYZER_TRIG_SETTLING_EXP  1
#define RSUPV_ANALYZER_TRIG_SETTLING_FLAT 2
#define RSUPV_ANALYZER_TRIG_SETTLING_AVER 3
    
/* --- Coupling ------------------------------------------------------------- */

#define RSUPV_ANALYZER_COUPLING_AC          0
#define RSUPV_ANALYZER_COUPLING_DC          1

/* --- Channel Input -------------------------------------------------------- */

#define RSUPV_ANALYZER_CH_INPUT_BAL         0
#define RSUPV_ANALYZER_CH_INPUT_GEN1        1
#define RSUPV_ANALYZER_CH_INPUT_GEN2        2

/* --- Channel Input Impedance ---------------------------------------------- */

#define RSUPV_ANALYZER_CH_INPUT_IMPEDANCE_R300   0
#define RSUPV_ANALYZER_CH_INPUT_IMPEDANCE_R600   1
#define RSUPV_ANALYZER_CH_INPUT_IMPEDANCE_R200K  2
#define RSUPV_ANALYZER_CH_INPUT_IMPEDANCE_R110   3
#define RSUPV_ANALYZER_CH_INPUT_IMPEDANCE_R10K   4
#define RSUPV_ANALYZER_CH_INPUT_IMPEDANCE_R20K   5
#define RSUPV_ANALYZER_CH_INPUT_IMPEDANCE_USER   6

/* --- Channel Input Common ------------------------------------------------- */

#define RSUPV_ANALYZER_CH_INPUT_COMMON_FLOAT    0
#define RSUPV_ANALYZER_CH_INPUT_COMMON_GROUND   1

/* --- Channel Input Range -------------------------------------------------- */

#define RSUPV_ANALYZER_CH_INPUT_RANGE_AUTO      0
#define RSUPV_ANALYZER_CH_INPUT_RANGE_FIX       1
#define RSUPV_ANALYZER_CH_INPUT_RANGE_LOWER     2

/* --- Measurement Mode ----------------------------------------------------- */

#define RSUPV_ANALYZER_MEAS_MODE_ADATA          0
#define RSUPV_ANALYZER_MEAS_MODE_JPHASE         1
#define RSUPV_ANALYZER_MEAS_MODE_CINPUT         2

/* --- Jitter Reference ----------------------------------------------------- */

#define RSUPV_ANALYZER_JITTER_INTC              0
#define RSUPV_ANALYZER_JITTER_REFP              1

/* --- Sample Frequency ----------------------------------------------------- */

#define RSUPV_ANALYZER_SAMPLE_FREQ_F32          0
#define RSUPV_ANALYZER_SAMPLE_FREQ_F44          1
#define RSUPV_ANALYZER_SAMPLE_FREQ_F48          2
#define RSUPV_ANALYZER_SAMPLE_FREQ_F88          3
#define RSUPV_ANALYZER_SAMPLE_FREQ_F96          4
#define RSUPV_ANALYZER_SAMPLE_FREQ_F176         5
#define RSUPV_ANALYZER_SAMPLE_FREQ_F192         6
#define RSUPV_ANALYZER_SAMPLE_FREQ_VALUE        7
#define RSUPV_ANALYZER_SAMPLE_FREQ_AUTO         8
#define RSUPV_ANALYZER_SAMPLE_FREQ_CHSTAT       9
    
/* --- Digital Audio Input -------------------------------------------------- */

#define RSUPV_ANALYZER_DIG_AUD_IN_BAL           0
#define RSUPV_ANALYZER_DIG_AUD_IN_UNB           1
#define RSUPV_ANALYZER_DIG_AUD_IN_OPT           2
#define RSUPV_ANALYZER_DIG_AUD_IN_INT           3

/* --- Analyzer Function ---------------------------------------------------- */

#define RSUPV_ANALYZER_FUNC_OFF                 0
#define RSUPV_ANALYZER_FUNC_RMS                 1
#define RSUPV_ANALYZER_FUNC_RMSS                2
#define RSUPV_ANALYZER_FUNC_PEAK                3
#define RSUPV_ANALYZER_FUNC_QPE                 4
#define RSUPV_ANALYZER_FUNC_DC                  5
#define RSUPV_ANALYZER_FUNC_THD                 6
#define RSUPV_ANALYZER_FUNC_THDN                7
#define RSUPV_ANALYZER_FUNC_MDIS                8
#define RSUPV_ANALYZER_FUNC_DFD                 9
#define RSUPV_ANALYZER_FUNC_WAF                 10
#define RSUPV_ANALYZER_FUNC_POL                 11
#define RSUPV_ANALYZER_FUNC_FFT                 12
#define RSUPV_ANALYZER_FUNC_FILT                13
#define RSUPV_ANALYZER_FUNC_WAV                 14
#define RSUPV_ANALYZER_FUNC_COH                 15
#define RSUPV_ANALYZER_FUNC_RUBB                16
#define RSUPV_ANALYZER_FUNC_PROT                17
#define RSUPV_ANALYZER_FUNC_THIR                18
#define RSUPV_ANALYZER_FUNC_SN                  19
#define RSUPV_ANALYZER_FUNC_NOCT                20
#define RSUPV_ANALYZER_FUNC_REC                 21
#define RSUPV_ANALYZER_FUNC_DIM                 22
#define RSUPV_ANALYZER_FUNC_PESQ                23
#define RSUPV_ANALYZER_FUNC_PEAQ				24
#define RSUPV_ANALYZER_FUNC_POLQA				25
#define RSUPV_ANALYZER_FUNC_LIPSYNC 			26
#define RSUPV_ANALYZER_FUNC_PLUGIN				27

/* --- Measurement Settling ------------------------------------------------- */

#define RSUPV_MEAS_FUNC_SETTLING_OFF  0
#define RSUPV_MEAS_FUNC_SETTLING_EXP  1
#define RSUPV_MEAS_FUNC_SETTLING_FLAT 2
#define RSUPV_MEAS_FUNC_SETTLING_AVER 3	

/* --- Notch Gain ----------------------------------------------------------- */

#define RSUPV_ANALYZER_NOTCH_GAIN_OFF           0
#define RSUPV_ANALYZER_NOTCH_GAIN_DB0           1
#define RSUPV_ANALYZER_NOTCH_GAIN_DB12          2
#define RSUPV_ANALYZER_NOTCH_GAIN_DB30          3

/* --- Notch Frequency ------------------------------------------------------ */

#define RSUPV_ANALYZER_NOTCH_FREQ_FIX           0
#define RSUPV_ANALYZER_NOTCH_FREQ_GENT          1

/* --- Analyzer Filter ------------------------------------------------------ */

#define RSUPV_ANALYZER_FILTER_OFF               0
#define RSUPV_ANALYZER_FILTER_UFIL1             1
#define RSUPV_ANALYZER_FILTER_UFIL2             2
#define RSUPV_ANALYZER_FILTER_UFIL3             3
#define RSUPV_ANALYZER_FILTER_UFIL4             4
#define RSUPV_ANALYZER_FILTER_UFIL5             5
#define RSUPV_ANALYZER_FILTER_UFIL6             6
#define RSUPV_ANALYZER_FILTER_UFIL7             7
#define RSUPV_ANALYZER_FILTER_UFIL8             8
#define RSUPV_ANALYZER_FILTER_UFIL9             9
#define RSUPV_ANALYZER_FILTER_AWE               10
#define RSUPV_ANALYZER_FILTER_CCIR              11
#define RSUPV_ANALYZER_FILTER_CARM              12
#define RSUPV_ANALYZER_FILTER_CCIU              13
#define RSUPV_ANALYZER_FILTER_CCIT              14
#define RSUPV_ANALYZER_FILTER_CMES              15
#define RSUPV_ANALYZER_FILTER_DCN               16
#define RSUPV_ANALYZER_FILTER_DEMP17            17
#define RSUPV_ANALYZER_FILTER_DEMP5015          18
#define RSUPV_ANALYZER_FILTER_DEMP50            19
#define RSUPV_ANALYZER_FILTER_DEMP75            20
#define RSUPV_ANALYZER_FILTER_IECT              21
#define RSUPV_ANALYZER_FILTER_JITT              22
#define RSUPV_ANALYZER_FILTER_URUM              23
#define RSUPV_ANALYZER_FILTER_WRUM              24
#define RSUPV_ANALYZER_FILTER_PEMP17            25
#define RSUPV_ANALYZER_FILTER_PEMP5015          26
#define RSUPV_ANALYZER_FILTER_PEMP50            27
#define RSUPV_ANALYZER_FILTER_PEMP75            28
#define RSUPV_ANALYZER_FILTER_HP22              29
#define RSUPV_ANALYZER_FILTER_HP400             30
#define RSUPV_ANALYZER_FILTER_LP22              31
#define RSUPV_ANALYZER_FILTER_LP30              32
#define RSUPV_ANALYZER_FILTER_LP80              33
#define RSUPV_ANALYZER_FILTER_AES17             34
#define RSUPV_ANALYZER_FILTER_CWE               35
/* --- Measurement Time ----------------------------------------------------- */

#define RSUPV_ANALYZER_MEAS_TIME_AFAS           0
#define RSUPV_ANALYZER_MEAS_TIME_AUTO           1
#define RSUPV_ANALYZER_MEAS_TIME_VAL            2
#define RSUPV_ANALYZER_MEAS_TIME_GENT           3
#define RSUPV_ANALYZER_MEAS_TIME_SFAS           4
#define RSUPV_ANALYZER_MEAS_TIME_FAS            5
#define RSUPV_ANALYZER_MEAS_TIME_SLOW           6
#define RSUPV_ANALYZER_MEAS_TIME_FIX            7

/* --- Sweep Control -------------------------------------------------------- */

#define RSUPV_ANALYZER_SWEEP_CTRL_OFF           0
#define RSUPV_ANALYZER_SWEEP_CTRL_ASW           1
#define RSUPV_ANALYZER_SWEEP_CTRL_ALIS          2
#define RSUPV_ANALYZER_SWEEP_CTRL_MSW           3
#define RSUPV_ANALYZER_SWEEP_CTRL_MLIS          4

/* --- Sweep Spacing -------------------------------------------------------- */

#define RSUPV_ANALYZER_SWEEP_SPAC_LINP          0
#define RSUPV_ANALYZER_SWEEP_SPAC_LINS          1
#define RSUPV_ANALYZER_SWEEP_SPAC_LOGP          2
#define RSUPV_ANALYZER_SWEEP_SPAC_LOGS          3

/* --- Peak Measurement Mode ------------------------------------------------ */

#define RSUPV_ANALYZER_PEAK_MEAS_MODE_PPE       0
#define RSUPV_ANALYZER_PEAK_MEAS_MODE_NPE       1
#define RSUPV_ANALYZER_PEAK_MEAS_MODE_PTOP      2
#define RSUPV_ANALYZER_PEAK_MEAS_MODE_PABS      3

/* --- Peak Measurement Interval Value -------------------------------------- */

#define RSUPV_ANALYZER_PEAK_MEAS_INTV_TIME_SFAS     0
#define RSUPV_ANALYZER_PEAK_MEAS_INTV_TIME_FAST     1
#define RSUPV_ANALYZER_PEAK_MEAS_INTV_TIME_SLOW     2
#define RSUPV_ANALYZER_PEAK_MEAS_INTV_TIME_VAL      3
#define RSUPV_ANALYZER_PEAK_MEAS_INTV_TIME_FIX      4

/* --- Dynamic Mode --------------------------------------------------------- */

#define RSUPV_ANALYZER_DMODE_FAST               0
#define RSUPV_ANALYZER_DMODE_PREC               1

/* --- THD Fundamental ------------------------------------------------------ */

#define RSUPV_ANALYZER_THD_FUND_AUTO            0
#define RSUPV_ANALYZER_THD_FUND_VAL             1
#define RSUPV_ANALYZER_THD_FUND_GENT            2

/* --- THD Measurement Mode ------------------------------------------------- */

#define RSUPV_ANALYZER_THD_MMODE_SEL            0
#define RSUPV_ANALYZER_THD_MMODE_DEV            1
#define RSUPV_ANALYZER_THD_MMODE_DODD           2
#define RSUPV_ANALYZER_THD_MMODE_DALL           3
#define RSUPV_ANALYZER_THD_MMODE_LSEL           4
#define RSUPV_ANALYZER_THD_MMODE_LDEV           5
#define RSUPV_ANALYZER_THD_MMODE_LDOD           6
#define RSUPV_ANALYZER_THD_MMODE_LDAL           7

/* --- THDN Measurement Mode ------------------------------------------------ */

#define RSUPV_ANALYZER_THDN_MMODE_THDN          0
#define RSUPV_ANALYZER_THDN_MMODE_SNDR          1
#define RSUPV_ANALYZER_THDN_MMODE_NOIS          2
#define RSUPV_ANALYZER_THDN_MMODE_LTHD          3
#define RSUPV_ANALYZER_THDN_MMODE_LNO           4

/* --- THDN Rejection ------------------------------------------------------- */

#define RSUPV_ANALYZER_THDN_REJ_NARR            0
#define RSUPV_ANALYZER_THDN_REJ_WIDE            1

/* --- THDN Reject Bandwidth ------------------------------------------------ */

#define RSUPV_ANALYZER_THDN_REJECTBW_WIDE       0
#define RSUPV_ANALYZER_THDN_REJECTBW_MED        1
#define RSUPV_ANALYZER_THDN_REJECTBW_NARR       2

/* --- DFD Measurement Mode ------------------------------------------------- */

#define RSUPV_ANALYZER_DFD_MMODE_D2_268         0
#define RSUPV_ANALYZER_DFD_MMODE_D3_268         1
#define RSUPV_ANALYZER_DFD_MMODE_D2_118         2
#define RSUPV_ANALYZER_DFD_MMODE_D3_118         3

/* --- FFT Size ------------------------------------------------------------- */

#define RSUPV_ANALYZER_FFT_SIZE_S512            0
#define RSUPV_ANALYZER_FFT_SIZE_S1K             1
#define RSUPV_ANALYZER_FFT_SIZE_S2K             2
#define RSUPV_ANALYZER_FFT_SIZE_S4K             3
#define RSUPV_ANALYZER_FFT_SIZE_S8K             4
#define RSUPV_ANALYZER_FFT_SIZE_S16K            5
#define RSUPV_ANALYZER_FFT_SIZE_S32K            6
#define RSUPV_ANALYZER_FFT_SIZE_S64K            7
#define RSUPV_ANALYZER_FFT_SIZE_S128K           8
#define RSUPV_ANALYZER_FFT_SIZE_S256K           9

/* --- FFT Window ----------------------------------------------------------- */

#define RSUPV_ANALYZER_FFT_WIND_HANN            0
#define RSUPV_ANALYZER_FFT_WIND_RECT            1
#define RSUPV_ANALYZER_FFT_WIND_BLAC            2
#define RSUPV_ANALYZER_FFT_WIND_RIF1            3
#define RSUPV_ANALYZER_FFT_WIND_RIF2            4
#define RSUPV_ANALYZER_FFT_WIND_RIF3            5
#define RSUPV_ANALYZER_FFT_WIND_HAMM            6
#define RSUPV_ANALYZER_FFT_WIND_FLAT            7

/* --- FFT Average Mode ----------------------------------------------------- */

#define RSUPV_ANALYZER_FFT_AVER_MODE_OFF        0
#define RSUPV_ANALYZER_FFT_AVER_MODE_EXP        1
#define RSUPV_ANALYZER_FFT_AVER_MODE_NORM       2

/* --- Level Monitor -------------------------------------------------------- */

#define RSUPV_ANALYZER_LEV_MON_OFF              0
#define RSUPV_ANALYZER_LEV_MON_RMS              1
#define RSUPV_ANALYZER_LEV_MON_DC               2
#define RSUPV_ANALYZER_LEV_MON_IMAX             3

/* --- Input Monitor -------------------------------------------------------- */

#define RSUPV_ANALYZER_INPUT_MON_OFF            0
#define RSUPV_ANALYZER_INPUT_MON_IPEA           1
#define RSUPV_ANALYZER_INPUT_MON_PHAS           2
#define RSUPV_ANALYZER_INPUT_MON_DIG            3

/* --- Freq To Phase -------------------------------------------------------- */

#define RSUPV_ANALYZER_FREQ_PHASE_OFF           0
#define RSUPV_ANALYZER_FREQ_PHASE_FREQ          1
#define RSUPV_ANALYZER_FREQ_PHASE_FQPH          2
#define RSUPV_ANALYZER_FREQ_PHASE_FQGR          3
#define RSUPV_ANALYZER_FREQ_PHASE_SFR           4
#define RSUPV_ANALYZER_FREQ_PHASE_FQS           5

/* --- Measurement Time ----------------------------------------------------- */

#define RSUPV_ANALYZER_MEAS_TIME_FAST           0
#define RSUPV_ANALYZER_MEAS_TIME_PREC           1

/* --- Format Phase --------------------------------------------------------- */

#define RSUPV_ANALYZER_PHASE_FORMAT_POS         0
#define RSUPV_ANALYZER_PHASE_FORMAT_POSN        1
#define RSUPV_ANALYZER_PHASE_FORMAT_NEG         2
#define RSUPV_ANALYZER_PHASE_FORMAT_RAD         3
#define RSUPV_ANALYZER_PHASE_FORMAT_RADB        4
#define RSUPV_ANALYZER_PHASE_FORMAT_RADN        5
#define RSUPV_ANALYZER_PHASE_FORMAT_INF         6

/* --- Measurement ---------------------------------------------------------- */

#define RSUPV_ANALYZER_MEASUREMENT_FUNC         1
#define RSUPV_ANALYZER_MEASUREMENT_IMON         2
#define RSUPV_ANALYZER_MEASUREMENT_FRQ3         3
#define RSUPV_ANALYZER_MEASUREMENT_FRQ4         4
#define RSUPV_ANALYZER_MEASUREMENT_FMON         5
#define RSUPV_ANALYZER_MEASUREMENT_LMON         6
#define RSUPV_ANALYZER_MEASUREMENT_WMON         7

/* --- Measurement Result --------------------------------------------------- */

#define RSUPV_MEASUREMENT_FUNCTION              0
#define RSUPV_MEASUREMENT_INPUT_MONITOR         1
#define RSUPV_MEASUREMENT_LEVEL_MONITOR         2
#define RSUPV_MEASUREMENT_FREQUENCY             3
#define RSUPV_MEASUREMENT_PHASE_GRP_DELAY       4

/* --- Function Reference --------------------------------------------------- */

#define RSUPV_ANALYZER_FUNCTION_REF_CH1S        0
#define RSUPV_ANALYZER_FUNCTION_REF_CH2S        1
#define RSUPV_ANALYZER_FUNCTION_REF_STOR        2
#define RSUPV_ANALYZER_FUNCTION_REF_CH1M        3
#define RSUPV_ANALYZER_FUNCTION_REF_CH2M        4
#define RSUPV_ANALYZER_FUNCTION_REF_GENT        5
#define RSUPV_ANALYZER_FUNCTION_REF_VAL         6
#define RSUPV_ANALYZER_FUNCTION_REF_DIG         7
#define RSUPV_ANALYZER_FUNCTION_REF_SOUR	    8
#define RSUPV_ANALYZER_FUNCTION_REF_MREF        9
#define RSUPV_ANALYZER_FUNCTION_REF_CH3S        10
#define RSUPV_ANALYZER_FUNCTION_REF_CH4S        11
#define RSUPV_ANALYZER_FUNCTION_REF_CH5S        12
#define RSUPV_ANALYZER_FUNCTION_REF_CH6S        13
#define RSUPV_ANALYZER_FUNCTION_REF_CH7S        14
#define RSUPV_ANALYZER_FUNCTION_REF_CH8S        15
#define RSUPV_ANALYZER_FUNCTION_REF_CH9S        16
#define RSUPV_ANALYZER_FUNCTION_REF_CH10S       17
#define RSUPV_ANALYZER_FUNCTION_REF_CH11S       18
#define RSUPV_ANALYZER_FUNCTION_REF_CH12S       19
#define RSUPV_ANALYZER_FUNCTION_REF_CH13S       20
#define RSUPV_ANALYZER_FUNCTION_REF_CH14S       21
#define RSUPV_ANALYZER_FUNCTION_REF_CH15S       22
#define RSUPV_ANALYZER_FUNCTION_REF_CH16S       23

/* --- Function Phase Reference --------------------------------------------- */

#define RSUPV_ANALYZER_FUNCTION_PHASE_REF_STOR      0
#define RSUPV_ANALYZER_FUNCTION_PHASE_REF_VAL       1
#define RSUPV_ANALYZER_FUNCTION_PHASE_REF_GENT      2

/* --- Trace ---------------------------------------------------------------- */

#define RSUPV_ANALYZER_TRACE_FFT_AB                 0
#define RSUPV_ANALYZER_TRACE_FFT_A                  1
#define RSUPV_ANALYZER_TRACE_FFT_B                  2
#define RSUPV_ANALYZER_TRACE_SWP_AB                 3
#define RSUPV_ANALYZER_TRACE_SWP_A                  4
#define RSUPV_ANALYZER_TRACE_SWP_B                  5
#define RSUPV_ANALYZER_TRACE_MON_AB                 6
#define RSUPV_ANALYZER_TRACE_MON_A                  7
#define RSUPV_ANALYZER_TRACE_MON_B                  8
#define RSUPV_ANALYZER_TRACE_WAV_AB                 9
#define RSUPV_ANALYZER_TRACE_WAV_A                  10
#define RSUPV_ANALYZER_TRACE_WAV_B                  11
#define RSUPV_ANALYZER_TRACE_BAR_AB                 12
#define RSUPV_ANALYZER_TRACE_BAR_A                  13
#define RSUPV_ANALYZER_TRACE_BAR_B                  14
    
/* --- Bandwidth ------------------------------------------------------------ */

#define RSUPV_ANALYZER_MEAS_BAND_PPCT1              0
#define RSUPV_ANALYZER_MEAS_BAND_PPCT3              1
#define RSUPV_ANALYZER_MEAS_BAND_POCT12             2
#define RSUPV_ANALYZER_MEAS_BAND_PTOC               3
#define RSUPV_ANALYZER_MEAS_BAND_PFAS               4
#define RSUPV_ANALYZER_MEAS_BAND_PFIX               5
#define RSUPV_ANALYZER_MEAS_BAND_SPCT1              6
#define RSUPV_ANALYZER_MEAS_BAND_SPCT3              7
#define RSUPV_ANALYZER_MEAS_BAND_SOCT12             8
#define RSUPV_ANALYZER_MEAS_BAND_STOC               9
#define RSUPV_ANALYZER_MEAS_BAND_SFAS               10
#define RSUPV_ANALYZER_MEAS_BAND_SFIX               11
    
/* --- Bandwidth ------------------------------------------------------------ */

#define RSUPV_ANALYZER_MEAS_FMODE_FIX               0
#define RSUPV_ANALYZER_MEAS_FMODE_GENT              1
#define RSUPV_ANALYZER_MEAS_FMODE_CH1F              2
#define RSUPV_ANALYZER_MEAS_FMODE_CH2F              3
#define RSUPV_ANALYZER_MEAS_FMODE_AUTO              4
#define RSUPV_ANALYZER_MEAS_FMODE_REFF              5
    
/* --- SN Meas Mode --------------------------------------------------------- */

#define RSUPV_ANALYZER_SN_MEAS_MODE_RMS             0
#define RSUPV_ANALYZER_SN_MEAS_MODE_QPE             1
#define RSUPV_ANALYZER_SN_MEAS_MODE_PPE             2
#define RSUPV_ANALYZER_SN_MEAS_MODE_NPE             3
#define RSUPV_ANALYZER_SN_MEAS_MODE_PTOP            4
#define RSUPV_ANALYZER_SN_MEAS_MODE_PABS            5
    
/* --- NOCT Meas Mode ------------------------------------------------------- */

#define RSUPV_ANALYZER_NOCT_MEAS_MODE_OCT1          0
#define RSUPV_ANALYZER_NOCT_MEAS_MODE_OCT3          1
#define RSUPV_ANALYZER_NOCT_MEAS_MODE_OCT6          2
#define RSUPV_ANALYZER_NOCT_MEAS_MODE_OCT12         3
#define RSUPV_ANALYZER_NOCT_MEAS_MODE_OCT24         4   
    
/* --- NOCT Meas Mode ------------------------------------------------------- */

#define RSUPV_ANALYZER_REC_TRG_SRC_CH1              0
#define RSUPV_ANALYZER_REC_TRG_SRC_CH2              1
#define RSUPV_ANALYZER_REC_TRG_SRC_MAN              2
#define RSUPV_ANALYZER_REC_TRG_SRC_GENB             3
    
/* --- NOCT Trigger Slope --------------------------------------------------- */

#define RSUPV_ANALYZER_REC_TRG_SLOPE_RIS            0
#define RSUPV_ANALYZER_REC_TRG_SLOPE_FAL            1
    
/* --- Waveform Meas Mode --------------------------------------------------- */

#define RSUPV_ANALYZER_WAV_MMODE_STAN               0
#define RSUPV_ANALYZER_WAV_MMODE_COMP               1
#define RSUPV_ANALYZER_WAV_MMODE_USAM               2
    
/* --- Waveform Trigger Source ---------------------------------------------- */

#define RSUPV_ANALYZER_WAV_TRG_SRC_CH1              0
#define RSUPV_ANALYZER_WAV_TRG_SRC_CH2              1
#define RSUPV_ANALYZER_WAV_TRG_SRC_MAN              2
#define RSUPV_ANALYZER_WAV_TRG_SRC_GENB             3
#define RSUPV_ANALYZER_WAV_TRG_SRC_TRGC             4
    
/* --- Waveform Trigger Slope- ---------------------------------------------- */

#define RSUPV_ANALYZER_WAV_TRG_SLOPE_RIS            0
#define RSUPV_ANALYZER_WAV_TRG_SLOPE_FALL           1
    
/* === I2S Analyzer ========================================================= */

/* --- Word Length ---------------------------------------------------------- */

#define RSUPV_ANALYZER_I2S_W16                      0
#define RSUPV_ANALYZER_I2S_W24                      1
#define RSUPV_ANALYZER_I2S_W32                      2
    
/* --- Format --------------------------------------------------------------- */

#define RSUPV_ANALYZER_I2S_FORM_I2S                 0
#define RSUPV_ANALYZER_I2S_FORM_USER                1

/* --- Fsync Slope ---------------------------------------------------------- */

#define RSUPV_ANALYZER_I2S_FSLOPE_FALL              0
#define RSUPV_ANALYZER_I2S_FSLOPE_RAIS              1
    
/* --- Input Input ---------------------------------------------------------- */

#define RSUPV_ANALYZER_I2S_INPUT_DSUB               0
#define RSUPV_ANALYZER_I2S_INPUT_INT                1
    
/* --- Sample Frequency Mode ------------------------------------------------ */

#define RSUPV_ANALYZER_I2S_SAMPLE_FREQ_F08    0
#define RSUPV_ANALYZER_I2S_SAMPLE_FREQ_F11    1
#define RSUPV_ANALYZER_I2S_SAMPLE_FREQ_F16    2
#define RSUPV_ANALYZER_I2S_SAMPLE_FREQ_F22    3
#define RSUPV_ANALYZER_I2S_SAMPLE_FREQ_F32    4
#define RSUPV_ANALYZER_I2S_SAMPLE_FREQ_F44    5
#define RSUPV_ANALYZER_I2S_SAMPLE_FREQ_F48    6
#define RSUPV_ANALYZER_I2S_SAMPLE_FREQ_F88    7
#define RSUPV_ANALYZER_I2S_SAMPLE_FREQ_F96    8
#define RSUPV_ANALYZER_I2S_SAMPLE_FREQ_F176   9
#define RSUPV_ANALYZER_I2S_SAMPLE_FREQ_F192   10
#define RSUPV_ANALYZER_I2S_SAMPLE_FREQ_F384   11
#define RSUPV_ANALYZER_I2S_SAMPLE_FREQ_VALUE  12
#define RSUPV_ANALYZER_I2S_SAMPLE_FREQ_AUTO   13
    

#define RSUPV_ANALYZER_PESQ_DMODE_PP862    0
#define RSUPV_ANALYZER_PESQ_DMODE_PPSI862  1
#define RSUPV_ANALYZER_PESQ_DMODE_PPSP862  2
#define RSUPV_ANALYZER_PESQ_DMODE_MP8621   3
#define RSUPV_ANALYZER_PESQ_DMODE_MPSI8621 4
#define RSUPV_ANALYZER_PESQ_DMODE_MPSP8621 5
#define RSUPV_ANALYZER_PESQ_DMODE_MP8622   6
#define RSUPV_ANALYZER_PESQ_DMODE_MPSI8622 7
#define RSUPV_ANALYZER_PESQ_DMODE_MPSP8622 8

/* --- PESQ Measurement Mode ------------------------------------------------ */
#define RSUPV_ANALYZER_PESQ_MMODE_DUT     0
#define RSUPV_ANALYZER_PESQ_MMODE_OFFLINE 1
    
/* --- Multichannel Coupling Mode ------------------------------------------- */
#define RSUPV_MULTICHANNEL_ANALYZER_COUPLING_TRACK 0
#define RSUPV_MULTICHANNEL_ANALYZER_COUPLING_SPLIT 1

/* --- External Sweep Mode ------------------------------------------------- */
#define RSUPV_ANALYZER_FREQ    0
#define RSUPV_ANALYZER_VOLT    1

/* === HDMI Analyzer ======================================================= */

/* --- Analyzer Audio Input ------------------------------------------------ */       
#define RSUPV_ANALYZER_HDMI_INPUT_SINK      0
#define RSUPV_ANALYZER_HDMI_INPUT_SARC      1
#define RSUPV_ANALYZER_HDMI_INPUT_DIUNBAL   2
#define RSUPV_ANALYZER_HDMI_INPUT_DIOPTICAL 3

/* --- Audio Format --------------------------------------------------------- */
#define RSUPV_HDMI_AUDIO_FORMAT_PCM_L0 0
#define RSUPV_HDMI_AUDIO_FORMAT_PCM_L1 1
#define RSUPV_HDMI_AUDIO_FORMAT_DD     2
#define RSUPV_HDMI_AUDIO_FORMAT_DDP    3
#define RSUPV_HDMI_AUDIO_FORMAT_DTS    4
#define RSUPV_HDMI_AUDIO_FORMAT_DTHD   5
#define RSUPV_HDMI_AUDIO_FORMAT_DTSHD  6
#define RSUPV_HDMI_AUDIO_FORMAT_DHDM   7

/* --- Audio Coding -------------------------------------------------------- */
#define RSUPV_ANALYZER_HDMI_AUDIO_CODING_PCM         0
#define RSUPV_ANALYZER_HDMI_AUDIO_CODING_AUTO_DETECT 1


/* === User-Defined Filters ================================================= */

/* --- Filter Type ---------------------------------------------------------- */

#define RSUPV_USER_DEF_FILTER_LPAS                  0
#define RSUPV_USER_DEF_FILTER_HPAS                  1
#define RSUPV_USER_DEF_FILTER_BPAS                  2
#define RSUPV_USER_DEF_FILTER_BSTO                  3
#define RSUPV_USER_DEF_FILTER_NOTC                  4
#define RSUPV_USER_DEF_FILTER_TOCT                  5
#define RSUPV_USER_DEF_FILTER_OCT                   6
#define RSUPV_USER_DEF_FILTER_FILE                  7

/* --- Filter Order --------------------------------------------------------- */

#define RSUPV_USER_DEF_FILTER_ORDER_N4              0
#define RSUPV_USER_DEF_FILTER_ORDER_N8              1

/* === AUXILIARIES ========================================================== */

/* --- Aux Signal Source ---------------------------------------------------- */

#define RSUPV_AUX_SIGNAL_SOURCE_INP                 0
#define RSUPV_AUX_SIGNAL_SOURCE_MON                 1
#define RSUPV_AUX_SIGNAL_SOURCE_FUNC                2
#define RSUPV_AUX_SIGNAL_SOURCE_GEN                 3
#define RSUPV_AUX_SIGNAL_SOURCE_DC                  4

/* --- Aux Channel ---------------------------------------------------------- */

#define RSUPV_AUX_CHANNEL_STER                      0
#define RSUPV_AUX_CHANNEL_CH1                       1
#define RSUPV_AUX_CHANNEL_CH2                       2

/* --- Aux Analog Aux Out --------------------------------------------------- */

#define RSUPV_AUX_ANLG_OUT_DC                       0
#define RSUPV_AUX_ANLG_OUT_AUDM1                    1

/* --- Aux Phone Out -------------------------------------------------------- */

#define RSUPV_AUX_PHONE_OUT_SPKC                    0
#define RSUPV_AUX_PHONE_OUT_PERM                    1
    
/* --- Aux Trigger Input Mode ----------------------------------------------- */

#define RSUPV_AUX_TRG_INPUT_MODE_MSIN               0
#define RSUPV_AUX_TRG_INPUT_MODE_MCON               1
#define RSUPV_AUX_TRG_INPUT_MODE_TRIG               2
    
/* --- Aux Trigger Input Edge ----------------------------------------------- */

#define RSUPV_AUX_TRG_INPUT_EDGE_RIS                0
#define RSUPV_AUX_TRG_INPUT_EDGE_FALL               1   

/* --- Aux Trigger Output Mode ----------------------------------------------- */

#define RSUPV_AUX_TRG_OUTPUT_MODE_MEAS              0
#define RSUPV_AUX_TRG_OUTPUT_MODE_AUXC              1   

/* === CONFIGURATION ======================================================== */

#define RSUPV_CALIBRATION_CLDG                      0
#define RSUPV_CALIBRATION_CAGE                      1
#define RSUPV_CALIBRATION_CANL                      2
#define RSUPV_CALIBRATION_CDPH                      3
    
/* === SWITCHER ============================================================= */

/* --- Switcher Tracking ---------------------------------------------------- */

#define RSUPV_SWITCHER_TRACKING_OFF                 0
#define RSUPV_SWITCHER_TRACKING_BVSA                1
#define RSUPV_SWITCHER_TRACKING_OVSI                2
#define RSUPV_SWITCHER_TRACKING_ALL                 3

/* --- Switcher Offset ------------------------------------------------------ */

#define RSUPV_SWITCHER_OFFSET_BVSA                  0
#define RSUPV_SWITCHER_OFFSET_OVSI                  1

/* --- Switcher Input/Output ------------------------------------------------ */

#define RSUPV_SWITCHER_A                            0
#define RSUPV_SWITCHER_B                            1


/* --- Switcher Connection -------------------------------------------------- */

#define RSUPV_SWITCHER_CONNECTION_COM  				0
#define RSUPV_SWITCHER_CONNECTION_USB  				1

/* --- Switcher COM Port ---------------------------------------------------- */                

#define RSUPV_AUDIO_SWIT_COM1                       0
#define RSUPV_AUDIO_SWIT_COM2                       1
#define RSUPV_AUDIO_SWIT_COM3                       2
#define RSUPV_AUDIO_SWIT_COM4                       3
#define RSUPV_AUDIO_SWIT_AUTO						4

/* === PROTOCOL ANALYSIS ==================================================== */

/* --- Protocol View Mode --------------------------------------------------- */

#define RSUPV_ANALYZER_PROT_VIEW_BINT               0
#define RSUPV_ANALYZER_PROT_VIEW_BIN                1

/* --- Protocol Highlight --------------------------------------------------- */

#define RSUPV_PROTOCOL_HIGHLIGHT_NOTHING            0
#define RSUPV_PROTOCOL_HIGHLIGHT_OUTPUT             1
#define RSUPV_PROTOCOL_HIGHLIGHT_CHANNELS           2
#define RSUPV_PROTOCOL_HIGHLIGHT_CHANGES            3

/* --- Protocol Persistence ------------------------------------------------- */

#define RSUPV_PROTOCOL_PERSISTENCE_SHORT            0
#define RSUPV_PROTOCOL_PERSISTENCE_LONG             1
#define RSUPV_PROTOCOL_PERSISTENCE_FOREVER          2

/* --- Protocol Coding Mode ------------------------------------------------- */

#define RSUPV_PROTOCOL_CODING_MODE_AUTO             0
#define RSUPV_PROTOCOL_CODING_MODE_PRO              1
#define RSUPV_PROTOCOL_CODING_MODE_CONS             2
#define RSUPV_PROTOCOL_CODING_MODE_FILE				3

/* --- Protocol Validity ---------------------------------------------------- */

#define RSUPV_PROTOCOL_VALIDITY_1_2                 0
#define RSUPV_PROTOCOL_VALIDITY_NONE                1

/* --- Protocol Channels ---------------------------------------------------- */

#define RSUPV_PROTOCOL_CHANNELS_2_IS_1              0
#define RSUPV_PROTOCOL_CHANNELS_SPLIT               1

/* === DISPLAY ============================================================== */

/* --- Display Subsystem ---------------------------------------------------- */

#define RSUPV_DISP_SUBSYS_SWE                       0
#define RSUPV_DISP_SUBSYS_MON                       4
#define RSUPV_DISP_SUBSYS_FFT                       1
#define RSUPV_DISP_SUBSYS_WAV                       2
#define RSUPV_DISP_SUBSYS_BAR                       3
#define RSUPV_DISP_SUBSYS_PESQ                      5

/* --- Display Data List Filter --------------------------------------------- */

#define RSUPV_DISP_DLIST_FILTER_ALL                 0
#define RSUPV_DISP_DLIST_FILTER_LIMU                1
#define RSUPV_DISP_DLIST_FILTER_LIML                2
#define RSUPV_DISP_DLIST_FILTER_LIMB                3
#define RSUPV_DISP_DLIST_FILTER_HARM                4
#define RSUPV_DISP_DLIST_FILTER_PEAK                5

/* --- Display Trace Update ------------------------------------------------- */

#define RSUPV_DISP_TRACE_UPD_ALIV                   0
#define RSUPV_DISP_TRACE_UPD_HOLD                   1

/* --- Display Trace -------------------------------------------------------- */

#define RSUPV_TRACE_A                               0
#define RSUPV_TRACE_B                               1
#define RSUPV_X_AXIS                                2

/* --- Display Trace Update ------------------------------------------------- */

#define RSUPV_DISP_X_AXIS_TIME                      0
#define RSUPV_DISP_X_AXIS_VOLT                      1
#define RSUPV_DISP_X_AXIS_FREQ                      2
#define RSUPV_DISP_X_AXIS_PHAS                      3
#define RSUPV_DISP_X_AXIS_VDIG                      4
#define RSUPV_DISP_X_AXIS_JPK                       5

/* --- Display Trace Update ------------------------------------------------- */

#define RSUPV_DISP_X_SOURCE_SWEEP                   0
#define RSUPV_DISP_X_SOURCE_HOLD                    1
#define RSUPV_DISP_X_SOURCE_MAN                     2
#define RSUPV_DISP_X_SOURCE_LRMS                    3
#define RSUPV_DISP_X_SOURCE_LDC                     4
#define RSUPV_DISP_X_SOURCE_LPEAK                   5
#define RSUPV_DISP_X_SOURCE_FREQ                    6

/* --- Display Cursor Type -------------------------------------------------- */

#define RSUPV_DISP_CURS_TYPE_O                      0
#define RSUPV_DISP_CURS_TYPE_X                      1

/* --- Display Cursor Type -------------------------------------------------- */

#define RSUPV_DISP_CUR_STATE_OFF                    0
#define RSUPV_DISP_CUR_STATE_ACT                    1
#define RSUPV_DISP_CUR_STATE_INAC                   2

/* --- Display Cursor Type -------------------------------------------------- */

#define RSUPV_DISP_CUR_MODE_VA                      0
#define RSUPV_DISP_CUR_MODE_VB                      1
#define RSUPV_DISP_CUR_MODE_VAB                     2
#define RSUPV_DISP_CUR_MODE_HA                      3
#define RSUPV_DISP_CUR_MODE_HB                      4

/* --- Display Cursor Movement ---------------------------------------------- */

#define RSUPV_DISP_CUR_POSMODE_PIX                  0
#define RSUPV_DISP_CUR_POSMODE_POIN                 1
#define RSUPV_DISP_CUR_POSMODE_PEAK                 2
#define RSUPV_DISP_CUR_POSMODE_HARM                 3

/* --- Display Marker Mode -------------------------------------------------- */

#define RSUPV_DISP_MARKER_MODE_OFF                  0
#define RSUPV_DISP_MARKER_MODE_FIX                  1
#define RSUPV_DISP_MARKER_MODE_TRKM                 2

/* --- Display Store Trace As ----------------------------------------------- */

#define RSUPV_DISP_STORE_TRACE_AS_TRCLIST           0
#define RSUPV_DISP_STORE_TRACE_AS_EQULIST           1
#define RSUPV_DISP_STORE_TRACE_AS_SWPLIST           2
#define RSUPV_DISP_STORE_TRACE_AS_LLIST             3
#define RSUPV_DISP_STORE_TRACE_AS_DSELECT           4

/* --- Display Y-Axis Spacing ----------------------------------------------- */

#define RSUPV_DISP_SPAC_LIN                         0
#define RSUPV_DISP_SPAC_LOG                         1

/* --- Display X-Axis Scaling ----------------------------------------------- */

#define RSUPV_DISP_SCAL_AUTO                        0
#define RSUPV_DISP_SCAL_MAN                         1

/* --- Display Limit State -------------------------------------------------- */

#define RSUPV_DISP_LIM_UPP                          0
#define RSUPV_DISP_LIM_LOW                          1

/* --- Display Limit Source ------------------------------------------------- */

#define RSUPV_DISP_LIM_SRC_VAL                      0
#define RSUPV_DISP_LIM_SRC_FILE                     1
#define RSUPV_DISP_LIM_SRC_FINT                     2
#define RSUPV_DISP_LIM_SRC_HOLD                     3

/* --- Display Cursor Move To ----------------------------------------------- */

#define RSUPV_DISP_CURS_SET_TO_MAX                  0
#define RSUPV_DISP_CURS_SET_TO_MIN                  1
#define RSUPV_DISP_CURS_SET_TO_MRKA                 2
#define RSUPV_DISP_CURS_SET_TO_MRKB                 3

/* --- Display Y-Source ----------------------------------------------------- */

#define RSUPV_DISP_Y_SRC_OFF                        0
#define RSUPV_DISP_Y_SRC_FUNC1                      1
#define RSUPV_DISP_Y_SRC_FUNC2                      2
#define RSUPV_DISP_Y_SRC_FREQ1                      3
#define RSUPV_DISP_Y_SRC_FREQ2                      4
#define RSUPV_DISP_Y_SRC_LMRM1                      5
#define RSUPV_DISP_Y_SRC_LMRM2                      6
#define RSUPV_DISP_Y_SRC_LMDC1                      7
#define RSUPV_DISP_Y_SRC_LMDC2                      8
#define RSUPV_DISP_Y_SRC_LMPK1                      9
#define RSUPV_DISP_Y_SRC_LMPK2                      10
#define RSUPV_DISP_Y_SRC_INPP1                      11
#define RSUPV_DISP_Y_SRC_INPP2                      12
#define RSUPV_DISP_Y_SRC_PHAS                       13
#define RSUPV_DISP_Y_SRC_GRO                        14
#define RSUPV_DISP_Y_SRC_FILEA                      15
#define RSUPV_DISP_Y_SRC_FILEB                      16
#define RSUPV_DISP_Y_SRC_LEV1                       17
#define RSUPV_DISP_Y_SRC_LEV2                       18
#define RSUPV_DISP_Y_SRC_PHAS1                      19
#define RSUPV_DISP_Y_SRC_PHAS2                      20
#define RSUPV_DISP_Y_SRC_FFTL1                      21
#define RSUPV_DISP_Y_SRC_FFTL2                      22
#define RSUPV_DISP_Y_SRC_FFTP1                      23
#define RSUPV_DISP_Y_SRC_FFTP2                      24
#define RSUPV_DISP_Y_SRC_FFTP21                     25
#define RSUPV_DISP_Y_SRC_PEMO                       26
#define RSUPV_DISP_Y_SRC_DELAY                      27
#define RSUPV_DISP_Y_SRC_REF                        28
#define RSUPV_DISP_Y_SRC_DEG                        29
#define RSUPV_DISP_Y_SRC_DROP                       30

/* --- Display Multichannel Y-Source ---------------------------------------- */

#define RSUPV_DISP_Y_SRC_MULTI_FUNC                 1
#define RSUPV_DISP_Y_SRC_MULTI_FREQ                 2
#define RSUPV_DISP_Y_SRC_MULTI_LMRM                 3
#define RSUPV_DISP_Y_SRC_MULTI_LMDC                 4
#define RSUPV_DISP_Y_SRC_MULTI_LMPK                 5
#define RSUPV_DISP_Y_SRC_MULTI_INPP                 6
#define RSUPV_DISP_Y_SRC_MULTI_PHAS                 7
#define RSUPV_DISP_Y_SRC_MULTI_GRO                  8
#define RSUPV_DISP_Y_SRC_MULTI_FILEA                9
#define RSUPV_DISP_Y_SRC_MULTI_FILEB                10
#define RSUPV_DISP_Y_SRC_MULTI_FFTL                 11
#define RSUPV_DISP_Y_SRC_MULTI_FFTP                 12
#define RSUPV_DISP_Y_SRC_MULTI_FFTR                 13
#define RSUPV_DISP_Y_SRC_MULTI_LEV                  14

/* --- Display Reference ---------------------------------------------------- */

#define RSUPV_DISP_REF_MEAS                         0
#define RSUPV_DISP_REF_VAL                          1
#define RSUPV_DISP_REF_MAX                          2
#define RSUPV_DISP_REF_XCUR                         3
#define RSUPV_DISP_REF_OCUR                         4
#define RSUPV_DISP_REF_REF997                       5
#define RSUPV_DISP_REF_REF1000                      6
#define RSUPV_DISP_REF_CH1M                         7
#define RSUPV_DISP_REF_CH2M                         8
#define RSUPV_DISP_REF_GENT                         9
#define RSUPV_DISP_REF_FILE                         10
#define RSUPV_DISP_REF_IFL                          11
#define RSUPV_DISP_REF_HOLD                         12
#define RSUPV_DISP_REF_NOIS                         13

/* --- Display Normalization ------------------------------------------------ */

#define RSUPV_NORMALIZATION_OFF                     0
#define RSUPV_NORMALIZATION_VAL                     1
#define RSUPV_NORMALIZATION_OCUR                    2
#define RSUPV_NORMALIZATION_XCUR                    3

/* --- Measurement Control -------------------------------------------------- */

#define RSUPV_MEAS_START                            0
#define RSUPV_MEAS_STOP                             1
#define RSUPV_MEAS_SINGLE                           2
#define RSUPV_MEAS_CONT                             3

/* --- Data Set ------------------------------------------------------------- */

#define RSUPV_DATA_SET_AX                           0
#define RSUPV_DATA_SET_AY                           1
#define RSUPV_DATA_SET_BX                           2
#define RSUPV_DATA_SET_BY                           3

#define RSUPV_VAL_MAX                               0
#define RSUPV_VAL_MIN                               1

#define RSUPV_AXIS_X                                0
#define RSUPV_AXIS_Y                                1


/* --- Audio quality measurements (PEAQ) ------------------------------------ */
#define RSUPV_ANALYZER_PEAQ_MMODE_DUT 				0
#define RSUPV_ANALYZER_PEAQ_MMODE_OFFLINE			1

#define RSUPV_ANALYZER_PEAQ_MODEL_BAS				0
#define RSUPV_ANALYZER_PEAQ_MODEL_ADV				1


/* === UTILITIES ============================================================ */
#define RSUPV_WINSTYLE_UPV                          0
#define RSUPV_WINSTYLE_WINDOWS                      1

/* --- Free Buffers --------------------------------------------------------- */

#define RSUPV_MEM_FREE_STRING                       0
#define RSUPV_MEM_FREE_DATA                         1

/* --- Hardcopy Source ------------------------------------------------------ */

#define RSUPV_HCOPY_SOURCE_WINDOW                   0
#define RSUPV_HCOPY_SOURCE_GRAPHICS                 1

/* --- Hardcopy Destination ------------------------------------------------- */

#define RSUPV_HCOPY_DESTIN_PRINTER                  0
#define RSUPV_HCOPY_DESTIN_FILE                     1
#define RSUPV_HCOPY_DESTIN_CLIPBRD                  2

/* --- Hardcopy Orientation ------------------------------------------------- */

#define RSUPV_HCOPY_ORIENTATION_PORTRAIT            0
#define RSUPV_HCOPY_ORIENTATION_LANDSCAPE           1

/* --- Hardcopy Store Mode -------------------------------------------------- */

#define RSUPV_HCOPY_FILE_MODE_NEW                   0
#define RSUPV_HCOPY_FILE_MODE_OVERWRITE             1
#define RSUPV_HCOPY_FILE_MODE_INCREMENT             2

/* --- Refinement ------------------------------------------------------------ */

#define RSUPV_ANALYZER_REFINEMENT_N1   				0
#define RSUPV_ANALYZER_REFINEMENT_N2   				1
#define RSUPV_ANALYZER_REFINEMENT_N4   				2
#define RSUPV_ANALYZER_REFINEMENT_N8   				3

/* --- Color Depth ----------------------------------------------------------- */

#define RSUPV_GEN_HDMI_COLOR_DEPTH_08 	0
#define RSUPV_GEN_HDMI_COLOR_DEPTH_10 	1
#define RSUPV_GEN_HDMI_COLOR_DEPTH_12 	2


/* --- Content --------------------------------------------------------------- */

#define RSUPV_GEN_HDMI_VIDEO_CONTENT_MONOCHROME 0
#define RSUPV_GEN_HDMI_VIDEO_CONTENT_LIPSYNC    1
#define RSUPV_GEN_HDMI_VIDEO_CONTENT_BERT       2
#define RSUPV_GEN_HDMI_VIDEO_CONTENT_PATTERN    3

/* --- Sink ARC  --------------------------------------------------------------- */
 
#define RSUPV_GEN_HDMI_AUDIO_SINK_ARC_LOOPBACK 0
#define RSUPV_GEN_HDMI_AUDIO_SINK_ARC_DAGEN    1
 
/* --- Format Freq  ------------------------------------------------------------- */

#define RSUPV_GEN_HDMI_FORMAT_FREQ_23  0
#define RSUPV_GEN_HDMI_FORMAT_FREQ_24  1
#define RSUPV_GEN_HDMI_FORMAT_FREQ_25  2
#define RSUPV_GEN_HDMI_FORMAT_FREQ_29  3
#define RSUPV_GEN_HDMI_FORMAT_FREQ_30  4
#define RSUPV_GEN_HDMI_FORMAT_FREQ_50  5
#define RSUPV_GEN_HDMI_FORMAT_FREQ_59  6
#define RSUPV_GEN_HDMI_FORMAT_FREQ_60  7
#define RSUPV_GEN_HDMI_FORMAT_FREQ_100 8
#define RSUPV_GEN_HDMI_FORMAT_FREQ_119 9
#define RSUPV_GEN_HDMI_FORMAT_FREQ_120 10

/* --- Format Resolution  -------------------------------------------------------- */

#define RSUPV_GEN_HDMI_FORMAT_RESOL_P640x480_4x3  0
#define RSUPV_GEN_HDMI_FORMAT_RESOL_P720x576_4x3  1
#define RSUPV_GEN_HDMI_FORMAT_RESOL_P720x576_16x9 2
#define RSUPV_GEN_HDMI_FORMAT_RESOL_I720x576_4x3  3
#define RSUPV_GEN_HDMI_FORMAT_RESOL_I720x576_16x9 4
#define RSUPV_GEN_HDMI_FORMAT_RESOL_P720x480_4x3  5
#define RSUPV_GEN_HDMI_FORMAT_RESOL_P720x480_16x9 6
#define RSUPV_GEN_HDMI_FORMAT_RESOL_I720x480_4x3  7
#define RSUPV_GEN_HDMI_FORMAT_RESOL_I720x480_16x9 8
#define RSUPV_GEN_HDMI_FORMAT_RESOL_P1280x720_16x9 9
#define RSUPV_GEN_HDMI_FORMAT_RESOL_P1920x1080_16x9 10
#define RSUPV_GEN_HDMI_FORMAT_RESOL_I1920x1080_16x9 11


/* --- Video Source  ------------------------------------------------------------- */

#define RSUPV_GEN_HDMI_VIDEO_SOURCE_INTERN  0
#define RSUPV_GEN_HDMI_VIDEO_SOURCE_AUX_IN  01

/* --- Stereo Filter -------------------------------------------------------------- */

#define RSUPV_GEN_STEREO_FILTER_TRACK 0
#define RSUPV_GEN_STEREO_FILTER_SPLIT 1

/* --- Alignment ------------------------------------------------------------------ */ 

#define RSUPV_ANALYZER_DIG_AUD_ALIGMENT_RISING   	0
#define RSUPV_ANALYZER_DIG_AUD_ALIGMENT_FALLING  	1	
#define RSUPV_ANALYZER_DIG_AUD_ALIGMENT_CH1H_CH2L 	2
#define RSUPV_ANALYZER_DIG_AUD_ALIGMENT_CH1L_CH2H	3
#define RSUPV_ANALYZER_DIG_AUD_ALIGMENT_CH1R_CH2F 	4
#define RSUPV_ANALYZER_DIG_AUD_ALIGMENT_CH1F_CH2R 	5

/* --- Channel Mode----------------------------------------------------------------- */ 

#define RSUPV_ANALYZER_DIG_AUD_CH_MODE_MONO   	0
#define RSUPV_ANALYZER_DIG_AUD_CH_MODE_STEREO 	1

/* --- Clock Source----------------------------------------------------------------- */ 

#define RSUPV_ANALYZER_DIG_AUD_CH_CLK_SOURCE_INTERN 0
#define RSUPV_ANALYZER_DIG_AUD_CH_CLK_SOURCE_EXTERN 1

/* ---  Down-sampling Factor ------------------------------------------------------- */                

#define RSUPV_ANALYZER_DIG_AUD_DWNSMPL_FACTOR_M16   0
#define RSUPV_ANALYZER_DIG_AUD_DWNSMPL_FACTOR_M32   1
#define RSUPV_ANALYZER_DIG_AUD_DWNSMPL_FACTOR_M64   2
#define RSUPV_ANALYZER_DIG_AUD_DWNSMPL_FACTOR_M128  3
#define RSUPV_ANALYZER_DIG_AUD_DWNSMPL_FACTOR_M256  4

/* ---  Band------------------------------------------------------------------------ */                

#define RSUPV_ANALYZER_POLQA_BAND_NARROW 0
#define RSUPV_ANALYZER_POLQA_BAND_WIDE   1

/* ---  Measurement Mode ----------------------------------------------------------- */                

#define RSUPV_ANALYZER_POLQA_MMODE_DUT     0
#define RSUPV_ANALYZER_POLQA_MMODE_OFFLINE 1


/*****************************************************************************/
/*= GLOBAL USER-CALLABLE FUNCTION DECLARATIONS (Exportable Functions) =======*/
/*****************************************************************************/

ViStatus _VI_FUNC rsupv_init (ViRsrc resourceName, ViBoolean IDQuery,
                              ViBoolean resetDevice, ViPSession instrumentHandle);
ViStatus _VI_FUNC rsupv_SetGeneratorOutputState (ViSession instrumentHandle,
                                                 ViBoolean state);
ViStatus _VI_FUNC rsupv_GetGeneratorOutputState (ViSession instrumentHandle,
                                                 ViPBoolean state);
ViStatus _VI_FUNC rsupv_SetGeneratorInstrument (ViSession instrumentHandle,
                                                ViInt32 instrument);
ViStatus _VI_FUNC rsupv_GetGeneratorInstrument (ViSession instrumentHandle,
                                                ViPInt32 instrument);
ViStatus _VI_FUNC rsupv_ConfigureGeneratorAnalog (ViSession instrumentHandle,
                                                  ViInt32 channel,
                                                  ViInt32 outputType,
                                                  ViInt32 impedance, ViInt32 common,
                                                  ViInt32 bandwidth,
                                                  ViInt32 voltRange,
                                                  ViReal64 maxVoltage,
                                                  ViInt32 units);
ViStatus _VI_FUNC rsupv_SetGeneratorChannelMode (ViSession instrumentHandle,
                                                 ViInt32 channel);
ViStatus _VI_FUNC rsupv_GetGeneratorChannelMode (ViSession instrumentHandle,
                                                 ViPInt32 channel);
ViStatus _VI_FUNC rsupv_SetGeneratorOutputType (ViSession instrumentHandle,
                                                ViInt32 outputType);
ViStatus _VI_FUNC rsupv_GetGeneratorOutputType (ViSession instrumentHandle,
                                                ViPInt32 outputType);
ViStatus _VI_FUNC rsupv_SetGeneratorImpedance (ViSession instrumentHandle,
                                               ViInt32 impedance);
ViStatus _VI_FUNC rsupv_GetGeneratorImpedance (ViSession instrumentHandle,
                                               ViPInt32 impedance);
ViStatus _VI_FUNC rsupv_SetGeneratorCommon (ViSession instrumentHandle,
                                            ViInt32 common);
ViStatus _VI_FUNC rsupv_GetGeneratorCommon (ViSession instrumentHandle,
                                            ViPInt32 common);
ViStatus _VI_FUNC rsupv_SetGeneratorBandwidth (ViSession instrumentHandle,
                                               ViInt32 bandwidth);
ViStatus _VI_FUNC rsupv_GetGeneratorBandwidth (ViSession instrumentHandle,
                                               ViPInt32 bandwidth);
ViStatus _VI_FUNC rsupv_SetGeneratorVoltageRange (ViSession instrumentHandle,
                                                  ViInt32 voltRange);
ViStatus _VI_FUNC rsupv_GetGeneratorVoltageRange (ViSession instrumentHandle,
                                                  ViPInt32 voltRange);
ViStatus _VI_FUNC rsupv_SetGeneratorMaxVoltage (ViSession instrumentHandle,
                                                ViReal64 maxVoltage, ViInt32 units);
ViStatus _VI_FUNC rsupv_GetGeneratorMaxVoltage (ViSession instrumentHandle,
                                                ViPReal64 maxVoltage,
                                                ViPInt32 units);
ViStatus _VI_FUNC rsupv_ConfigureGeneratorDigital (ViSession instrumentHandle,
                                                   ViInt32 syncTo,
                                                   ViInt32 sampleFreq,
                                                   ViReal64 sampleFreqValue,
                                                   ViInt32 syncOutput,
                                                   ViReal64 intClkFreq,
                                                   ViInt32 syncOutType,
                                                   ViInt32 auxOutput);
ViStatus _VI_FUNC rsupv_ConfigureGeneratorDigitalAudioRefGen
             (ViSession instrumentHandle, ViInt32 refGenData, ViInt32 phaseToRef,
              ViReal64 framePhaseValue, ViInt32 units);
ViStatus _VI_FUNC rsupv_SetDigitalGeneratorSourceMode (ViSession instrumentHandle,
                                                       ViInt32 sourceMode);
ViStatus _VI_FUNC rsupv_GetDigitalGeneratorSourceMode (ViSession instrumentHandle,
                                                       ViPInt32 sourceMode);
ViStatus _VI_FUNC rsupv_SetDigitalGeneratorAddImpairment (ViSession instrumentHandle,
                                                          ViBoolean addImpairment);
ViStatus _VI_FUNC rsupv_GetDigitalGeneratorAddImpairment (ViSession instrumentHandle,
                                                          ViPBoolean addImpairment);
ViStatus _VI_FUNC rsupv_SetDigitalGeneratorChannelMode (ViSession instrumentHandle,
                                                        ViInt32 channel);
ViStatus _VI_FUNC rsupv_GetDigitalGeneratorChannelMode (ViSession instrumentHandle,
                                                        ViPInt32 channel);
ViStatus _VI_FUNC rsupv_SetDigitalGeneratorSyncTo (ViSession instrumentHandle,
                                                   ViInt32 syncTo);
ViStatus _VI_FUNC rsupv_GetDigitalGeneratorSyncTo (ViSession instrumentHandle,
                                                   ViPInt32 syncTo);
ViStatus _VI_FUNC rsupv_SetDigitalGeneratorSampleFrequency
             (ViSession instrumentHandle, ViInt32 sampleFrequency,
              ViReal64 variableSampleFrequency);
ViStatus _VI_FUNC rsupv_GetDigitalGeneratorSampleFrequency
             (ViSession instrumentHandle, ViPInt32 sampleFrequency,
              ViPReal64 variableSampleFrequency);
ViStatus _VI_FUNC rsupv_SetDigitalGeneratorSyncOutput (ViSession instrumentHandle,
                                                       ViInt32 syncOutput);
ViStatus _VI_FUNC rsupv_GetDigitalGeneratorSyncOutput (ViSession instrumentHandle,
                                                       ViPInt32 syncOutput);
ViStatus _VI_FUNC rsupv_SetDigitalGeneratorInternalClockFrequency
             (ViSession instrumentHandle, ViReal64 internalClockFrequency);
ViStatus _VI_FUNC rsupv_GetDigitalGeneratorInternalClockFrequency
             (ViSession instrumentHandle, ViPReal64 internalClockFrequency);
ViStatus _VI_FUNC rsupv_SetDigitalGeneratorSyncOutType (ViSession instrumentHandle,
                                                        ViInt32 syncOutputType);
ViStatus _VI_FUNC rsupv_GetDigitalGeneratorSyncOutType (ViSession instrumentHandle,
                                                        ViPInt32 syncOutputType);
ViStatus _VI_FUNC rsupv_SetDigitalGeneratorAuxOutput (ViSession instrumentHandle,
                                                      ViInt32 auxOutput);
ViStatus _VI_FUNC rsupv_GetDigitalGeneratorAuxOutput (ViSession instrumentHandle,
                                                      ViPInt32 auxOutput);
ViStatus _VI_FUNC rsupv_SetDigitalGeneratorAudioBits (ViSession instrumentHandle,
                                                      ViInt32 audioBits);
ViStatus _VI_FUNC rsupv_GetDigitalGeneratorAudioBits (ViSession instrumentHandle,
                                                      ViPInt32 audioBits);
ViStatus _VI_FUNC rsupv_SetDigitalGeneratorBalancedImpedance
             (ViSession instrumentHandle, ViInt32 balancedImpedance);
ViStatus _VI_FUNC rsupv_GetDigitalGeneratorBalancedImpedance
             (ViSession instrumentHandle, ViPInt32 balancedImpedance);
ViStatus _VI_FUNC rsupv_SetDigitalGeneratorUnbalancedImpedance
             (ViSession instrumentHandle, ViInt32 unbalancedImpedance);
ViStatus _VI_FUNC rsupv_GetDigitalGeneratorUnbalancedImpedance
             (ViSession instrumentHandle, ViPInt32 unbalancedImpedance);
ViStatus _VI_FUNC rsupv_SetDigitalGeneratorBalancedAmplitude
             (ViSession instrumentHandle, ViReal64 balancedAmplitude,
              ViInt32 units);
ViStatus _VI_FUNC rsupv_GetDigitalGeneratorBalancedAmplitude
             (ViSession instrumentHandle, ViPReal64 balancedAmplitude,
              ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetDigitalGeneratorUnbalancedAmplitude
             (ViSession instrumentHandle, ViReal64 unbalancedAmplitude,
              ViInt32 units);
ViStatus _VI_FUNC rsupv_GetDigitalGeneratorUnbalancedAmplitude
             (ViSession instrumentHandle, ViPReal64 unbalancedAmplitude,
              ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetDigitalGeneratorUnbalancedOutput
             (ViSession instrumentHandle, ViInt32 unbalancedOutput);
ViStatus _VI_FUNC rsupv_GetDigitalGeneratorUnbalancedOutput
             (ViSession instrumentHandle, ViPInt32 unbalancedOutput);
ViStatus _VI_FUNC rsupv_SetDigitalGeneratorCableSimulation
             (ViSession instrumentHandle, ViInt32 cableSimulation);
ViStatus _VI_FUNC rsupv_GetDigitalGeneratorCableSimulation
             (ViSession instrumentHandle, ViPInt32 cableSimulation);
ViStatus _VI_FUNC rsupv_SetDigitalGeneratorChannels (ViSession instrumentHandle,
                                                     ViInt32 measChannel,
                                                     ViBoolean genChannels);
ViStatus _VI_FUNC rsupv_GetDigitalGeneratorChannels (ViSession instrumentHandle,
                                                     ViInt32 measChannel,
                                                     ViPBoolean genChannels);
ViStatus _VI_FUNC rsupv_SetDigitalGeneratorRefGeneratorData
             (ViSession instrumentHandle, ViInt32 refGeneratorData);
ViStatus _VI_FUNC rsupv_GetDigitalGeneratorRefGeneratorData
             (ViSession instrumentHandle, ViPInt32 refGeneratorData);
ViStatus _VI_FUNC rsupv_SetDigitalGeneratorPhaseToRef (ViSession instrumentHandle,
                                                       ViInt32 phaseToRef);
ViStatus _VI_FUNC rsupv_GetDigitalGeneratorPhaseToRef (ViSession instrumentHandle,
                                                       ViPInt32 phaseToRef);
ViStatus _VI_FUNC rsupv_SetDigitalGeneratorFramePhase (ViSession instrumentHandle,
                                                       ViReal64 framePhase,
                                                       ViInt32 units);
ViStatus _VI_FUNC rsupv_GetDigitalGeneratorFramePhase (ViSession instrumentHandle,
                                                       ViPReal64 framePhase,
                                                       ViPInt32 units);
ViStatus _VI_FUNC rsupv_ConfigureGeneratorI2S (ViSession instrumentHandle,
                                               ViInt32 syncTo, ViInt32 wordLength,
                                               ViInt32 sampleFrequency,
                                               ViReal64 variableSampleFrequency,
                                               ViInt32 MClkRatio, ViInt32 audioBits,
                                               ViInt32 format, ViInt32 fsyncShape,
                                               ViInt32 fsyncPolarity,
                                               ViInt32 wordOffset);
ViStatus _VI_FUNC rsupv_SetI2SGeneratorSyncTo (ViSession instrumentHandle,
                                               ViInt32 syncTo);
ViStatus _VI_FUNC rsupv_GetI2SGeneratorSyncTo (ViSession instrumentHandle,
                                               ViPInt32 syncTo);
ViStatus _VI_FUNC rsupv_SetI2SGeneratorWordLength (ViSession instrumentHandle,
                                                   ViInt32 wordLength);
ViStatus _VI_FUNC rsupv_GetI2SGeneratorWordLength (ViSession instrumentHandle,
                                                   ViPInt32 wordLength);
ViStatus _VI_FUNC rsupv_SetI2SGeneratorSampleFrequency (ViSession instrumentHandle,
                                                        ViInt32 sampleFrequency,
                                                        ViReal64 variableSampleFrequency);
ViStatus _VI_FUNC rsupv_GetI2SGeneratorBClkFrequency (ViSession instrumentHandle,
                                                      ViPReal64 BClkFreq);
ViStatus _VI_FUNC rsupv_GetI2SGeneratorSampleFrequency (ViSession instrumentHandle,
                                                        ViPInt32 sampleFrequency,
                                                        ViPReal64 variableSampleFrequency);
ViStatus _VI_FUNC rsupv_SetI2SGeneratorMClkRatio (ViSession instrumentHandle,
                                                  ViInt32 MClkRatio);
ViStatus _VI_FUNC rsupv_GetI2SGeneratorMClkRatio (ViSession instrumentHandle,
                                                  ViPInt32 MClkRatio);
ViStatus _VI_FUNC rsupv_SetI2SGeneratorAudioBits (ViSession instrumentHandle,
                                                  ViInt32 audioBits);
ViStatus _VI_FUNC rsupv_GetI2SGeneratorAudioBits (ViSession instrumentHandle,
                                                  ViPInt32 audioBits);
ViStatus _VI_FUNC rsupv_SetI2SGeneratorFormat (ViSession instrumentHandle,
                                               ViInt32 format);
ViStatus _VI_FUNC rsupv_GetI2SGeneratorFormat (ViSession instrumentHandle,
                                               ViPInt32 format);
ViStatus _VI_FUNC rsupv_SetI2SGeneratorFsyncShape (ViSession instrumentHandle,
                                                   ViInt32 fsyncShape);
ViStatus _VI_FUNC rsupv_GetI2SGeneratorFsyncShape (ViSession instrumentHandle,
                                                   ViPInt32 fsyncShape);
ViStatus _VI_FUNC rsupv_SetI2SGeneratorFsyncPolarity (ViSession instrumentHandle,
                                                      ViInt32 fsyncPolarity);
ViStatus _VI_FUNC rsupv_GetI2SGeneratorFsyncPolarity (ViSession instrumentHandle,
                                                      ViPInt32 fsyncPolarity);
ViStatus _VI_FUNC rsupv_SetI2SGeneratorWordOffset (ViSession instrumentHandle,
                                                   ViInt32 wordOffset);
ViStatus _VI_FUNC rsupv_GetI2SGeneratorWordOffset (ViSession instrumentHandle,
                                                   ViPInt32 wordOffset);
ViStatus _VI_FUNC rsupv_ConfigureUSIGeneratorClockAndFrequency
             (ViSession instrumentHandle, ViInt32 clock,
              ViBoolean mixedSamplingFrequency, ViInt32 ratio);
ViStatus _VI_FUNC rsupv_ConfigureUSIGeneratorFrame (ViSession instrumentHandle,
                                                    ViInt32 samples,
                                                    ViInt32 numberOfSlots);
ViStatus _VI_FUNC rsupv_SetUSIGeneratorTxData (ViSession instrumentHandle,
                                               ViInt32 dataLine,
                                               ViString signalType);
ViStatus _VI_FUNC rsupv_SetUSIGeneratorSyncTo (ViSession instrumentHandle,
                                               ViInt32 syncTo);
ViStatus _VI_FUNC rsupv_ConfigureUSIGeneratorSlot (ViSession instrumentHandle,
                                                   ViInt32 firstBit,
                                                   ViInt32 slotLength,
                                                   ViInt32 audioBits,
                                                   ViInt32 leadBits);
ViStatus _VI_FUNC rsupv_SetUSIGeneratorSampleFrequency (ViSession instrumentHandle,
                                                        ViInt32 sampleFrequency,
                                                        ViReal64 variableSampleFrequency,
                                                        ViInt32 units);
ViStatus _VI_FUNC rsupv_ConfigureUSIGeneratorFsync (ViSession instrumentHandle,
                                                    ViInt32 fsyncWidth,
                                                    ViInt32 variableFsyncWidth,
                                                    ViInt32 fsyncOffset,
                                                    ViInt32 fsyncSlope);
ViStatus _VI_FUNC rsupv_ConfigureUSIGeneratorSlClk (ViSession instrumentHandle,
                                                    ViInt32 slClkWidth,
                                                    ViInt32 variableSlClkWidth,
                                                    ViInt32 slClkOffset,
                                                    ViInt32 slClkSlope);
ViStatus _VI_FUNC rsupv_ConfigureUSIGeneratorJitter (ViSession instrumentHandle,
                                                     ViReal64 BClkJitterFrequency,
                                                     ViReal64 BClkJitterAmplitude,
                                                     ViReal64 MClkJitterFrequency,
                                                     ViReal64 MClkJitterAmplitude);
ViStatus _VI_FUNC rsupv_USIGeneratorResync (ViSession instrumentHandle);
ViStatus _VI_FUNC rsupv_SetUSIGeneratorClock (ViSession instrumentHandle,
                                              ViInt32 clock);
ViStatus _VI_FUNC rsupv_GetUSIGeneratorClock (ViSession instrumentHandle,
                                              ViPInt32 clock);
ViStatus _VI_FUNC rsupv_SetUSIGeneratorMixedSamplingFrequencyState
             (ViSession instrumentHandle, ViBoolean mixedSamplingFrequency);
ViStatus _VI_FUNC rsupv_GetUSIGeneratorMixedSamplingFrequencyState
             (ViSession instrumentHandle, ViPBoolean mixedSamplingFrequency);
ViStatus _VI_FUNC rsupv_SetUSIGeneratorRatio (ViSession instrumentHandle,
                                              ViInt32 ratio);
ViStatus _VI_FUNC rsupv_GetUSIGeneratorRatio (ViSession instrumentHandle,
                                              ViPInt32 ratio);
ViStatus _VI_FUNC rsupv_SetUSIGeneratorSamplesPerFrame (ViSession instrumentHandle,
                                                        ViInt32 samples);
ViStatus _VI_FUNC rsupv_GetUSIGeneratorSamplesPerFrame (ViSession instrumentHandle,
                                                        ViPInt32 samples);
ViStatus _VI_FUNC rsupv_SetUSIGeneratorNumberOfSlots (ViSession instrumentHandle,
                                                      ViInt32 numberOfSlots);
ViStatus _VI_FUNC rsupv_GetUSIGeneratorNumberOfSlots (ViSession instrumentHandle,
                                                      ViPInt32 numberOfSlots);
ViStatus _VI_FUNC rsupv_GetUSIGeneratorTxData (ViSession instrumentHandle,
                                               ViInt32 dataLine, ViInt32 arraySize,
                                               ViChar _VI_FAR signalType[]);
ViStatus _VI_FUNC rsupv_GetUSIGeneratorSyncTo (ViSession instrumentHandle,
                                               ViPInt32 syncTo);
ViStatus _VI_FUNC rsupv_SetUSIGeneratorFirstBit (ViSession instrumentHandle,
                                                 ViInt32 firstBit);
ViStatus _VI_FUNC rsupv_GetUSIGeneratorFirstBit (ViSession instrumentHandle,
                                                 ViPInt32 firstBit);
ViStatus _VI_FUNC rsupv_SetUSIGeneratorSlotLength (ViSession instrumentHandle,
                                                   ViInt32 slotLength);
ViStatus _VI_FUNC rsupv_GetUSIGeneratorSlotLength (ViSession instrumentHandle,
                                                   ViPInt32 slotLength);
ViStatus _VI_FUNC rsupv_SetUSIGeneratorAudioBits (ViSession instrumentHandle,
                                                  ViInt32 audioBits);
ViStatus _VI_FUNC rsupv_GetUSIGeneratorAudioBits (ViSession instrumentHandle,
                                                  ViPInt32 audioBits);
ViStatus _VI_FUNC rsupv_SetUSIGeneratorLeadBits (ViSession instrumentHandle,
                                                 ViInt32 leadBits);
ViStatus _VI_FUNC rsupv_GetUSIGeneratorLeadBits (ViSession instrumentHandle,
                                                 ViPInt32 leadBits);
ViStatus _VI_FUNC rsupv_GetUSIGeneratorSampleFrequency (ViSession instrumentHandle,
                                                        ViPInt32 sampleFrequency,
                                                        ViPReal64 variableSampleFrequency,
                                                        ViPInt32 units);
ViStatus _VI_FUNC rsupv_GetUSIGeneratorFsyncFrequency (ViSession instrumentHandle,
                                                       ViPReal64 fsyncFrequency);
ViStatus _VI_FUNC rsupv_GetUSIGeneratorBClkFrequency (ViSession instrumentHandle,
                                                      ViPReal64 BClkFrequency);
ViStatus _VI_FUNC rsupv_SetUSIGeneratorFsyncWidth (ViSession instrumentHandle,
                                                   ViInt32 fsyncWidth,
                                                   ViInt32 variableFsyncWidth);
ViStatus _VI_FUNC rsupv_GetUSIGeneratorFsyncWidth (ViSession instrumentHandle,
                                                   ViPInt32 fsyncWidth,
                                                   ViPInt32 variableFsyncWidth);
ViStatus _VI_FUNC rsupv_SetUSIGeneratorFsyncOffset (ViSession instrumentHandle,
                                                    ViInt32 fsyncOffset);
ViStatus _VI_FUNC rsupv_GetUSIGeneratorFsyncOffset (ViSession instrumentHandle,
                                                    ViPInt32 fsyncOffset);
ViStatus _VI_FUNC rsupv_SetUSIGeneratorFsyncSlope (ViSession instrumentHandle,
                                                   ViInt32 fsyncSlope);
ViStatus _VI_FUNC rsupv_GetUSIGeneratorFsyncSlope (ViSession instrumentHandle,
                                                   ViPInt32 fsyncSlope);
ViStatus _VI_FUNC rsupv_SetUSIGeneratorBClkSlope (ViSession instrumentHandle,
                                                  ViInt32 BClkSlope);
ViStatus _VI_FUNC rsupv_GetUSIGeneratorBClkSlope (ViSession instrumentHandle,
                                                  ViPInt32 BClkSlope);
ViStatus _VI_FUNC rsupv_SetUSIGeneratorSlClkWidth (ViSession instrumentHandle,
                                                   ViInt32 slClkWidth,
                                                   ViInt32 variableSlClkWidth);
ViStatus _VI_FUNC rsupv_GetUSIGeneratorSlClkWidth (ViSession instrumentHandle,
                                                   ViPInt32 slClkWidth,
                                                   ViPInt32 variableSlClkWidth);
ViStatus _VI_FUNC rsupv_SetUSIGeneratorSlClkOffset (ViSession instrumentHandle,
                                                    ViInt32 slClkOffset);
ViStatus _VI_FUNC rsupv_GetUSIGeneratorSlClkOffset (ViSession instrumentHandle,
                                                    ViPInt32 slClkOffset);
ViStatus _VI_FUNC rsupv_SetUSIGeneratorSlClkSlope (ViSession instrumentHandle,
                                                   ViInt32 slClkSlope);
ViStatus _VI_FUNC rsupv_GetUSIGeneratorSlClkSlope (ViSession instrumentHandle,
                                                   ViPInt32 slClkSlope);
ViStatus _VI_FUNC rsupv_SetUSIGeneratorMClkRatio (ViSession instrumentHandle,
                                                  ViInt32 ratio);
ViStatus _VI_FUNC rsupv_GetUSIGeneratorMClkRatio (ViSession instrumentHandle,
                                                  ViPInt32 ratio);
ViStatus _VI_FUNC rsupv_SetUSIGeneratorBClkJitterFrequency
             (ViSession instrumentHandle, ViReal64 BClkJitterFrequency);
ViStatus _VI_FUNC rsupv_GetUSIGeneratorBClkJitterFrequency
             (ViSession instrumentHandle, ViPReal64 BClkJitterFrequency);
ViStatus _VI_FUNC rsupv_SetUSIGeneratorBClkJitterAmplitude
             (ViSession instrumentHandle, ViReal64 BClkJitterAmplitude);
ViStatus _VI_FUNC rsupv_GetUSIGeneratorBClkJitterAmplitude
             (ViSession instrumentHandle, ViPReal64 BClkJitterAmplitude);
ViStatus _VI_FUNC rsupv_SetUSIGeneratorMClkJitterFrequency
             (ViSession instrumentHandle, ViReal64 MClkJitterFrequency);
ViStatus _VI_FUNC rsupv_GetUSIGeneratorMClkJitterFrequency
             (ViSession instrumentHandle, ViPReal64 MClkJitterFrequency);
ViStatus _VI_FUNC rsupv_SetUSIGeneratorMClkJitterAmplitude
             (ViSession instrumentHandle, ViReal64 MClkJitterAmplitude);
ViStatus _VI_FUNC rsupv_GetUSIGeneratorMClkJitterAmplitude
             (ViSession instrumentHandle, ViPReal64 MClkJitterAmplitude);
ViStatus _VI_FUNC rsupv_SetUSIGeneratorLogicVoltage (ViSession instrumentHandle,
                                                     ViInt32 logicVoltage);
ViStatus _VI_FUNC rsupv_GetUSIGeneratorLogicVoltage (ViSession instrumentHandle,
                                                     ViPInt32 logicVoltage);
ViStatus _VI_FUNC rsupv_SetUSIGeneratorCoding (ViSession instrumentHandle,
                                               ViInt32 coding);
ViStatus _VI_FUNC rsupv_GetUSIGeneratorCoding (ViSession instrumentHandle,
                                               ViPInt32 coding);
ViStatus _VI_FUNC rsupv_ConfigureHDMIGeneratorAudio (ViSession instrumentHandle,
                                                     ViInt32 audioFormat,
                                                     ViInt32 channel,
                                                     ViInt32 syncTo,
                                                     ViInt32 sampleFrequency,
                                                     ViReal64 variableSampleFrequency);
ViStatus _VI_FUNC rsupv_ConfigureHDMIGeneratorVideo (ViSession instrumentHandle,
                                                     ViInt32 source,
                                                     ViInt32 formatResolution,
                                                     ViInt32 formatFrequency,
                                                     ViInt32 colorDepth);
ViStatus _VI_FUNC rsupv_GetHDMIGeneratorVideoFormatNo (ViSession instrumentHandle,
                                                       ViInt32 bufferSize,
                                                       ViChar _VI_FAR formatNo[]);
ViStatus _VI_FUNC rsupv_SetHDMIGeneratorVideoColorDepth (ViSession instrumentHandle,
                                                         ViInt32 colorDepth);
ViStatus _VI_FUNC rsupv_GetHDMIGeneratorVideoColorDepth (ViSession instrumentHandle,
                                                         ViPInt32 colorDepth);
ViStatus _VI_FUNC rsupv_SetHDMIGeneratorVideoContent (ViSession instrumentHandle,
                                                      ViInt32 content);
ViStatus _VI_FUNC rsupv_GetHDMIGeneratorVideoContent (ViSession instrumentHandle,
                                                      ViPInt32 content);
ViStatus _VI_FUNC rsupv_GetHDMIGeneratorVideoColorString (ViSession instrumentHandle,
                                                          ViInt32 bufferSize,
                                                          ViChar _VI_FAR colorString[]);
ViStatus _VI_FUNC rsupv_GetHDMIGeneratorVideoAVI (ViSession instrumentHandle,
                                                  ViInt32 bufferSize,
                                                  ViChar _VI_FAR AVI[]);
ViStatus _VI_FUNC rsupv_GetHDMIGeneratorVideoSPD (ViSession instrumentHandle,
                                                  ViInt32 bufferSize,
                                                  ViChar _VI_FAR SPD[]);
ViStatus _VI_FUNC rsupv_GetHDMIGeneratorVideoEEDID (ViSession instrumentHandle,
                                                    ViInt32 bufferSize,
                                                    ViChar _VI_FAR eEDID[]);
ViStatus _VI_FUNC rsupv_GetHDMIGeneratorVideoCEC (ViSession instrumentHandle,
                                                  ViInt32 bufferSize,
                                                  ViChar _VI_FAR CEC[]);
ViStatus _VI_FUNC rsupv_SetHDMIGeneratorVideoFormatResolution
             (ViSession instrumentHandle, ViInt32 formatResolution);
ViStatus _VI_FUNC rsupv_GetHDMIGeneratorVideoFormatResolution
             (ViSession instrumentHandle, ViPInt32 formatResolution);
ViStatus _VI_FUNC rsupv_SetHDMIGeneratorVideoFormatFrequency
             (ViSession instrumentHandle, ViInt32 formatFrequency);
ViStatus _VI_FUNC rsupv_GetHDMIGeneratorVideoFormatFrequency
             (ViSession instrumentHandle, ViPInt32 formatFrequency);
ViStatus _VI_FUNC rsupv_SetHDMIGeneratorVideoSource (ViSession instrumentHandle,
                                                     ViInt32 source);
ViStatus _VI_FUNC rsupv_GetHDMIGeneratorVideoSource (ViSession instrumentHandle,
                                                     ViPInt32 source);
ViStatus _VI_FUNC rsupv_SetHDMIGeneratorAudioFormat (ViSession instrumentHandle,
                                                     ViInt32 audioFormat);
ViStatus _VI_FUNC rsupv_GetHDMIGeneratorAudioFormat (ViSession instrumentHandle,
                                                     ViPInt32 audioFormat);
ViStatus _VI_FUNC rsupv_SetHDMIGeneratorAudioSinkARC (ViSession instrumentHandle,
                                                      ViInt32 sinkARC);
ViStatus _VI_FUNC rsupv_GetHDMIGeneratorAudioSinkARC (ViSession instrumentHandle,
                                                      ViPInt32 sinkARC);
ViStatus _VI_FUNC rsupv_GetHDMIGeneratorAudioInfoFrame (ViSession instrumentHandle,
                                                        ViInt32 bufferSize,
                                                        ViChar _VI_FAR audioInfoFrame[]);
ViStatus _VI_FUNC rsupv_SetHDMIGeneratorChannelsMode (ViSession instrumentHandle,
                                                      ViInt32 measChannel,
                                                      ViBoolean genChannels);
ViStatus _VI_FUNC rsupv_GetHDMIGeneratorChannelsMode (ViSession instrumentHandle,
                                                      ViInt32 measChannel,
                                                      ViPBoolean genChannels);
ViStatus _VI_FUNC rsupv_ConfigureGeneratorReference (ViSession instrumentHandle,
                                                     ViReal64 refVoltage,
                                                     ViInt32 voltageUnits,
                                                     ViReal64 refFrequency,
                                                     ViInt32 frequencyUnits);
ViStatus _VI_FUNC rsupv_SetGeneratorRefVoltage (ViSession instrumentHandle,
                                                ViReal64 refVoltage, ViInt32 units);
ViStatus _VI_FUNC rsupv_GetGeneratorRefVoltage (ViSession instrumentHandle,
                                                ViPReal64 refVoltage,
                                                ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetGeneratorRefFrequency (ViSession instrumentHandle,
                                                  ViReal64 refFrequency,
                                                  ViInt32 units);
ViStatus _VI_FUNC rsupv_GetGeneratorRefFrequency (ViSession instrumentHandle,
                                                  ViPReal64 refFrequency,
                                                  ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetGeneratorFrequency (ViSession instrumentHandle,
                                               ViInt32 channel, ViReal64 frequency,
                                               ViInt32 units);
ViStatus _VI_FUNC rsupv_GetGeneratorFrequency (ViSession instrumentHandle,
                                               ViInt32 channel, ViPReal64 frequency,
                                               ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetGeneratorVoltage (ViSession instrumentHandle,
                                             ViInt32 channel, ViReal64 voltage,
                                             ViInt32 units);
ViStatus _VI_FUNC rsupv_GetGeneratorVoltage (ViSession instrumentHandle,
                                             ViInt32 channel, ViPReal64 voltage,
                                             ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetGeneratorTotalVoltage (ViSession instrumentHandle,
                                                  ViReal64 voltageValue,
                                                  ViInt32 units);
ViStatus _VI_FUNC rsupv_GetGeneratorTotalVoltage (ViSession instrumentHandle,
                                                  ViPReal64 voltageValue,
                                                  ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetGeneratorVoltageRMS (ViSession instrumentHandle,
                                                ViReal64 voltageRMS, ViInt32 units);
ViStatus _VI_FUNC rsupv_GetGeneratorVoltageRMS (ViSession instrumentHandle,
                                                ViPReal64 voltageRMS,
                                                ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetGeneratorCrestFactor (ViSession instrumentHandle,
                                                 ViInt32 crestFactor);
ViStatus _VI_FUNC rsupv_GetGeneratorCrestFactor (ViSession instrumentHandle,
                                                 ViPInt32 crestFactor);
ViStatus _VI_FUNC rsupv_SetGeneratorCrestFactorValue (ViSession instrumentHandle,
                                                      ViReal64 crestFactor);
ViStatus _VI_FUNC rsupv_GetGeneratorCrestFactorValue (ViSession instrumentHandle,
                                                      ViPReal64 crestFactor);
ViStatus _VI_FUNC rsupv_SetGeneratorDCOffset (ViSession instrumentHandle,
                                              ViBoolean DCOffset);
ViStatus _VI_FUNC rsupv_GetGeneratorDCOffset (ViSession instrumentHandle,
                                              ViPBoolean DCOffset);
ViStatus _VI_FUNC rsupv_SetGeneratorDCOffsetValue (ViSession instrumentHandle,
                                                   ViReal64 DCOffset,
                                                   ViInt32 units);
ViStatus _VI_FUNC rsupv_GetGeneratorDCOffsetValue (ViSession instrumentHandle,
                                                   ViPReal64 DCOffset,
                                                   ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetGeneratorDCOffsetChannelValue (ViSession instrumentHandle,
                                                          ViInt32 channel,
                                                          ViReal64 DCOffset,
                                                          ViInt32 units);
ViStatus _VI_FUNC rsupv_GetGeneratorDCOffsetChannelValue (ViSession instrumentHandle,
                                                          ViInt32 channel,
                                                          ViPReal64 DCOffset,
                                                          ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetGeneratorDCOffsetCoupling (ViSession instrumentHandle,
                                                      ViInt32 DCOffset);
ViStatus _VI_FUNC rsupv_GetGeneratorDCOffsetCoupling (ViSession instrumentHandle,
                                                      ViPInt32 DCOffset);
ViStatus _VI_FUNC rsupv_SetGeneratorSweepCtrl (ViSession instrumentHandle,
                                               ViInt32 sweepCtrl);
ViStatus _VI_FUNC rsupv_GetGeneratorSweepCtrl (ViSession instrumentHandle,
                                               ViPInt32 sweepCtrl);
ViStatus _VI_FUNC rsupv_SetGeneratorSweepNextStep (ViSession instrumentHandle,
                                                   ViInt32 nextStep);
ViStatus _VI_FUNC rsupv_GetGeneratorSweepNextStep (ViSession instrumentHandle,
                                                   ViPInt32 nextStep);
ViStatus _VI_FUNC rsupv_SetGeneratorSweepDwellTime (ViSession instrumentHandle,
                                                    ViReal64 dwell, ViInt32 units);
ViStatus _VI_FUNC rsupv_GetGeneratorSweepDwellTime (ViSession instrumentHandle,
                                                    ViPReal64 dwell,
                                                    ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetGeneratorSweepDwellFile (ViSession instrumentHandle,
                                                    ViString dwellFile);
ViStatus _VI_FUNC rsupv_SetGeneratorSweepXAxis (ViSession instrumentHandle,
                                                ViInt32 xAxis);
ViStatus _VI_FUNC rsupv_GetGeneratorSweepXAxis (ViSession instrumentHandle,
                                                ViPInt32 xAxis);
ViStatus _VI_FUNC rsupv_SetGeneratorSweepZAxis (ViSession instrumentHandle,
                                                ViInt32 zAxis);
ViStatus _VI_FUNC rsupv_GetGeneratorSweepZAxis (ViSession instrumentHandle,
                                                ViPInt32 zAxis);
ViStatus _VI_FUNC rsupv_SetGeneratorSweepHalt (ViSession instrumentHandle,
                                               ViInt32 axis, ViInt32 halt,
                                               ViReal64 haltValue, ViInt32 units);
ViStatus _VI_FUNC rsupv_GetGeneratorSweepHalt (ViSession instrumentHandle,
                                               ViInt32 axis, ViPInt32 halt,
                                               ViPReal64 haltValue, ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetGeneratorSweepSpacing (ViSession instrumentHandle,
                                                  ViInt32 axis, ViInt32 spacing);
ViStatus _VI_FUNC rsupv_GetGeneratorSweepSpacing (ViSession instrumentHandle,
                                                  ViInt32 axis, ViPInt32 spacing);
ViStatus _VI_FUNC rsupv_SetGeneratorSweepStart (ViSession instrumentHandle,
                                                ViInt32 axis, ViReal64 start,
                                                ViInt32 units);
ViStatus _VI_FUNC rsupv_GetGeneratorSweepStart (ViSession instrumentHandle,
                                                ViInt32 axis, ViPReal64 start,
                                                ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetGeneratorSweepStop (ViSession instrumentHandle,
                                               ViInt32 axis, ViReal64 stop,
                                               ViInt32 units);
ViStatus _VI_FUNC rsupv_GetGeneratorSweepStop (ViSession instrumentHandle,
                                               ViInt32 axis, ViPReal64 stop,
                                               ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetGeneratorSweepPoints (ViSession instrumentHandle,
                                                 ViInt32 axis, ViInt32 points);
ViStatus _VI_FUNC rsupv_GetGeneratorSweepPoints (ViSession instrumentHandle,
                                                 ViInt32 axis, ViPInt32 points);
ViStatus _VI_FUNC rsupv_SetGeneratorSweepSteps (ViSession instrumentHandle,
                                                ViInt32 axis, ViReal64 steps,
                                                ViInt32 units);
ViStatus _VI_FUNC rsupv_GetGeneratorSweepSteps (ViSession instrumentHandle,
                                                ViInt32 axis, ViPReal64 steps,
                                                ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetGeneratorTotVoltFile (ViSession instrumentHandle,
                                                 ViString voltFile);
ViStatus _VI_FUNC rsupv_SetGeneratorFreqFile (ViSession instrumentHandle,
                                              ViString freqFile);
ViStatus _VI_FUNC rsupv_SetGeneratorPhaseFile (ViSession instrumentHandle,
                                               ViString phaseFile);
ViStatus _VI_FUNC rsupv_SetGeneratorOnTimeFile (ViSession instrumentHandle,
                                                ViString onTimeFile);
ViStatus _VI_FUNC rsupv_SetGeneratorIntervalFile (ViSession instrumentHandle,
                                                  ViString intervalFile);
ViStatus _VI_FUNC rsupv_SetGeneratorFilter (ViSession instrumentHandle,
                                            ViInt32 filter);
ViStatus _VI_FUNC rsupv_GetGeneratorFilter (ViSession instrumentHandle,
                                            ViPInt32 filter);
ViStatus _VI_FUNC rsupv_SetGeneratorEqualizer (ViSession instrumentHandle,
                                               ViBoolean equalizer);
ViStatus _VI_FUNC rsupv_GetGeneratorEqualizer (ViSession instrumentHandle,
                                               ViPBoolean equalizer);
ViStatus _VI_FUNC rsupv_SetGeneratorEqualizerFile (ViSession instrumentHandle,
                                                   ViString equalizerFile);
ViStatus _VI_FUNC rsupv_SetGeneratorEqualizerCoupling (ViSession instrumentHandle,
                                                       ViInt32 equalizer);
ViStatus _VI_FUNC rsupv_GetGeneratorEqualizerCoupling (ViSession instrumentHandle,
                                                       ViPInt32 equalizer);
ViStatus _VI_FUNC rsupv_SetGeneratorFunction (ViSession instrumentHandle,
                                              ViInt32 generatorFunction);
ViStatus _VI_FUNC rsupv_GetGeneratorFunction (ViSession instrumentHandle,
                                              ViPInt32 generatorFunction);
ViStatus _VI_FUNC rsupv_SetGeneratorSineLowDistortion (ViSession instrumentHandle,
                                                       ViBoolean lowDistortion);
ViStatus _VI_FUNC rsupv_GetGeneratorSineLowDistortion (ViSession instrumentHandle,
                                                       ViPBoolean lowDistortion);
ViStatus _VI_FUNC rsupv_SetGeneratorStereoFrequencyMode (ViSession instrumentHandle,
                                                         ViInt32 frequencyMode);
ViStatus _VI_FUNC rsupv_GetGeneratorStereoFrequencyMode (ViSession instrumentHandle,
                                                         ViPInt32 frequencyMode);
ViStatus _VI_FUNC rsupv_SetGeneratorStereoVoltageMode (ViSession instrumentHandle,
                                                       ViInt32 voltageMode);
ViStatus _VI_FUNC rsupv_GetGeneratorStereoVoltageMode (ViSession instrumentHandle,
                                                       ViPInt32 voltageMode);
ViStatus _VI_FUNC rsupv_SetGeneratorStereoFrequencyCh2 (ViSession instrumentHandle,
                                                        ViReal64 frequencyCh2,
                                                        ViInt32 units);
ViStatus _VI_FUNC rsupv_GetGeneratorStereoFrequencyCh2 (ViSession instrumentHandle,
                                                        ViPReal64 frequencyCh2,
                                                        ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetGeneratorStereoVoltageCh2 (ViSession instrumentHandle,
                                                      ViReal64 voltageCh2,
                                                      ViInt32 units);
ViStatus _VI_FUNC rsupv_GetGeneratorStereoVoltageCh2 (ViSession instrumentHandle,
                                                      ViPReal64 voltageCh2,
                                                      ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetGeneratorStereoChannelFilterCoupling
             (ViSession instrumentHandle, ViInt32 filter);
ViStatus _VI_FUNC rsupv_GetGeneratorStereoChannelFilterCoupling
             (ViSession instrumentHandle, ViPInt32 filter);
ViStatus _VI_FUNC rsupv_SetGeneratorStereoChannelFilter (ViSession instrumentHandle,
                                                         ViInt32 filter);
ViStatus _VI_FUNC rsupv_GetGeneratorStereoChannelFilter (ViSession instrumentHandle,
                                                         ViPInt32 filter);
ViStatus _VI_FUNC rsupv_SetGeneratorStereoEqualizer (ViSession instrumentHandle,
                                                     ViBoolean equalizer);
ViStatus _VI_FUNC rsupv_GetGeneratorStereoEqualizer (ViSession instrumentHandle,
                                                     ViPBoolean equalizer);
ViStatus _VI_FUNC rsupv_SetGeneratorStereoEqualizerFile (ViSession instrumentHandle,
                                                         ViString equalFile);
ViStatus _VI_FUNC rsupv_SetGeneratorMultisineNoOfSine (ViSession instrumentHandle,
                                                       ViInt32 noOfSine);
ViStatus _VI_FUNC rsupv_GetGeneratorMultisineNoOfSine (ViSession instrumentHandle,
                                                       ViPInt32 noOfSine);
ViStatus _VI_FUNC rsupv_SetGeneratorMultisinePhaseNoi (ViSession instrumentHandle,
                                                       ViInt32 number,
                                                       ViReal64 phaseNoI,
                                                       ViInt32 units);
ViStatus _VI_FUNC rsupv_GetGeneratorMultisinePhaseNoi (ViSession instrumentHandle,
                                                       ViInt32 number,
                                                       ViPReal64 phaseNoI,
                                                       ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetGeneratorMultisineTotalGain (ViSession instrumentHandle,
                                                        ViReal64 totalGain);
ViStatus _VI_FUNC rsupv_GetGeneratorMultisineTotalGain (ViSession instrumentHandle,
                                                        ViPReal64 totalGain);
ViStatus _VI_FUNC rsupv_SetGeneratorSineBurstLowLevel (ViSession instrumentHandle,
                                                       ViReal64 lowLevel,
                                                       ViInt32 units);
ViStatus _VI_FUNC rsupv_GetGeneratorSineBurstLowLevel (ViSession instrumentHandle,
                                                       ViPReal64 lowLevel,
                                                       ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetGeneratorSineBurstOnTime (ViSession instrumentHandle,
                                                     ViReal64 onTime,
                                                     ViInt32 units);
ViStatus _VI_FUNC rsupv_GetGeneratorSineBurstOnTime (ViSession instrumentHandle,
                                                     ViPReal64 onTime,
                                                     ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetGeneratorSineBurstInterval (ViSession instrumentHandle,
                                                       ViReal64 interval,
                                                       ViInt32 units);
ViStatus _VI_FUNC rsupv_GetGeneratorSineBurstInterval (ViSession instrumentHandle,
                                                       ViPReal64 interval,
                                                       ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetGeneratorSineBurstOnDelay (ViSession instrumentHandle,
                                                      ViReal64 burstOnDelay,
                                                      ViInt32 units);
ViStatus _VI_FUNC rsupv_GetGeneratorSineBurstOnDelay (ViSession instrumentHandle,
                                                      ViPReal64 burstOnDelay,
                                                      ViPInt32 units);
ViStatus _VI_FUNC rsupv_ConfigureGeneratorModDist (ViSession instrumentHandle,
                                                   ViReal64 upperFreq,
                                                   ViInt32 upperFreqUnits,
                                                   ViReal64 lowerFreq,
                                                   ViInt32 lowerFreqUnits,
                                                   ViReal64 voltCh21,
                                                   ViReal64 totalVoltage,
                                                   ViInt32 voltageUnits);
ViStatus _VI_FUNC rsupv_SetGeneratorModDistUpperFrequency
             (ViSession instrumentHandle, ViReal64 upperFrequency, ViInt32 units);
ViStatus _VI_FUNC rsupv_GetGeneratorModDistUpperFrequency
             (ViSession instrumentHandle, ViPReal64 upperFrequency, ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetGeneratorModDistLowerFrequency
             (ViSession instrumentHandle, ViReal64 lowerFrequency, ViInt32 units);
ViStatus _VI_FUNC rsupv_GetGeneratorModDistLowerFrequency
             (ViSession instrumentHandle, ViPReal64 lowerFrequency, ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetGeneratorModDistLevelRatio (ViSession instrumentHandle,
                                                       ViReal64 voltageLFUF);
ViStatus _VI_FUNC rsupv_GetGeneratorModDistLevelRatio (ViSession instrumentHandle,
                                                       ViPReal64 voltageLFUF);
ViStatus _VI_FUNC rsupv_ConfigureGeneratorDFD (ViSession instrumentHandle,
                                               ViInt32 mode, ViReal64 diffFreq,
                                               ViInt32 diffFreqUnits,
                                               ViReal64 meanFreq,
                                               ViInt32 meanFreqUnits,
                                               ViReal64 upperFreq,
                                               ViInt32 upperFreqUnits,
                                               ViReal64 voltageValue,
                                               ViInt32 voltageUnits);
ViStatus _VI_FUNC rsupv_SetGeneratorDFDMeanFrequency (ViSession instrumentHandle,
                                                      ViReal64 meanFrequency,
                                                      ViInt32 units);
ViStatus _VI_FUNC rsupv_GetGeneratorDFDMeanFrequency (ViSession instrumentHandle,
                                                      ViPReal64 meanFrequency,
                                                      ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetGeneratorDFDDiffFrequency (ViSession instrumentHandle,
                                                      ViReal64 diffFrequency,
                                                      ViInt32 units);
ViStatus _VI_FUNC rsupv_GetGeneratorDFDDiffFrequency (ViSession instrumentHandle,
                                                      ViPReal64 diffFrequency,
                                                      ViPInt32 units);
ViStatus _VI_FUNC rsupv_ConfigureGeneratorDIM (ViSession instrumentHandle,
                                               ViInt32 squareSine,
                                               ViInt32 bandwidth,
                                               ViReal64 voltageValue,
                                               ViInt32 voltageUnits);
ViStatus _VI_FUNC rsupv_SetGeneratorDIMSquareToSine (ViSession instrumentHandle,
                                                     ViInt32 squareSine);
ViStatus _VI_FUNC rsupv_GetGeneratorDIMSquareToSine (ViSession instrumentHandle,
                                                     ViPInt32 squareSine);
ViStatus _VI_FUNC rsupv_SetGeneratorDIMBandwidth (ViSession instrumentHandle,
                                                  ViInt32 bandwidth);
ViStatus _VI_FUNC rsupv_GetGeneratorDIMBandwidth (ViSession instrumentHandle,
                                                  ViPInt32 bandwidth);
ViStatus _VI_FUNC rsupv_SetGeneratorRandomDomain (ViSession instrumentHandle,
                                                  ViInt32 domain);
ViStatus _VI_FUNC rsupv_GetGeneratorRandomDomain (ViSession instrumentHandle,
                                                  ViPInt32 domain);
ViStatus _VI_FUNC rsupv_SetGeneratorRandomShape (ViSession instrumentHandle,
                                                 ViInt32 shape);
ViStatus _VI_FUNC rsupv_GetGeneratorRandomShape (ViSession instrumentHandle,
                                                 ViPInt32 shape);
ViStatus _VI_FUNC rsupv_SetGeneratorRandomShapeFile (ViSession instrumentHandle,
                                                     ViString shapeFile);
ViStatus _VI_FUNC rsupv_SetGeneratorRandomLowerFrequency (ViSession instrumentHandle,
                                                          ViReal64 lowerFrequency,
                                                          ViInt32 units);
ViStatus _VI_FUNC rsupv_GetGeneratorRandomLowerFrequency (ViSession instrumentHandle,
                                                          ViPReal64 lowerFrequency,
                                                          ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetGeneratorRandomUpperFrequency (ViSession instrumentHandle,
                                                          ViReal64 upperFrequency,
                                                          ViInt32 units);
ViStatus _VI_FUNC rsupv_GetGeneratorRandomUpperFrequency (ViSession instrumentHandle,
                                                          ViPReal64 upperFrequency,
                                                          ViPInt32 units);
ViStatus _VI_FUNC rsupv_ConfigureGeneratorArbitrary (ViSession instrumentHandle,
                                                     ViString shapeFile,
                                                     ViReal64 voltPeak,
                                                     ViInt32 units);
ViStatus _VI_FUNC rsupv_SetGeneratorArbitraryShapeFile (ViSession instrumentHandle,
                                                        ViString shapeFile);
ViStatus _VI_FUNC rsupv_ConfigureGeneratorFMModulation (ViSession instrumentHandle,
                                                        ViReal64 modFreq,
                                                        ViInt32 modFreqUnits,
                                                        ViReal64 carrierFreq,
                                                        ViInt32 carrierFreqUnits,
                                                        ViReal64 deviation,
                                                        ViReal64 carrierVolt,
                                                        ViInt32 carrierVoltUnits);
ViStatus _VI_FUNC rsupv_ConfigureGeneratorAMModulation (ViSession instrumentHandle,
                                                        ViReal64 modFreq,
                                                        ViInt32 modFreqUnits,
                                                        ViReal64 carrierFreq,
                                                        ViInt32 carrierFreqUnits,
                                                        ViReal64 modDepth,
                                                        ViReal64 carrierVolt,
                                                        ViInt32 carrierVoltUnits);
ViStatus _VI_FUNC rsupv_SetGeneratorModulationFrequency (ViSession instrumentHandle,
                                                         ViReal64 modulationFrequency,
                                                         ViInt32 units);
ViStatus _VI_FUNC rsupv_GetGeneratorModulationFrequency (ViSession instrumentHandle,
                                                         ViPReal64 modulationFrequency,
                                                         ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetGeneratorModulationCarrierFrequency
             (ViSession instrumentHandle, ViReal64 carrierFrequency, ViInt32 units);
ViStatus _VI_FUNC rsupv_GetGeneratorModulationCarrierFrequency
             (ViSession instrumentHandle, ViPReal64 carrierFrequency,
              ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetGeneratorModulationCarrierVoltage
             (ViSession instrumentHandle, ViReal64 carrierVoltage, ViInt32 units);
ViStatus _VI_FUNC rsupv_GetGeneratorModulationCarrierVoltage
             (ViSession instrumentHandle, ViPReal64 carrierVoltage, ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetGeneratorModulationDeviation (ViSession instrumentHandle,
                                                         ViReal64 deviation);
ViStatus _VI_FUNC rsupv_GetGeneratorModulationDeviation (ViSession instrumentHandle,
                                                         ViPReal64 deviation);
ViStatus _VI_FUNC rsupv_SetGeneratorModulationDepth (ViSession instrumentHandle,
                                                     ViReal64 modulationDepth);
ViStatus _VI_FUNC rsupv_GetGeneratorModulationDepth (ViSession instrumentHandle,
                                                     ViPReal64 modulationDepth);
ViStatus _VI_FUNC rsupv_SetGeneratorPlayScalePkToFS (ViSession instrumentHandle,
                                                     ViBoolean scalePkToFS);
ViStatus _VI_FUNC rsupv_GetGeneratorPlayScalePkToFS (ViSession instrumentHandle,
                                                     ViPBoolean scalePkToFS);
ViStatus _VI_FUNC rsupv_SetGeneratorPlayChannel (ViSession instrumentHandle,
                                                 ViInt32 channel);
ViStatus _VI_FUNC rsupv_GetGeneratorPlayChannel (ViSession instrumentHandle,
                                                 ViPInt32 channel);
ViStatus _VI_FUNC rsupv_SetGeneratorPlayMode (ViSession instrumentHandle,
                                              ViInt32 mode);
ViStatus _VI_FUNC rsupv_GetGeneratorPlayMode (ViSession instrumentHandle,
                                              ViPInt32 mode);
ViStatus _VI_FUNC rsupv_SetGeneratorPlayTime (ViSession instrumentHandle,
                                              ViReal64 time);
ViStatus _VI_FUNC rsupv_GetGeneratorPlayTime (ViSession instrumentHandle,
                                              ViPReal64 time);
ViStatus _VI_FUNC rsupv_SetGeneratorPlayShapeFile (ViSession instrumentHandle,
                                                   ViString shapeFile);
ViStatus _VI_FUNC rsupv_SetGeneratorPlayRestart (ViSession instrumentHandle,
                                                 ViInt32 restart);
ViStatus _VI_FUNC rsupv_GetGeneratorPlayRestart (ViSession instrumentHandle,
                                                 ViPInt32 restart);
ViStatus _VI_FUNC rsupv_SetGeneratorPlayAnalyzerLoopChannel
             (ViSession instrumentHandle, ViInt32 loopChannel);
ViStatus _VI_FUNC rsupv_GetGeneratorPlayAnalyzerLoopChannel
             (ViSession instrumentHandle, ViPInt32 loopChannel);
ViStatus _VI_FUNC rsupv_SetGeneratorPlayAnalyzerLoopGain (ViSession instrumentHandle,
                                                          ViReal64 loopGain,
                                                          ViInt32 units);
ViStatus _VI_FUNC rsupv_GetGeneratorPlayAnalyzerLoopGain (ViSession instrumentHandle,
                                                          ViPReal64 loopGain,
                                                          ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetGeneratorDither (ViSession instrumentHandle,
                                            ViBoolean dither);
ViStatus _VI_FUNC rsupv_GetGeneratorDither (ViSession instrumentHandle,
                                            ViPBoolean dither);
ViStatus _VI_FUNC rsupv_SetGeneratorDitherValue (ViSession instrumentHandle,
                                                 ViReal64 value, ViInt32 units);
ViStatus _VI_FUNC rsupv_GetGeneratorDitherValue (ViSession instrumentHandle,
                                                 ViPReal64 value, ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetGeneratorPDF (ViSession instrumentHandle, ViInt32 PDF);
ViStatus _VI_FUNC rsupv_GetGeneratorPDF (ViSession instrumentHandle, ViPInt32 PDF);
ViStatus _VI_FUNC rsupv_SetGeneratorFrequencySpacing (ViSession instrumentHandle,
                                                      ViInt32 frequencySpacing);
ViStatus _VI_FUNC rsupv_GetGeneratorFrequencySpacing (ViSession instrumentHandle,
                                                      ViPInt32 frequencySpacing);
ViStatus _VI_FUNC rsupv_SetGeneratorFrequencySpacingValue
             (ViSession instrumentHandle, ViReal64 frequencySpacingValue,
              ViInt32 units);
ViStatus _VI_FUNC rsupv_GetGeneratorFrequencySpacingValue
             (ViSession instrumentHandle, ViPReal64 frequencySpacingValue,
              ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetGeneratorChannelPhaseRatio (ViSession instrumentHandle,
                                                       ViReal64 phaseCh21);
ViStatus _VI_FUNC rsupv_GetGeneratorChannelPhaseRatio (ViSession instrumentHandle,
                                                       ViPReal64 phaseCh21);
ViStatus _VI_FUNC rsupv_SetGeneratorChannelVoltageRatio (ViSession instrumentHandle,
                                                         ViReal64 voltCh21);
ViStatus _VI_FUNC rsupv_GetGeneratorChannelVoltageRatio (ViSession instrumentHandle,
                                                         ViPReal64 voltCh21);
ViStatus _VI_FUNC rsupv_SetGeneratorFunctionMode (ViSession instrumentHandle,
                                                  ViInt32 functionMode);
ViStatus _VI_FUNC rsupv_GetGeneratorFunctionMode (ViSession instrumentHandle,
                                                  ViPInt32 functionMode);
ViStatus _VI_FUNC rsupv_SetGeneratorAmplitudeVariation (ViSession instrumentHandle,
                                                        ViInt32 amplitudeVariation);
ViStatus _VI_FUNC rsupv_GetGeneratorAmplitudeVariation (ViSession instrumentHandle,
                                                        ViPInt32 amplitudeVariation);
ViStatus _VI_FUNC rsupv_SetGeneratorAVModulationFrequency
             (ViSession instrumentHandle, ViReal64 modulationFrequency,
              ViInt32 units);
ViStatus _VI_FUNC rsupv_GetGeneratorAVModulationFrequency
             (ViSession instrumentHandle, ViPReal64 modulationFrequency,
              ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetGeneratorVariation (ViSession instrumentHandle,
                                               ViReal64 variation);
ViStatus _VI_FUNC rsupv_GetGeneratorVariation (ViSession instrumentHandle,
                                               ViPReal64 variation);
ViStatus _VI_FUNC rsupv_SetGeneratorMultichannelFilter (ViSession instrumentHandle,
                                                        ViInt32 channel,
                                                        ViInt32 filter);
ViStatus _VI_FUNC rsupv_GetGeneratorMultichannelFilter (ViSession instrumentHandle,
                                                        ViInt32 channel,
                                                        ViPInt32 filter);
ViStatus _VI_FUNC rsupv_SetGeneratorMultichannelAllChanSine
             (ViSession instrumentHandle, ViInt32 channel, ViBoolean allChanSine);
ViStatus _VI_FUNC rsupv_GetGeneratorMultichannelAllChanSine
             (ViSession instrumentHandle, ViInt32 channel, ViPBoolean allChanSine);
ViStatus _VI_FUNC rsupv_SetGeneratorMultichannelGain (ViSession instrumentHandle,
                                                      ViInt32 channel,
                                                      ViReal64 gain);
ViStatus _VI_FUNC rsupv_GetGeneratorMultichannelGain (ViSession instrumentHandle,
                                                      ViInt32 channel,
                                                      ViPReal64 gain);
ViStatus _VI_FUNC rsupv_SetGeneratorMultichannelLimitToFS
             (ViSession instrumentHandle, ViInt32 channel, ViBoolean limitToFS);
ViStatus _VI_FUNC rsupv_GetGeneratorMultichannelLimitToFS
             (ViSession instrumentHandle, ViInt32 channel, ViPBoolean limitToFS);
ViStatus _VI_FUNC rsupv_SetGeneratorMultichannelTotalGain
             (ViSession instrumentHandle, ViInt32 channel, ViReal64 totalGain);
ViStatus _VI_FUNC rsupv_GetGeneratorMultichannelTotalGain
             (ViSession instrumentHandle, ViInt32 channel, ViPReal64 totalGain);
ViStatus _VI_FUNC rsupv_SetGeneratorMultichannelSine (ViSession instrumentHandle,
                                                      ViInt32 channel,
                                                      ViBoolean addToChannel);
ViStatus _VI_FUNC rsupv_GetGeneratorMultichannelSine (ViSession instrumentHandle,
                                                      ViInt32 channel,
                                                      ViPBoolean addToChannel);
ViStatus _VI_FUNC rsupv_SetGeneratorMultichannelSineFrequency
             (ViSession instrumentHandle, ViInt32 channel, ViReal64 sineFrequency,
              ViInt32 units);
ViStatus _VI_FUNC rsupv_GetGeneratorMultichannelSineFrequency
             (ViSession instrumentHandle, ViInt32 channel, ViPReal64 sineFrequency,
              ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetGeneratorMultichannelSinePhase
             (ViSession instrumentHandle, ViInt32 channel, ViReal64 sinePhase,
              ViInt32 units);
ViStatus _VI_FUNC rsupv_GetGeneratorMultichannelSinePhase
             (ViSession instrumentHandle, ViInt32 channel, ViPReal64 sinePhase,
              ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetGeneratorMultichannelSineVoltage
             (ViSession instrumentHandle, ViInt32 channel, ViReal64 sineVoltage,
              ViInt32 units);
ViStatus _VI_FUNC rsupv_GetGeneratorMultichannelSineVoltage
             (ViSession instrumentHandle, ViInt32 channel, ViPReal64 sineVoltage,
              ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetGeneratorMultichannelSineArbitrary
             (ViSession instrumentHandle, ViInt32 channel, ViBoolean arbitrary);
ViStatus _VI_FUNC rsupv_GetGeneratorMultichannelSineArbitrary
             (ViSession instrumentHandle, ViInt32 channel, ViPBoolean arbitrary);
ViStatus _VI_FUNC rsupv_SetGeneratorMultichannelSineArbitraryFilename
             (ViSession instrumentHandle, ViInt32 channel, ViString arbitraryFile);
ViStatus _VI_FUNC rsupv_SetGeneratorMultichannelSineVoltPeak
             (ViSession instrumentHandle, ViInt32 channel, ViReal64 voltPeak,
              ViInt32 units);
ViStatus _VI_FUNC rsupv_GetGeneratorMultichannelSineVoltPeak
             (ViSession instrumentHandle, ViInt32 channel, ViPReal64 voltPeak,
              ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetGeneratorMultichannelSineEqualizer
             (ViSession instrumentHandle, ViInt32 channel, ViBoolean equalizer);
ViStatus _VI_FUNC rsupv_GetGeneratorMultichannelSineEqualizer
             (ViSession instrumentHandle, ViInt32 channel, ViPBoolean equalizer);
ViStatus _VI_FUNC rsupv_SetGeneratorMultichannelSineEqualizerFilename
             (ViSession instrumentHandle, ViInt32 channel, ViString equalFile);
ViStatus _VI_FUNC rsupv_SetGeneratorMultichannelDCOffset (ViSession instrumentHandle,
                                                          ViInt32 channel,
                                                          ViBoolean DCOffset);
ViStatus _VI_FUNC rsupv_GetGeneratorMultichannelDCOffset (ViSession instrumentHandle,
                                                          ViInt32 channel,
                                                          ViPBoolean DCOffset);
ViStatus _VI_FUNC rsupv_SetGeneratorMultichannelDCOffsetValue
             (ViSession instrumentHandle, ViInt32 channel, ViReal64 DCOffset,
              ViInt32 units);
ViStatus _VI_FUNC rsupv_GetGeneratorMultichannelDCOffsetValue
             (ViSession instrumentHandle, ViInt32 channel, ViPReal64 DCOffset,
              ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetGeneratorSingleChannelTrackToOtherChannel
             (ViSession instrumentHandle, ViBoolean trackToOtherChannel);
ViStatus _VI_FUNC rsupv_GetGeneratorSingleChannelTrackToOtherChannel
             (ViSession instrumentHandle, ViPBoolean trackToOtherChannel);
ViStatus _VI_FUNC rsupv_SetGeneratorSingleChannel (ViSession instrumentHandle,
                                                   ViInt32 channel);
ViStatus _VI_FUNC rsupv_GetGeneratorSingleChannel (ViSession instrumentHandle,
                                                   ViPInt32 channel);
ViStatus _VI_FUNC rsupv_SetGeneratorAllChannelSine (ViSession instrumentHandle,
                                                    ViBoolean allChannelSine);
ViStatus _VI_FUNC rsupv_GetGeneratorAllChannelSine (ViSession instrumentHandle,
                                                    ViPBoolean allChannelSine);
ViStatus _VI_FUNC rsupv_SetGeneratorSineFrequency (ViSession instrumentHandle,
                                                   ViReal64 frequency,
                                                   ViInt32 units);
ViStatus _VI_FUNC rsupv_GetGeneratorSineFrequency (ViSession instrumentHandle,
                                                   ViPReal64 frequency,
                                                   ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetGeneratorSineVoltage (ViSession instrumentHandle,
                                                 ViReal64 voltage, ViInt32 units);
ViStatus _VI_FUNC rsupv_GetGeneratorSineVoltage (ViSession instrumentHandle,
                                                 ViPReal64 voltage, ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetAnalyzerInstrument (ViSession instrumentHandle,
                                               ViInt32 instrument);
ViStatus _VI_FUNC rsupv_GetAnalyzerInstrument (ViSession instrumentHandle,
                                               ViPInt32 instrument);
ViStatus _VI_FUNC rsupv_SetAnalyzerCoupling (ViSession instrumentHandle,
                                             ViInt32 coupling);
ViStatus _VI_FUNC rsupv_GetAnalyzerCoupling (ViSession instrumentHandle,
                                             ViPInt32 coupling);
ViStatus _VI_FUNC rsupv_SetAnalyzerChannelInput (ViSession instrumentHandle,
                                                 ViInt32 channel, ViInt32 input);
ViStatus _VI_FUNC rsupv_GetAnalyzerChannelInput (ViSession instrumentHandle,
                                                 ViInt32 channel, ViPInt32 input);
ViStatus _VI_FUNC rsupv_SetAnalyzerChannelInputImpedance (ViSession instrumentHandle,
                                                          ViInt32 channel,
                                                          ViInt32 imped);
ViStatus _VI_FUNC rsupv_GetAnalyzerChannelInputImpedance (ViSession instrumentHandle,
                                                          ViInt32 channel,
                                                          ViPInt32 imped);
ViStatus _VI_FUNC rsupv_SetAnalyzerChannelInputCommon (ViSession instrumentHandle,
                                                       ViInt32 channel,
                                                       ViInt32 common);
ViStatus _VI_FUNC rsupv_GetAnalyzerChannelInputCommon (ViSession instrumentHandle,
                                                       ViInt32 channel,
                                                       ViPInt32 common);
ViStatus _VI_FUNC rsupv_SetAnalyzerChannelInputRange (ViSession instrumentHandle,
                                                      ViInt32 channel,
                                                      ViInt32 range);
ViStatus _VI_FUNC rsupv_GetAnalyzerChannelInputRange (ViSession instrumentHandle,
                                                      ViInt32 channel,
                                                      ViPInt32 range);
ViStatus _VI_FUNC rsupv_SetAnalyzerChannelInputRangeValue
             (ViSession instrumentHandle, ViInt32 channel, ViReal64 rangeValue);
ViStatus _VI_FUNC rsupv_GetAnalyzerChannelInputRangeValue
             (ViSession instrumentHandle, ViInt32 channel, ViPReal64 rangeValue);
ViStatus _VI_FUNC rsupv_SetMultichannelAnalyzerMeasChannels
             (ViSession instrumentHandle, ViInt32 channel, ViBoolean channelState);
ViStatus _VI_FUNC rsupv_GetMultichannelAnalyzerMeasChannels
             (ViSession instrumentHandle, ViInt32 channel, ViPBoolean channelState);
ViStatus _VI_FUNC rsupv_SetMultichannelAnalyzerCouplingMode
             (ViSession instrumentHandle, ViInt32 coupling);
ViStatus _VI_FUNC rsupv_GetMultichannelAnalyzerCouplingMode
             (ViSession instrumentHandle, ViPInt32 coupling);
ViStatus _VI_FUNC rsupv_SetMultichannelAnalyzerCoupling (ViSession instrumentHandle,
                                                         ViInt32 channel,
                                                         ViInt32 coupling);
ViStatus _VI_FUNC rsupv_GetMultichannelAnalyzerCoupling (ViSession instrumentHandle,
                                                         ViInt32 channel,
                                                         ViPInt32 coupling);
ViStatus _VI_FUNC rsupv_SetMultichannelAnalyzerChannelRange
             (ViSession instrumentHandle, ViInt32 coupling);
ViStatus _VI_FUNC rsupv_GetMultichannelAnalyzerChannelRange
             (ViSession instrumentHandle, ViPInt32 coupling);
ViStatus _VI_FUNC rsupv_SetMultichannelAnalyzerReferenceChannel
             (ViSession instrumentHandle, ViInt32 channel);
ViStatus _VI_FUNC rsupv_GetMultichannelAnalyzerReferenceChannel
             (ViSession instrumentHandle, ViPInt32 channel);
ViStatus _VI_FUNC rsupv_SetMultichannelAnalyzerImpedanceChannel
             (ViSession instrumentHandle, ViInt32 channel, ViInt32 impedance);
ViStatus _VI_FUNC rsupv_GetMultichannelAnalyzerImpedanceChannel
             (ViSession instrumentHandle, ViInt32 channel, ViPInt32 impedance);
ViStatus _VI_FUNC rsupv_SetMultichannelAnalyzerChannelInputImpedance
             (ViSession instrumentHandle, ViInt32 channel, ViInt32 imped);
ViStatus _VI_FUNC rsupv_GetMultichannelAnalyzerChannelInputImpedance
             (ViSession instrumentHandle, ViInt32 channel, ViPInt32 imped);
ViStatus _VI_FUNC rsupv_SetMultichannelAnalyzerTriggerChannel
             (ViSession instrumentHandle, ViInt32 channel);
ViStatus _VI_FUNC rsupv_GetMultichannelAnalyzerTriggerChannel
             (ViSession instrumentHandle, ViPInt32 channel);
ViStatus _VI_FUNC rsupv_SetDigitalAnalyzerMeasMode (ViSession instrumentHandle,
                                                    ViInt32 measMode);
ViStatus _VI_FUNC rsupv_GetDigitalAnalyzerMeasMode (ViSession instrumentHandle,
                                                    ViPInt32 measMode);
ViStatus _VI_FUNC rsupv_SetDigitalAnalyzerJitterRef (ViSession instrumentHandle,
                                                     ViInt32 jitterRef);
ViStatus _VI_FUNC rsupv_GetDigitalAnalyzerJitterRef (ViSession instrumentHandle,
                                                     ViPInt32 jitterRef);
ViStatus _VI_FUNC rsupv_SetDigitalAnalyzerAudioBits (ViSession instrumentHandle,
                                                     ViInt32 audioBits);
ViStatus _VI_FUNC rsupv_GetDigitalAnalyzerAudioBits (ViSession instrumentHandle,
                                                     ViPInt32 audioBits);
ViStatus _VI_FUNC rsupv_SetDigitalAnalyzerAudioInput (ViSession instrumentHandle,
                                                      ViInt32 input);
ViStatus _VI_FUNC rsupv_GetDigitalAnalyzerAudioInput (ViSession instrumentHandle,
                                                      ViPInt32 input);
ViStatus _VI_FUNC rsupv_SetI2SAnalyzerWordLength (ViSession instrumentHandle,
                                                  ViInt32 wordLength);
ViStatus _VI_FUNC rsupv_GetI2SAnalyzerWordLength (ViSession instrumentHandle,
                                                  ViPInt32 wordLength);
ViStatus _VI_FUNC rsupv_SetI2SAnalyzerFormat (ViSession instrumentHandle,
                                              ViInt32 format);
ViStatus _VI_FUNC rsupv_GetI2SAnalyzerFormat (ViSession instrumentHandle,
                                              ViPInt32 format);
ViStatus _VI_FUNC rsupv_SetI2SAnalyzerFsyncSlope (ViSession instrumentHandle,
                                                  ViInt32 fsyncSlope);
ViStatus _VI_FUNC rsupv_GetI2SAnalyzerFsyncSlope (ViSession instrumentHandle,
                                                  ViPInt32 fsyncSlope);
ViStatus _VI_FUNC rsupv_SetI2SAnalyzerWordOffset (ViSession instrumentHandle,
                                                  ViInt32 wordOffset);
ViStatus _VI_FUNC rsupv_GetI2SAnalyzerWordOffset (ViSession instrumentHandle,
                                                  ViPInt32 wordOffset);
ViStatus _VI_FUNC rsupv_SetI2SAnalyzerInput (ViSession instrumentHandle,
                                             ViInt32 input);
ViStatus _VI_FUNC rsupv_GetI2SAnalyzerInput (ViSession instrumentHandle,
                                             ViPInt32 input);
ViStatus _VI_FUNC rsupv_SetUSIAnalyzerMeasChannelState (ViSession instrumentHandle,
                                                        ViInt32 measChannel,
                                                        ViBoolean state);
ViStatus _VI_FUNC rsupv_ConfigureUSIAnalyzerClockAndFrequency
             (ViSession instrumentHandle, ViInt32 clock,
              ViBoolean mixedSamplingFrequency, ViInt32 ratio);
ViStatus _VI_FUNC rsupv_ConfigureUSIAnalyzerFrame (ViSession instrumentHandle,
                                                   ViInt32 samples,
                                                   ViInt32 numberOfSlots);
ViStatus _VI_FUNC rsupv_SetUSIAnalyzerMeasurementSource (ViSession instrumentHandle,
                                                         ViInt32 measChannel,
                                                         ViInt32 dataLink);
ViStatus _VI_FUNC rsupv_SetUSIAnalyzerSlots (ViSession instrumentHandle,
                                             ViInt32 measChannel, ViString slots);
ViStatus _VI_FUNC rsupv_ConfigureUSIAnalyzerSlot (ViSession instrumentHandle,
                                                  ViInt32 firstBit,
                                                  ViInt32 slotLength,
                                                  ViInt32 audioBits,
                                                  ViInt32 leadBits);
ViStatus _VI_FUNC rsupv_SetUSIAnalyzerSampleFrequency (ViSession instrumentHandle,
                                                       ViInt32 sampleFrequency,
                                                       ViReal64 variableSampleFrequency,
                                                       ViInt32 units);
ViStatus _VI_FUNC rsupv_ConfigureUSIAnalyzerFsync (ViSession instrumentHandle,
                                                   ViInt32 fsyncWidth,
                                                   ViInt32 variableFsyncWidth,
                                                   ViInt32 fsyncOffset,
                                                   ViInt32 fsyncSlope);
ViStatus _VI_FUNC rsupv_USIAnalyzerResync (ViSession instrumentHandle);
ViStatus _VI_FUNC rsupv_GetUSIAnalyzerMeasChannelState (ViSession instrumentHandle,
                                                        ViInt32 measChannel,
                                                        ViPBoolean state);
ViStatus _VI_FUNC rsupv_SetUSIAnalyzerClock (ViSession instrumentHandle,
                                             ViInt32 clock);
ViStatus _VI_FUNC rsupv_GetUSIAnalyzerClock (ViSession instrumentHandle,
                                             ViPInt32 clock);
ViStatus _VI_FUNC rsupv_SetUSIAnalyzerTimeout (ViSession instrumentHandle,
                                               ViReal64 timeout);
ViStatus _VI_FUNC rsupv_GetUSIAnalyzerTimeout (ViSession instrumentHandle,
                                               ViPReal64 timeout);
ViStatus _VI_FUNC rsupv_SetUSIAnalyzerMixedSamplingFrequencyState
             (ViSession instrumentHandle, ViBoolean mixedSamplingFrequency);
ViStatus _VI_FUNC rsupv_GetUSIAnalyzerMixedSamplingFrequencyState
             (ViSession instrumentHandle, ViPBoolean mixedSamplingFrequency);
ViStatus _VI_FUNC rsupv_SetUSIAnalyzerRatio (ViSession instrumentHandle,
                                             ViInt32 ratio);
ViStatus _VI_FUNC rsupv_GetUSIAnalyzerRatio (ViSession instrumentHandle,
                                             ViPInt32 ratio);
ViStatus _VI_FUNC rsupv_SetUSIAnalyzerSamplesPerFrame (ViSession instrumentHandle,
                                                       ViInt32 samples);
ViStatus _VI_FUNC rsupv_GetUSIAnalyzerSamplesPerFrame (ViSession instrumentHandle,
                                                       ViPInt32 samples);
ViStatus _VI_FUNC rsupv_SetUSIAnalyzerNumberOfSlots (ViSession instrumentHandle,
                                                     ViInt32 numberOfSlots);
ViStatus _VI_FUNC rsupv_GetUSIAnalyzerNumberOfSlots (ViSession instrumentHandle,
                                                     ViPInt32 numberOfSlots);
ViStatus _VI_FUNC rsupv_GetUSIAnalyzerMeasurementSource (ViSession instrumentHandle,
                                                         ViInt32 measChannel,
                                                         ViPInt32 dataLink);
ViStatus _VI_FUNC rsupv_GetUSIAnalyzerSlots (ViSession instrumentHandle,
                                             ViInt32 measChannel, ViInt32 arraySize,
                                             ViChar _VI_FAR slots[]);
ViStatus _VI_FUNC rsupv_SetUSIAnalyzerSyncTo (ViSession instrumentHandle,
                                              ViInt32 syncTo);
ViStatus _VI_FUNC rsupv_GetUSIAnalyzerSyncTo (ViSession instrumentHandle,
                                              ViPInt32 syncTo);
ViStatus _VI_FUNC rsupv_SetUSIAnalyzerFirstBit (ViSession instrumentHandle,
                                                ViInt32 firstBit);
ViStatus _VI_FUNC rsupv_GetUSIAnalyzerFirstBit (ViSession instrumentHandle,
                                                ViPInt32 firstBit);
ViStatus _VI_FUNC rsupv_SetUSIAnalyzerSlotLength (ViSession instrumentHandle,
                                                  ViInt32 slotLength);
ViStatus _VI_FUNC rsupv_GetUSIAnalyzerSlotLength (ViSession instrumentHandle,
                                                  ViPInt32 slotLength);
ViStatus _VI_FUNC rsupv_SetUSIAnalyzerAudioBits (ViSession instrumentHandle,
                                                 ViInt32 audioBits);
ViStatus _VI_FUNC rsupv_GetUSIAnalyzerAudioBits (ViSession instrumentHandle,
                                                 ViPInt32 audioBits);
ViStatus _VI_FUNC rsupv_SetUSIAnalyzerLeadBits (ViSession instrumentHandle,
                                                ViInt32 leadBits);
ViStatus _VI_FUNC rsupv_GetUSIAnalyzerLeadBits (ViSession instrumentHandle,
                                                ViPInt32 leadBits);
ViStatus _VI_FUNC rsupv_GetUSIAnalyzerSampleFrequency (ViSession instrumentHandle,
                                                       ViPInt32 sampleFrequency,
                                                       ViPReal64 variableSampleFrequency,
                                                       ViPInt32 units);
ViStatus _VI_FUNC rsupv_GetUSIAnalyzerFsyncFrequency (ViSession instrumentHandle,
                                                      ViPReal64 fsyncFrequency);
ViStatus _VI_FUNC rsupv_GetUSIAnalyzerBClkFrequency (ViSession instrumentHandle,
                                                     ViPReal64 BClkFrequency);
ViStatus _VI_FUNC rsupv_SetUSIAnalyzerFsyncWidth (ViSession instrumentHandle,
                                                  ViInt32 fsyncWidth,
                                                  ViInt32 variableFsyncWidth);
ViStatus _VI_FUNC rsupv_GetUSIAnalyzerFsyncWidth (ViSession instrumentHandle,
                                                  ViPInt32 fsyncWidth,
                                                  ViPInt32 variableFsyncWidth);
ViStatus _VI_FUNC rsupv_SetUSIAnalyzerFsyncOffset (ViSession instrumentHandle,
                                                   ViInt32 fsyncOffset);
ViStatus _VI_FUNC rsupv_GetUSIAnalyzerFsyncOffset (ViSession instrumentHandle,
                                                   ViPInt32 fsyncOffset);
ViStatus _VI_FUNC rsupv_SetUSIAnalyzerFsyncSlope (ViSession instrumentHandle,
                                                  ViInt32 fsyncSlope);
ViStatus _VI_FUNC rsupv_GetUSIAnalyzerFsyncSlope (ViSession instrumentHandle,
                                                  ViPInt32 fsyncSlope);
ViStatus _VI_FUNC rsupv_SetUSIAnalyzerBClkSlope (ViSession instrumentHandle,
                                                 ViInt32 BClkSlope);
ViStatus _VI_FUNC rsupv_GetUSIAnalyzerBClkSlope (ViSession instrumentHandle,
                                                 ViPInt32 BClkSlope);
ViStatus _VI_FUNC rsupv_SetUSIAnalyzerMClkRatio (ViSession instrumentHandle,
                                                 ViInt32 ratio);
ViStatus _VI_FUNC rsupv_GetUSIAnalyzerMClkRatio (ViSession instrumentHandle,
                                                 ViPInt32 ratio);
ViStatus _VI_FUNC rsupv_SetUSIAnalyzerSamplingDelay (ViSession instrumentHandle,
                                                     ViReal64 samplingDelay);
ViStatus _VI_FUNC rsupv_GetUSIAnalyzerSamplingDelay (ViSession instrumentHandle,
                                                     ViPReal64 samplingDelay);
ViStatus _VI_FUNC rsupv_SetUSIAnalyzerLogicVoltage (ViSession instrumentHandle,
                                                    ViInt32 logicVoltage);
ViStatus _VI_FUNC rsupv_GetUSIAnalyzerLogicVoltage (ViSession instrumentHandle,
                                                    ViPInt32 logicVoltage);
ViStatus _VI_FUNC rsupv_SetUSIAnalyzerCoding (ViSession instrumentHandle,
                                              ViInt32 coding);
ViStatus _VI_FUNC rsupv_GetUSIAnalyzerCoding (ViSession instrumentHandle,
                                              ViPInt32 coding);
ViStatus _VI_FUNC rsupv_ConfigureHDMIAnalyzerAudio (ViSession instrumentHandle,
                                                    ViInt32 input,
                                                    ViInt32 audioCoding);
ViStatus _VI_FUNC rsupv_SetHDMIAnalyzerAudioInput (ViSession instrumentHandle,
                                                   ViInt32 input);
ViStatus _VI_FUNC rsupv_GetHDMIAnalyzerAudioInput (ViSession instrumentHandle,
                                                   ViPInt32 input);
ViStatus _VI_FUNC rsupv_GetHDMIAnalyzerAudioFormat (ViSession instrumentHandle,
                                                    ViPInt32 audioFormat);
ViStatus _VI_FUNC rsupv_SetHDMIAnalyzerAudioCoding (ViSession instrumentHandle,
                                                    ViInt32 audioCoding);
ViStatus _VI_FUNC rsupv_GetHDMIAnalyzerAudioCoding (ViSession instrumentHandle,
                                                    ViPInt32 audioCoding);
ViStatus _VI_FUNC rsupv_GetHDMIAnalyzerAudioDetected (ViSession instrumentHandle,
                                                      ViInt32 bufferSize,
                                                      ViChar _VI_FAR detected[]);
ViStatus _VI_FUNC rsupv_GetHDMIAnalyzerAudioNParameter (ViSession instrumentHandle,
                                                        ViPInt32 n);
ViStatus _VI_FUNC rsupv_GetHDMIAnalyzerAudioCTSParameter (ViSession instrumentHandle,
                                                          ViPInt32 CTS);
ViStatus _VI_FUNC rsupv_SetHDMIAnalyzerAudioChannel (ViSession instrumentHandle,
                                                         ViInt32 channel);
ViStatus _VI_FUNC rsupv_GetHDMIAnalyzerAudioChannel (ViSession instrumentHandle,
                                                     ViPInt32 channel);
ViStatus _VI_FUNC rsupv_SetHDMIAnalyzerAudioMeasChannelState
             (ViSession instrumentHandle, ViInt32 measChannel, ViBoolean state);
ViStatus _VI_FUNC rsupv_GetHDMIAnalyzerAudioMeasChannelState
             (ViSession instrumentHandle, ViInt32 measChannel, ViPBoolean state);
ViStatus _VI_FUNC rsupv_GetHDMIAnalyzerAudioInfoFrame (ViSession instrumentHandle,
                                                       ViInt32 bufferSize,
                                                       ViChar _VI_FAR audioInfoFrame[]);
ViStatus _VI_FUNC rsupv_GetHDMIAnalyzerVideoFormatNo (ViSession instrumentHandle,
                                                      ViInt32 bufferSize,
                                                      ViChar _VI_FAR formatNo[]);
ViStatus _VI_FUNC rsupv_GetHDMIAnalyzerVideoColorDepth (ViSession instrumentHandle,
                                                        ViInt32 bufferSize,
                                                        ViChar _VI_FAR colorDepth[]);
ViStatus _VI_FUNC rsupv_GetHDMIAnalyzerVideoHDCPState (ViSession instrumentHandle,
                                                       ViPBoolean HDCPState);
ViStatus _VI_FUNC rsupv_GetHDMIAnalyzerVideoTimings (ViSession instrumentHandle,
                                                     ViInt32 bufferSize,
                                                     ViChar _VI_FAR timings[]);
ViStatus _VI_FUNC rsupv_GetHDMIAnalyzerVideoAVI (ViSession instrumentHandle,
                                                 ViInt32 bufferSize,
                                                 ViChar _VI_FAR AVI[]);
ViStatus _VI_FUNC rsupv_GetHDMIAnalyzerVideoSPD (ViSession instrumentHandle,
                                                 ViInt32 bufferSize,
                                                 ViChar _VI_FAR SPD[]);
ViStatus _VI_FUNC rsupv_GetHDMIAnalyzerVideoEEDID (ViSession instrumentHandle,
                                                   ViInt32 bufferSize,
                                                   ViChar _VI_FAR eEDID[]);
ViStatus _VI_FUNC rsupv_SetAnalogAnalyzerChannelMode (ViSession instrumentHandle,
                                                      ViInt32 channelMode);
ViStatus _VI_FUNC rsupv_GetAnalogAnalyzerChannelMode (ViSession instrumentHandle,
                                                      ViPInt32 channelMode);
ViStatus _VI_FUNC rsupv_SetDigitalAnalyzerChannelMode (ViSession instrumentHandle,
                                                       ViInt32 channelMode);
ViStatus _VI_FUNC rsupv_GetDigitalAnalyzerChannelMode (ViSession instrumentHandle,
                                                       ViPInt32 channelMode);
ViStatus _VI_FUNC rsupv_SetI2SAnalyzerChannelMode (ViSession instrumentHandle,
                                                   ViInt32 channelMode);
ViStatus _VI_FUNC rsupv_GetI2SAnalyzerChannelMode (ViSession instrumentHandle,
                                                   ViPInt32 channelMode);
ViStatus _VI_FUNC rsupv_ConfigureDigBitstreamAnalyzer (ViSession instrumentHandle,
                                                       ViInt32 clockSource,
                                                       ViInt32 channelMode,
                                                       ViInt32 alignment,
                                                       ViInt32 dwnsmplFact,
                                                       ViReal64 clockFrequency,
                                                       ViReal64 dutyCycle);
ViStatus _VI_FUNC rsupv_SetDigBitstreamAnalyzerClockSource
             (ViSession instrumentHandle, ViInt32 clockSource);
ViStatus _VI_FUNC rsupv_GetDigBitstreamAnalyzerClockSource
             (ViSession instrumentHandle, ViPInt32 clockSource);
ViStatus _VI_FUNC rsupv_SetDigBitstreamAnalyzerChannelMode
             (ViSession instrumentHandle, ViInt32 channelMode);
ViStatus _VI_FUNC rsupv_GetDigBitstreamAnalyzerChannelMode
             (ViSession instrumentHandle, ViPInt32 channelMode);
ViStatus _VI_FUNC rsupv_SetDigBitstreamAnalyzerAlignment (ViSession instrumentHandle,
                                                          ViInt32 alignment);
ViStatus _VI_FUNC rsupv_GetDigBitstreamAnalyzerAlignment (ViSession instrumentHandle,
                                                          ViPInt32 alignment);
ViStatus _VI_FUNC rsupv_SetDigBitstreamAnalyzerClockFrequency
             (ViSession instrumentHandle, ViReal64 clockFrequency);
ViStatus _VI_FUNC rsupv_GetDigBitstreamAnalyzerClockFrequency
             (ViSession instrumentHandle, ViPReal64 clockFrequency);
ViStatus _VI_FUNC rsupv_SetDigBitstreamAnalyzerDutyCycle (ViSession instrumentHandle,
                                                          ViReal64 dutyCycle);
ViStatus _VI_FUNC rsupv_GetDigBitstreamAnalyzerDutyCycle (ViSession instrumentHandle,
                                                          ViPReal64 dutyCycle);
ViStatus _VI_FUNC rsupv_SetDigBitstreamAnalyzerDownSamplingFactor
             (ViSession instrumentHandle, ViInt32 dwnsmplFact);
ViStatus _VI_FUNC rsupv_GetDigBitstreamAnalyzerDownSamplingFactor
             (ViSession instrumentHandle, ViPInt32 dwnsmplFact);
ViStatus _VI_FUNC rsupv_SetAnalyzerBandwidth (ViSession instrumentHandle,
                                              ViInt32 bandwidth);
ViStatus _VI_FUNC rsupv_GetAnalyzerBandwidth (ViSession instrumentHandle,
                                              ViPInt32 bandwidth);
ViStatus _VI_FUNC rsupv_SetAnalyzerSampleFrequency (ViSession instrumentHandle,
                                                    ViInt32 sampleFrequency,
                                                    ViReal64 sampleFrequencyValue);
ViStatus _VI_FUNC rsupv_GetAnalyzerSampleFrequency (ViSession instrumentHandle,
                                                    ViPInt32 sampleFrequency,
                                                    ViPReal64 sampleFrequencyValue);
ViStatus _VI_FUNC rsupv_SetI2SAnalyzerSampleFrequency (ViSession instrumentHandle,
                                                       ViInt32 sampleFrequency,
                                                       ViReal64 sampleFrequencyValue);
ViStatus _VI_FUNC rsupv_GetI2SAnalyzerSampleFrequency (ViSession instrumentHandle,
                                                       ViPInt32 sampleFrequency,
                                                       ViPReal64 sampleFrequencyValue);
ViStatus _VI_FUNC rsupv_SetAnalyzerRefImpedance (ViSession instrumentHandle,
                                                 ViReal64 refImped);
ViStatus _VI_FUNC rsupv_GetAnalyzerRefImpedance (ViSession instrumentHandle,
                                                 ViPReal64 refImped);
ViStatus _VI_FUNC rsupv_SetAnalyzerStartCondition (ViSession instrumentHandle,
                                                   ViInt32 startCondition);
ViStatus _VI_FUNC rsupv_GetAnalyzerStartCondition (ViSession instrumentHandle,
                                                   ViPInt32 startCondition);
ViStatus _VI_FUNC rsupv_SetAnalyzerStartDelay (ViSession instrumentHandle,
                                               ViReal64 startDelay);
ViStatus _VI_FUNC rsupv_GetAnalyzerStartDelay (ViSession instrumentHandle,
                                               ViPReal64 startDelay);
ViStatus _VI_FUNC rsupv_SetAnalyzerTriggerSettlingMode (ViSession instrumentHandle,
                                                        ViInt32 settling);
ViStatus _VI_FUNC rsupv_GetAnalyzerTriggerSettlingMode (ViSession instrumentHandle,
                                                        ViPInt32 settling);
ViStatus _VI_FUNC rsupv_SetAnalyzerTriggerSettlingCount (ViSession instrumentHandle,
                                                         ViInt32 samples);
ViStatus _VI_FUNC rsupv_GetAnalyzerTriggerSettlingCount (ViSession instrumentHandle,
                                                         ViPInt32 samples);
ViStatus _VI_FUNC rsupv_SetAnalyzerTriggerSettlingResolution
             (ViSession instrumentHandle, ViReal64 resolution);
ViStatus _VI_FUNC rsupv_GetAnalyzerTriggerSettlingResolution
             (ViSession instrumentHandle, ViPReal64 resolution);
ViStatus _VI_FUNC rsupv_SetAnalyzerTriggerSettlingTolerance
             (ViSession instrumentHandle, ViReal64 tolerance);
ViStatus _VI_FUNC rsupv_GetAnalyzerTriggerSettlingTolerance
             (ViSession instrumentHandle, ViPReal64 tolerance);
ViStatus _VI_FUNC rsupv_SetExternalSweepStartValue (ViSession instrumentHandle,
                                                    ViInt32 sweepControl,
                                                    ViReal64 start, ViInt32 units);
ViStatus _VI_FUNC rsupv_GetExternalSweepStartValue (ViSession instrumentHandle,
                                                    ViInt32 sweepControl,
                                                    ViPReal64 start,
                                                    ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetExternalSweepStopValue (ViSession instrumentHandle,
                                                   ViInt32 sweepControl,
                                                   ViReal64 stop, ViInt32 units);
ViStatus _VI_FUNC rsupv_GetExternalSweepStopValue (ViSession instrumentHandle,
                                                   ViInt32 sweepControl,
                                                   ViPReal64 stop, ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetExternalSweepMinimumLevel (ViSession instrumentHandle,
                                                      ViReal64 minVolt);
ViStatus _VI_FUNC rsupv_GetExternalSweepMinimumLevel (ViSession instrumentHandle,
                                                      ViPReal64 minVolt);
ViStatus _VI_FUNC rsupv_SetExternalSweepVariation (ViSession instrumentHandle,
                                                   ViInt32 sweepControl,
                                                   ViReal64 variation);
ViStatus _VI_FUNC rsupv_GetExternalSweepVariation (ViSession instrumentHandle,
                                                   ViInt32 sweepControl,
                                                   ViPReal64 variation);
ViStatus _VI_FUNC rsupv_SetAnalyzerFunction (ViSession instrumentHandle,
                                             ViInt32 function);
ViStatus _VI_FUNC rsupv_GetAnalyzerFunction (ViSession instrumentHandle,
                                             ViPInt32 function);
ViStatus _VI_FUNC rsupv_ConfigureMeasurementFunctionsSettling
             (ViSession instrumentHandle, ViInt32 fnctSettling, ViInt32 samples,
              ViReal64 timeout, ViReal64 resolution, ViReal64 tolerance);
ViStatus _VI_FUNC rsupv_SetMeasurementFunctionsSettling (ViSession instrumentHandle,
                                                         ViInt32 fnctSettling);
ViStatus _VI_FUNC rsupv_GetMeasurementFunctionsSettling (ViSession instrumentHandle,
                                                         ViPInt32 fnctSettling);
ViStatus _VI_FUNC rsupv_SetMeasurementFunctionSettlingCount
             (ViSession instrumentHandle, ViInt32 samples);
ViStatus _VI_FUNC rsupv_GetMeasurementFunctionSettlingCount
             (ViSession instrumentHandle, ViPInt32 settlingCount);
ViStatus _VI_FUNC rsupv_SetMeasurementFunctionSettlingResolution
             (ViSession instrumentHandle, ViReal64 resolution);
ViStatus _VI_FUNC rsupv_GetMeasurementFunctionSettlingResolution
             (ViSession instrumentHandle, ViPReal64 resolution);
ViStatus _VI_FUNC rsupv_SetMeasurementFunctionSettlingTolerance
             (ViSession instrumentHandle, ViReal64 tolerance);
ViStatus _VI_FUNC rsupv_GetMeasurementFunctionSettlingTolerance
             (ViSession instrumentHandle, ViPReal64 tolerance);
ViStatus _VI_FUNC rsupv_SetMeasurementFunctionSettlingTimeout
             (ViSession instrumentHandle, ViReal64 timeout);
ViStatus _VI_FUNC rsupv_GetMeasurementFunctionSettlingTimeout
             (ViSession instrumentHandle, ViPReal64 timeout);
ViStatus _VI_FUNC rsupv_ConfigureAnalyzerSweep (ViSession instrumentHandle,
                                                ViInt32 sweepControl,
                                                ViInt32 spacing, ViInt32 points,
                                                ViReal64 start, ViInt32 startUnits,
                                                ViReal64 stop, ViInt32 stopUnits,
                                                ViReal64 step, ViInt32 stepUnits);
ViStatus _VI_FUNC rsupv_SetAnalyzerSweepControl (ViSession instrumentHandle,
                                                 ViInt32 sweepControl);
ViStatus _VI_FUNC rsupv_GetAnalyzerSweepControl (ViSession instrumentHandle,
                                                 ViPInt32 sweepControl);
ViStatus _VI_FUNC rsupv_SetAnalyzerSweepSpacing (ViSession instrumentHandle,
                                                 ViInt32 spacing);
ViStatus _VI_FUNC rsupv_GetAnalyzerSweepSpacing (ViSession instrumentHandle,
                                                 ViPInt32 spacing);
ViStatus _VI_FUNC rsupv_SetAnalyzerSweepStart (ViSession instrumentHandle,
                                               ViReal64 start, ViInt32 units);
ViStatus _VI_FUNC rsupv_GetAnalyzerSweepStart (ViSession instrumentHandle,
                                               ViPReal64 start, ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetAnalyzerSweepStop (ViSession instrumentHandle,
                                              ViReal64 stop, ViInt32 units);
ViStatus _VI_FUNC rsupv_GetAnalyzerSweepStop (ViSession instrumentHandle,
                                              ViPReal64 stop, ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetAnalyzerSweepPoints (ViSession instrumentHandle,
                                                ViInt32 points);
ViStatus _VI_FUNC rsupv_GetAnalyzerSweepPoints (ViSession instrumentHandle,
                                                ViPInt32 points);
ViStatus _VI_FUNC rsupv_SetAnalyzerSweepSteps (ViSession instrumentHandle,
                                               ViReal64 step, ViInt32 units);
ViStatus _VI_FUNC rsupv_GetAnalyzerSweepSteps (ViSession instrumentHandle,
                                               ViPReal64 step, ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetAnalyzerLevelMeasTime (ViSession instrumentHandle,
                                                  ViInt32 measTime);
ViStatus _VI_FUNC rsupv_GetAnalyzerLevelMeasTime (ViSession instrumentHandle,
                                                  ViPInt32 measTime);
ViStatus _VI_FUNC rsupv_SetAnalyzerLevelMeasTimeValue (ViSession instrumentHandle,
                                                       ViReal64 measTimeValue);
ViStatus _VI_FUNC rsupv_GetAnalyzerLevelMeasTimeValue (ViSession instrumentHandle,
                                                       ViPReal64 measTimeValue);
ViStatus _VI_FUNC rsupv_SetAnalyzerSNSequenceState (ViSession instrumentHandle,
                                                    ViBoolean sNEnable);
ViStatus _VI_FUNC rsupv_GetAnalyzerSNSequenceState (ViSession instrumentHandle,
                                                    ViPBoolean sNEnable);
ViStatus _VI_FUNC rsupv_ConfigureAnalyzerPeakMeasurement (ViSession instrumentHandle,
                                                          ViInt32 measMode,
                                                          ViInt32 intervalTime,
                                                          ViReal64 intervalTimeValue);
ViStatus _VI_FUNC rsupv_SetAnalyzerPeakMeasMode (ViSession instrumentHandle,
                                                 ViInt32 measMode);
ViStatus _VI_FUNC rsupv_GetAnalyzerPeakMeasMode (ViSession instrumentHandle,
                                                 ViPInt32 measMode);
ViStatus _VI_FUNC rsupv_SetAnalyzerPeakMeasIntervalTime (ViSession instrumentHandle,
                                                         ViInt32 intervalTime);
ViStatus _VI_FUNC rsupv_GetAnalyzerPeakMeasIntervalTime (ViSession instrumentHandle,
                                                         ViPInt32 intervalTime);
ViStatus _VI_FUNC rsupv_SetAnalyzerPeakMeasIntervalTimeValue
             (ViSession instrumentHandle, ViReal64 intervalTimeValue);
ViStatus _VI_FUNC rsupv_GetAnalyzerPeakMeasIntervalTimeValue
             (ViSession instrumentHandle, ViPReal64 intervalTimeValue);
ViStatus _VI_FUNC rsupv_SetAnalyzerLevelMeasBandwidth (ViSession instrumentHandle,
                                                       ViInt32 bandwidth);
ViStatus _VI_FUNC rsupv_GetAnalyzerLevelMeasBandwidth (ViSession instrumentHandle,
                                                       ViPInt32 bandwidth);
ViStatus _VI_FUNC rsupv_SetAnalyzerLevelMeasBandwidthValue
             (ViSession instrumentHandle, ViReal64 bandwidthValue);
ViStatus _VI_FUNC rsupv_GetAnalyzerLevelMeasBandwidthValue
             (ViSession instrumentHandle, ViPReal64 bandwidthValue);
ViStatus _VI_FUNC rsupv_SetAnalyzerLevelMeasFrequencyMode
             (ViSession instrumentHandle, ViInt32 frequencyMode);
ViStatus _VI_FUNC rsupv_GetAnalyzerLevelMeasFrequencyMode
             (ViSession instrumentHandle, ViPInt32 frequencyMode);
ViStatus _VI_FUNC rsupv_SetAnalyzerLevelMeasFrequencyValue
             (ViSession instrumentHandle, ViReal64 frequencyValue);
ViStatus _VI_FUNC rsupv_GetAnalyzerLevelMeasFrequencyValue
             (ViSession instrumentHandle, ViPReal64 frequencyValue);
ViStatus _VI_FUNC rsupv_SetAnalyzerLevelMeasFrequencyFactor
             (ViSession instrumentHandle, ViReal64 frequencyFactor);
ViStatus _VI_FUNC rsupv_GetAnalyzerLevelMeasFrequencyFactor
             (ViSession instrumentHandle, ViPReal64 frequencyFactor);
ViStatus _VI_FUNC rsupv_SetAnalyzerLevelMeasFrequencyStart
             (ViSession instrumentHandle, ViReal64 frequencyStart);
ViStatus _VI_FUNC rsupv_GetAnalyzerLevelMeasFrequencyStart
             (ViSession instrumentHandle, ViPReal64 frequencyStart);
ViStatus _VI_FUNC rsupv_SetAnalyzerLevelMeasFrequencyStop
             (ViSession instrumentHandle, ViReal64 frequencyStop);
ViStatus _VI_FUNC rsupv_GetAnalyzerLevelMeasFrequencyStop
             (ViSession instrumentHandle, ViPReal64 frequencyStop);
ViStatus _VI_FUNC rsupv_SetAnalyzerLevelDCMeasTime (ViSession instrumentHandle,
                                                    ViInt32 measTime);
ViStatus _VI_FUNC rsupv_GetAnalyzerLevelDCMeasTime (ViSession instrumentHandle,
                                                    ViPInt32 measTime);
ViStatus _VI_FUNC rsupv_SetAnalyzerDynamicMode (ViSession instrumentHandle,
                                                ViInt32 dynamicMode);
ViStatus _VI_FUNC rsupv_GetAnalyzerDynamicMode (ViSession instrumentHandle,
                                                ViPInt32 dynamicMode);
ViStatus _VI_FUNC rsupv_SetAnalyzerBargraphState (ViSession instrumentHandle,
                                                  ViBoolean bargraphState);
ViStatus _VI_FUNC rsupv_GetAnalyzerBargraphState (ViSession instrumentHandle,
                                                  ViPBoolean bargraphState);
ViStatus _VI_FUNC rsupv_SetAnalyzerRefinement (ViSession instrumentHandle,
                                               ViInt32 refinement);
ViStatus _VI_FUNC rsupv_GetAnalyzerRefinement (ViSession instrumentHandle,
                                               ViPInt32 refinement);
ViStatus _VI_FUNC rsupv_ConfigureAnalyzerFundamental (ViSession instrumentHandle,
                                                      ViInt32 fundamental,
                                                      ViReal64 fundamentalValue);
ViStatus _VI_FUNC rsupv_SetAnalyzerTHDFundamental (ViSession instrumentHandle,
                                                   ViInt32 fundamental);
ViStatus _VI_FUNC rsupv_GetAnalyzerTHDFundamental (ViSession instrumentHandle,
                                                   ViPInt32 fundamental);
ViStatus _VI_FUNC rsupv_SetAnalyzerTHDFundamentalValue (ViSession instrumentHandle,
                                                        ViReal64 fundamentalValue);
ViStatus _VI_FUNC rsupv_GetAnalyzerTHDFundamentalValue (ViSession instrumentHandle,
                                                        ViPReal64 fundamentalValue);
ViStatus _VI_FUNC rsupv_ConfigureAnalyzerTHD (ViSession instrumentHandle,
                                              ViInt32 measMode, ViInt32 harmonic,
                                              ViBoolean harmonicState);
ViStatus _VI_FUNC rsupv_SetAnalyzerTHDMeasMode (ViSession instrumentHandle,
                                                ViInt32 measMode);
ViStatus _VI_FUNC rsupv_GetAnalyzerTHDMeasMode (ViSession instrumentHandle,
                                                ViPInt32 measMode);
ViStatus _VI_FUNC rsupv_SetAnalyzerTHDHarmonicState (ViSession instrumentHandle,
                                                     ViInt32 harmonic,
                                                     ViBoolean harmonicState);
ViStatus _VI_FUNC rsupv_GetAnalyzerTHDHarmonicState (ViSession instrumentHandle,
                                                     ViInt32 harmonic,
                                                     ViPBoolean harmonicState);
ViStatus _VI_FUNC rsupv_SetAnalyzerTHDNMeasurementMode (ViSession instrumentHandle,
                                                        ViInt32 measurementMode);
ViStatus _VI_FUNC rsupv_GetAnalyzerTHDNMeasurementMode (ViSession instrumentHandle,
                                                        ViPInt32 measurementMode);
ViStatus _VI_FUNC rsupv_SetAnalyzerTHDNRejection (ViSession instrumentHandle,
                                                  ViInt32 rejection);
ViStatus _VI_FUNC rsupv_GetAnalyzerTHDNRejection (ViSession instrumentHandle,
                                                  ViPInt32 rejection);
ViStatus _VI_FUNC rsupv_SetAnalyzerTHDNRejectBandwidth (ViSession instrumentHandle,
                                                        ViInt32 rejectBandwidth);
ViStatus _VI_FUNC rsupv_GetAnalyzerTHDNRejectBandwidth (ViSession instrumentHandle,
                                                        ViPInt32 rejectBandwidth);
ViStatus _VI_FUNC rsupv_SetAnalyzerTHDNEqualizer (ViSession instrumentHandle,
                                                  ViBoolean equalizer);
ViStatus _VI_FUNC rsupv_GetAnalyzerTHDNEqualizer (ViSession instrumentHandle,
                                                  ViPBoolean equalizer);
ViStatus _VI_FUNC rsupv_SetAnalyzerTHDNEqualizerFile (ViSession instrumentHandle,
                                                      ViString equalFile);
ViStatus _VI_FUNC rsupv_SetAnalyzerTHDNFrequencyLimLow (ViSession instrumentHandle,
                                                        ViReal64 freqLimLow);
ViStatus _VI_FUNC rsupv_GetAnalyzerTHDNFrequencyLimLow (ViSession instrumentHandle,
                                                        ViPReal64 freqLimLow);
ViStatus _VI_FUNC rsupv_SetAnalyzerTHDNFrequencyLimUpp (ViSession instrumentHandle,
                                                        ViReal64 freqLimUpp);
ViStatus _VI_FUNC rsupv_GetAnalyzerTHDNFrequencyLimUpp (ViSession instrumentHandle,
                                                        ViPReal64 freqLimUpp);
ViStatus _VI_FUNC rsupv_SetAnalyzerDFDMeasurementMode (ViSession instrumentHandle,
                                                       ViInt32 measurementMode);
ViStatus _VI_FUNC rsupv_GetAnalyzerDFDMeasurementMode (ViSession instrumentHandle,
                                                       ViPInt32 measurementMode);
ViStatus _VI_FUNC rsupv_SetAnalyzerFFTEqualizer (ViSession instrumentHandle,
                                                 ViBoolean equalizer);
ViStatus _VI_FUNC rsupv_GetAnalyzerFFTEqualizer (ViSession instrumentHandle,
                                                 ViPBoolean equalizer);
ViStatus _VI_FUNC rsupv_SetAnalyzerFFTEqualizerFile (ViSession instrumentHandle,
                                                     ViString equalFile);
ViStatus _VI_FUNC rsupv_ConfigureAnalyzerFFTFrequencyLimit
             (ViSession instrumentHandle, ViBoolean limitEnable,
              ViReal64 freqLimLow, ViReal64 freqLimUpp);
ViStatus _VI_FUNC rsupv_SetAnalyzerFFTFrequencyLimitState
             (ViSession instrumentHandle, ViBoolean limitEnable);
ViStatus _VI_FUNC rsupv_GetAnalyzerFFTFrequencyLimitState
             (ViSession instrumentHandle, ViPBoolean limitEnable);
ViStatus _VI_FUNC rsupv_SetAnalyzerFFTFrequencyLimitLow (ViSession instrumentHandle,
                                                         ViReal64 freqLimLow);
ViStatus _VI_FUNC rsupv_GetAnalyzerFFTFrequencyLimitLow (ViSession instrumentHandle,
                                                         ViPReal64 freqLimLow);
ViStatus _VI_FUNC rsupv_SetAnalyzerFFTFrequencyLimitUpp (ViSession instrumentHandle,
                                                         ViReal64 freqLimUpp);
ViStatus _VI_FUNC rsupv_GetAnalyzerFFTFrequencyLimitUpp (ViSession instrumentHandle,
                                                         ViPReal64 freqLimUpp);
ViStatus _VI_FUNC rsupv_SetAnalyzerFFTSize (ViSession instrumentHandle,
                                            ViInt32 FFTSize);
ViStatus _VI_FUNC rsupv_GetAnalyzerFFTSize (ViSession instrumentHandle,
                                            ViPInt32 FFTSize);
ViStatus _VI_FUNC rsupv_SetAnalyzerFFTMaxSize (ViSession instrumentHandle,
                                               ViInt32 FFTSize);
ViStatus _VI_FUNC rsupv_GetAnalyzerFFTMaxSize (ViSession instrumentHandle,
                                               ViPInt32 FFTSize);
ViStatus _VI_FUNC rsupv_GetAnalyzerFFTResolution (ViSession instrumentHandle,
                                                  ViPReal64 resolution);
ViStatus _VI_FUNC rsupv_GetAnalyzerFFTMeasurementTime (ViSession instrumentHandle,
                                                       ViPReal64 measTime);
ViStatus _VI_FUNC rsupv_SetAnalyzerFFTWindow (ViSession instrumentHandle,
                                              ViInt32 window);
ViStatus _VI_FUNC rsupv_GetAnalyzerFFTWindow (ViSession instrumentHandle,
                                              ViPInt32 window);
ViStatus _VI_FUNC rsupv_SetAnalyzerFFTMonitorState (ViSession instrumentHandle,
                                                    ViBoolean FFTMonitor);
ViStatus _VI_FUNC rsupv_GetAnalyzerFFTMonitorState (ViSession instrumentHandle,
                                                    ViPBoolean FFTMonitor);
ViStatus _VI_FUNC rsupv_SetAnalyzerPostFFTState (ViSession instrumentHandle,
                                                 ViBoolean postFFT);
ViStatus _VI_FUNC rsupv_GetAnalyzerPostFFTState (ViSession instrumentHandle,
                                                 ViPBoolean postFFT);
ViStatus _VI_FUNC rsupv_SetAnalyzerFFTDelayCh1 (ViSession instrumentHandle,
                                                ViReal64 delayChannel1);
ViStatus _VI_FUNC rsupv_GetAnalyzerFFTDelayCh1 (ViSession instrumentHandle,
                                                ViPReal64 delayChannel1);
ViStatus _VI_FUNC rsupv_SetAnalyzerFFTAvgMode (ViSession instrumentHandle,
                                               ViInt32 avgMode);
ViStatus _VI_FUNC rsupv_GetAnalyzerFFTAvgMode (ViSession instrumentHandle,
                                               ViPInt32 avgMode);
ViStatus _VI_FUNC rsupv_SetAnalyzerFFTAvgCount (ViSession instrumentHandle,
                                                ViInt32 avgCount);
ViStatus _VI_FUNC rsupv_GetAnalyzerFFTAvgCount (ViSession instrumentHandle,
                                                ViPInt32 avgCount);
ViStatus _VI_FUNC rsupv_SetAnalyzerFFTTriggeredState (ViSession instrumentHandle,
                                                      ViBoolean triggeredFFTEnable);
ViStatus _VI_FUNC rsupv_GetAnalyzerFFTTriggeredState (ViSession instrumentHandle,
                                                      ViPBoolean triggeredFFTEnable);
ViStatus _VI_FUNC rsupv_SetAnalyzerFFTUndersampleState (ViSession instrumentHandle,
                                                        ViBoolean undersample);
ViStatus _VI_FUNC rsupv_GetAnalyzerFFTUndersampleState (ViSession instrumentHandle,
                                                        ViPBoolean undersample);
ViStatus _VI_FUNC rsupv_SetAnalyzerFFTCompFactor (ViSession instrumentHandle,
                                                  ViInt32 compFactor);
ViStatus _VI_FUNC rsupv_GetAnalyzerFFTCompFactor (ViSession instrumentHandle,
                                                  ViPInt32 compFactor);
ViStatus _VI_FUNC rsupv_SetAnalyzerFFTZoomCenter (ViSession instrumentHandle,
                                                  ViReal64 center);
ViStatus _VI_FUNC rsupv_GetAnalyzerFFTZoomCenter (ViSession instrumentHandle,
                                                  ViPReal64 center);
ViStatus _VI_FUNC rsupv_GetAnalyzerFFTZoomStart (ViSession instrumentHandle,
                                                 ViPReal64 start);
ViStatus _VI_FUNC rsupv_GetAnalyzerFFTZoomStop (ViSession instrumentHandle,
                                                ViPReal64 stop);
ViStatus _VI_FUNC rsupv_ConfigureAnalyzerPEAQ (ViSession instrumentHandle,
                                               ViInt32 modelVersion,
                                               ViInt32 measurementMode,
                                               ViString storeWAVToFilename);
ViStatus _VI_FUNC rsupv_SetAnalyzerPEAQModel (ViSession instrumentHandle,
                                              ViInt32 modelVersion);
ViStatus _VI_FUNC rsupv_GetAnalyzerPEAQModel (ViSession instrumentHandle,
                                              ViPInt32 modelVersion);
ViStatus _VI_FUNC rsupv_SetAnalyzerPEAQMeasurementMode (ViSession instrumentHandle,
                                                        ViInt32 measurementMode);
ViStatus _VI_FUNC rsupv_GetAnalyzerPEAQMeasurementMode (ViSession instrumentHandle,
                                                        ViPInt32 measurementMode);
ViStatus _VI_FUNC rsupv_SetAnalyzerPEAQStoreWAVTo (ViSession instrumentHandle,
                                                   ViString storeWAVTo);
ViStatus _VI_FUNC rsupv_SetAnalyzerPEAQFilename (ViSession instrumentHandle,
                                                 ViString filename);
ViStatus _VI_FUNC rsupv_GetAnalyzerPEAQReferenceLevel (ViSession instrumentHandle,
                                                       ViPReal64 referenceLevel);
ViStatus _VI_FUNC rsupv_GetAnalyzerPEAQDegLevel (ViSession instrumentHandle,
                                                 ViPReal64 degLevel);
ViStatus _VI_FUNC rsupv_GetAnalyzerPEAQAvgDelay (ViSession instrumentHandle,
                                                 ViPReal64 avgDelay);
ViStatus _VI_FUNC rsupv_GetAnalyzerPEAQDelayDetect (ViSession instrumentHandle,
                                                    ViPReal64 delayDetect);
ViStatus _VI_FUNC rsupv_ConfigureAnalyzerPESQ (ViSession instrumentHandle,
                                               ViInt32 accordingTo,
                                               ViInt32 measurementMode,
                                               ViString storeWAVToFilename);
ViStatus _VI_FUNC rsupv_SetAnalyzerPESQAccordingTo (ViSession instrumentHandle,
                                                    ViInt32 accordingTo);
ViStatus _VI_FUNC rsupv_GetAnalyzerPESQAccordingTo (ViSession instrumentHandle,
                                                    ViPInt32 accordingTo);
ViStatus _VI_FUNC rsupv_SetAnalyzerPESQMeasurementMode (ViSession instrumentHandle,
                                                        ViInt32 measurementMode);
ViStatus _VI_FUNC rsupv_GetAnalyzerPESQMeasurementMode (ViSession instrumentHandle,
                                                        ViPInt32 measurementMode);
ViStatus _VI_FUNC rsupv_SetAnalyzerPESQStoreWAVTo (ViSession instrumentHandle,
                                                   ViString storeWAVTo);
ViStatus _VI_FUNC rsupv_SetAnalyzerPESQFilename (ViSession instrumentHandle,
                                                 ViString filename);
ViStatus _VI_FUNC rsupv_GetAnalyzerPESQReferenceLevel (ViSession instrumentHandle,
                                                       ViPReal64 referenceLevel);
ViStatus _VI_FUNC rsupv_GetAnalyzerPESQDegLevel (ViSession instrumentHandle,
                                                 ViPReal64 degLevel);
ViStatus _VI_FUNC rsupv_GetAnalyzerPESQAvgDelay (ViSession instrumentHandle,
                                                 ViPReal64 avgDelay);
ViStatus _VI_FUNC rsupv_SetAnalyzerPOLQABand (ViSession instrumentHandle,
                                              ViInt32 band);
ViStatus _VI_FUNC rsupv_GetAnalyzerPOLQABand (ViSession instrumentHandle,
                                              ViPInt32 band);
ViStatus _VI_FUNC rsupv_SetAnalyzerPOLQAMeasurementMode (ViSession instrumentHandle,
                                                         ViInt32 measurementMode);
ViStatus _VI_FUNC rsupv_GetAnalyzerPOLQAMeasurementMode (ViSession instrumentHandle,
                                                         ViPInt32 measurementMode);
ViStatus _VI_FUNC rsupv_SetAnalyzerPOLQAGain (ViSession instrumentHandle,
                                              ViReal64 gain);
ViStatus _VI_FUNC rsupv_GetAnalyzerPOLQAGain (ViSession instrumentHandle,
                                              ViPReal64 gain);
ViStatus _VI_FUNC rsupv_GetAnalyzerPOLQAReferenceLevel (ViSession instrumentHandle,
                                                        ViPReal64 refLevel);
ViStatus _VI_FUNC rsupv_GetAnalyzerPOLQADegLevel (ViSession instrumentHandle,
                                                  ViPReal64 degLevel);
ViStatus _VI_FUNC rsupv_GetAnalyzerPOLQAAttenuation (ViSession instrumentHandle,
                                                     ViPReal64 attenuation);
ViStatus _VI_FUNC rsupv_GetAnalyzerPOLQASNRRef (ViSession instrumentHandle,
                                                ViPReal64 SNRRef);
ViStatus _VI_FUNC rsupv_GetAnalyzerPOLQASNRDegraded (ViSession instrumentHandle,
                                                     ViPReal64 SNRDegraded);
ViStatus _VI_FUNC rsupv_GetAnalyzerPOLQARefSpRatio (ViSession instrumentHandle,
                                                    ViPReal64 refSpRatio);
ViStatus _VI_FUNC rsupv_GetAnalyzerPOLQADegSpRatio (ViSession instrumentHandle,
                                                    ViPReal64 degSpRatio);
ViStatus _VI_FUNC rsupv_GetAnalyzerPOLQAMinDelay (ViSession instrumentHandle,
                                                  ViPReal64 minDelay);
ViStatus _VI_FUNC rsupv_GetAnalyzerPOLQAMaxDelay (ViSession instrumentHandle,
                                                  ViPReal64 maxDelay);
ViStatus _VI_FUNC rsupv_SetAnalyzerWaveformMonitorState (ViSession instrumentHandle,
                                                         ViBoolean waveformMonitor);
ViStatus _VI_FUNC rsupv_GetAnalyzerWaveformMonitorState (ViSession instrumentHandle,
                                                         ViPBoolean waveformMonitor);
ViStatus _VI_FUNC rsupv_SetAnalyzerWaveformMonitorMeasMode
             (ViSession instrumentHandle, ViInt32 measMode);
ViStatus _VI_FUNC rsupv_GetAnalyzerWaveformMonitorMeasMode
             (ViSession instrumentHandle, ViPInt32 measMode);
ViStatus _VI_FUNC rsupv_SetAnalyzerWaveformMonitorCompressionFactor
             (ViSession instrumentHandle, ViInt32 compressionFactor);
ViStatus _VI_FUNC rsupv_GetAnalyzerWaveformMonitorCompressionFactor
             (ViSession instrumentHandle, ViPInt32 compressionFactor);
ViStatus _VI_FUNC rsupv_SetAnalyzerWaveformMonitorTraceLength
             (ViSession instrumentHandle, ViReal64 traceLength);
ViStatus _VI_FUNC rsupv_GetAnalyzerWaveformMonitorTraceLength
             (ViSession instrumentHandle, ViPReal64 traceLength);
ViStatus _VI_FUNC rsupv_SetAnalyzerWaveformMonitorTriggerSource
             (ViSession instrumentHandle, ViInt32 triggerSource);
ViStatus _VI_FUNC rsupv_GetAnalyzerWaveformMonitorTriggerSource
             (ViSession instrumentHandle, ViPInt32 triggerSource);
ViStatus _VI_FUNC rsupv_SetAnalyzerWaveformMonitorTriggerLevel
             (ViSession instrumentHandle, ViReal64 triggerLevel, ViInt32 units);
ViStatus _VI_FUNC rsupv_GetAnalyzerWaveformMonitorTriggerLevel
             (ViSession instrumentHandle, ViPReal64 triggerLevel, ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetAnalyzerWaveformMonitorTriggerSlope
             (ViSession instrumentHandle, ViInt32 triggerSlope);
ViStatus _VI_FUNC rsupv_GetAnalyzerWaveformMonitorTriggerSlope
             (ViSession instrumentHandle, ViPInt32 triggerSlope);
ViStatus _VI_FUNC rsupv_SetAnalyzerWaveformMonitorPretrigger
             (ViSession instrumentHandle, ViReal64 pretrigger);
ViStatus _VI_FUNC rsupv_GetAnalyzerWaveformMonitorPretrigger
             (ViSession instrumentHandle, ViPReal64 pretrigger);
ViStatus _VI_FUNC rsupv_SetAnalyzerWaveformMonitorAutotrigger
             (ViSession instrumentHandle, ViBoolean autotrigger);
ViStatus _VI_FUNC rsupv_GetAnalyzerWaveformMonitorAutotrigger
             (ViSession instrumentHandle, ViPBoolean autotrigger);
ViStatus _VI_FUNC rsupv_SetAnalyzerCombinedMeasurement (ViSession instrumentHandle,
                                                        ViInt32 combinedMeasurement);
ViStatus _VI_FUNC rsupv_GetAnalyzerCombinedMeasurement (ViSession instrumentHandle,
                                                        ViPInt32 combinedMeasurement);
ViStatus _VI_FUNC rsupv_SetAnalyzerMeasurementTime (ViSession instrumentHandle,
                                                    ViInt32 measTime);
ViStatus _VI_FUNC rsupv_GetAnalyzerMeasurementTime (ViSession instrumentHandle,
                                                    ViPInt32 measTime);
ViStatus _VI_FUNC rsupv_SetAnalyzerFormatPhase (ViSession instrumentHandle,
                                                ViInt32 formatPhase);
ViStatus _VI_FUNC rsupv_GetAnalyzerFormatPhase (ViSession instrumentHandle,
                                                ViPInt32 formatPhase);
ViStatus _VI_FUNC rsupv_SetAnalyzerInputMonitor (ViSession instrumentHandle,
                                                 ViInt32 inputMonitor);
ViStatus _VI_FUNC rsupv_GetAnalyzerInputMonitor (ViSession instrumentHandle,
                                                 ViPInt32 inputMonitor);
ViStatus _VI_FUNC rsupv_SetAnalyzerLevelMonitor (ViSession instrumentHandle,
                                                 ViInt32 levelMonitor);
ViStatus _VI_FUNC rsupv_GetAnalyzerLevelMonitor (ViSession instrumentHandle,
                                                 ViPInt32 levelMonitor);
ViStatus _VI_FUNC rsupv_SetAnalyzerPrefilter (ViSession instrumentHandle,
                                              ViInt32 preFilter);
ViStatus _VI_FUNC rsupv_GetAnalyzerPrefilter (ViSession instrumentHandle,
                                              ViPInt32 preFilter);
ViStatus _VI_FUNC rsupv_SetAnalyzerFilter (ViSession instrumentHandle,
                                           ViInt32 filterNumber, ViInt32 filter);
ViStatus _VI_FUNC rsupv_GetAnalyzerFilter (ViSession instrumentHandle,
                                           ViInt32 filterNumber, ViPInt32 filter);
ViStatus _VI_FUNC rsupv_ConfigureAnalyzerNotchFilter (ViSession instrumentHandle,
                                                      ViInt32 notchGain,
                                                      ViInt32 notchFrequency,
                                                      ViReal64 notchCenterFrequency);
ViStatus _VI_FUNC rsupv_SetAnalyzerNotchGain (ViSession instrumentHandle,
                                              ViInt32 notchGain);
ViStatus _VI_FUNC rsupv_GetAnalyzerNotchGain (ViSession instrumentHandle,
                                              ViPInt32 notchGain);
ViStatus _VI_FUNC rsupv_SetAnalyzerNotchFrequency (ViSession instrumentHandle,
                                                   ViInt32 notchFrequency);
ViStatus _VI_FUNC rsupv_GetAnalyzerNotchFrequency (ViSession instrumentHandle,
                                                   ViPInt32 notchFrequency);
ViStatus _VI_FUNC rsupv_SetAnalyzerNotchCenterFrequency (ViSession instrumentHandle,
                                                         ViReal64 notchCenterFrequency);
ViStatus _VI_FUNC rsupv_GetAnalyzerNotchCenterFrequency (ViSession instrumentHandle,
                                                         ViPReal64 notchCenterFrequency);
ViStatus _VI_FUNC rsupv_SetAnalyzerDCSuppression (ViSession instrumentHandle,
                                                  ViBoolean DCSuppression);
ViStatus _VI_FUNC rsupv_GetAnalyzerDCSuppression (ViSession instrumentHandle,
                                                  ViPBoolean DCSuppression);
ViStatus _VI_FUNC rsupv_SetAnalyzerSNMeasMode (ViSession instrumentHandle,
                                               ViInt32 measMode);
ViStatus _VI_FUNC rsupv_GetAnalyzerSNMeasMode (ViSession instrumentHandle,
                                               ViPInt32 measMode);
ViStatus _VI_FUNC rsupv_SetAnalyzerSNMeasTime (ViSession instrumentHandle,
                                               ViInt32 measTime);
ViStatus _VI_FUNC rsupv_GetAnalyzerSNMeasTime (ViSession instrumentHandle,
                                               ViPInt32 measTime);
ViStatus _VI_FUNC rsupv_SetAnalyzerNOCTMeasMode (ViSession instrumentHandle,
                                                 ViInt32 measMode);
ViStatus _VI_FUNC rsupv_GetAnalyzerNOCTMeasMode (ViSession instrumentHandle,
                                                 ViPInt32 measMode);
ViStatus _VI_FUNC rsupv_SetAnalyzerRecordFile (ViSession instrumentHandle,
                                               ViString recordFile);
ViStatus _VI_FUNC rsupv_SetAnalyzerRecordLength (ViSession instrumentHandle,
                                                 ViReal64 recordLength,
                                                 ViInt32 units);
ViStatus _VI_FUNC rsupv_GetAnalyzerRecordLength (ViSession instrumentHandle,
                                                 ViPReal64 recordLength,
                                                 ViPInt32 units);
ViStatus _VI_FUNC rsupv_GetAnalyzerRecordFileLength (ViSession instrumentHandle,
                                                     ViPInt32 fileLength);
ViStatus _VI_FUNC rsupv_SetAnalyzerRecordTriggerSource (ViSession instrumentHandle,
                                                        ViInt32 triggerSource);
ViStatus _VI_FUNC rsupv_GetAnalyzerRecordTriggerSource (ViSession instrumentHandle,
                                                        ViPInt32 triggerSource);
ViStatus _VI_FUNC rsupv_SetAnalyzerRecordTriggerLevel (ViSession instrumentHandle,
                                                       ViReal64 triggerLevel,
                                                       ViInt32 units);
ViStatus _VI_FUNC rsupv_GetAnalyzerRecordTriggerLevel (ViSession instrumentHandle,
                                                       ViPReal64 triggerLevel,
                                                       ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetAnalyzerRecordTriggerSlope (ViSession instrumentHandle,
                                                       ViInt32 triggerSlope);
ViStatus _VI_FUNC rsupv_GetAnalyzerRecordTriggerSlope (ViSession instrumentHandle,
                                                       ViPInt32 triggerSlope);
ViStatus _VI_FUNC rsupv_SetAnalyzerRecordPretrigger (ViSession instrumentHandle,
                                                     ViReal64 recordPretrigger,
                                                     ViInt32 units);
ViStatus _VI_FUNC rsupv_GetAnalyzerRecordPretrigger (ViSession instrumentHandle,
                                                     ViPReal64 recordPretrigger,
                                                     ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetProtocolAnalysisState (ViSession instrumentHandle,
                                                  ViBoolean protocolAnalysisState);
ViStatus _VI_FUNC rsupv_GetProtocolAnalysisState (ViSession instrumentHandle,
                                                  ViPBoolean protocolAnalysisState);
ViStatus _VI_FUNC rsupv_SetProtocolAnalysisDisplayState (ViSession instrumentHandle,
                                                         ViBoolean protocolAnalysisDisplayState);
ViStatus _VI_FUNC rsupv_GetProtocolAnalysisDisplayState (ViSession instrumentHandle,
                                                         ViPBoolean protocolAnalysisDisplayState);
ViStatus _VI_FUNC rsupv_SetProtocolAnalysisDisplayMode (ViSession instrumentHandle,
                                                        ViInt32 displayMode);
ViStatus _VI_FUNC rsupv_GetProtocolAnalysisDisplayMode (ViSession instrumentHandle,
                                                        ViPInt32 displayMode);
ViStatus _VI_FUNC rsupv_SetProtocolAnalysisHighlight (ViSession instrumentHandle,
                                                      ViInt32 highlight);
ViStatus _VI_FUNC rsupv_GetProtocolAnalysisHighlight (ViSession instrumentHandle,
                                                      ViPInt32 highlight);
ViStatus _VI_FUNC rsupv_SetProtocolAnalysisPersistence (ViSession instrumentHandle,
                                                        ViInt32 persistence);
ViStatus _VI_FUNC rsupv_GetProtocolAnalysisPersistence (ViSession instrumentHandle,
                                                        ViPInt32 persistence);
ViStatus _VI_FUNC rsupv_SetProtocolAnalysisViewMode (ViSession instrumentHandle,
                                                     ViInt32 viewMode);
ViStatus _VI_FUNC rsupv_GetProtocolAnalysisViewMode (ViSession instrumentHandle,
                                                     ViPInt32 viewMode);
ViStatus _VI_FUNC rsupv_GetProtocolAnalysisChannelByte (ViSession instrumentHandle,
                                                        ViInt32 channel,
                                                        ViInt32 byteValue,
                                                        ViPInt32 value);
ViStatus _VI_FUNC rsupv_GetProtocolAnalysisError (ViSession instrumentHandle,
                                                  ViPInt32 errorCode,
                                                  ViInt32 arraySize,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC rsupv_SetLipSyncAnalysisActiveColorHigh
             (ViSession instrumentHandle, ViString RGBString);
ViStatus _VI_FUNC rsupv_GetLipSyncAnalysisActiveColorHigh
             (ViSession instrumentHandle, ViInt32 bufferSize,
              ViChar _VI_FAR RGBString[]);
ViStatus _VI_FUNC rsupv_SetLipSyncAnalysisActiveColorLow (ViSession instrumentHandle,
                                                          ViString RGBString);
ViStatus _VI_FUNC rsupv_GetLipSyncAnalysisActiveColorLow (ViSession instrumentHandle,
                                                          ViInt32 bufferSize,
                                                          ViChar _VI_FAR RGBString[]);
ViStatus _VI_FUNC rsupv_SetLipSyncAnalysisActivePatternColor
             (ViSession instrumentHandle, ViString RGBString);
ViStatus _VI_FUNC rsupv_GetLipSyncAnalysisActivePatternColor
             (ViSession instrumentHandle, ViInt32 bufferSize,
              ViChar _VI_FAR RGBString[]);
ViStatus _VI_FUNC rsupv_SetLipSyncAnalysisMutePatternColor
             (ViSession instrumentHandle, ViString RGBString);
ViStatus _VI_FUNC rsupv_GetLipSyncAnalysisMutePatternColor
             (ViSession instrumentHandle, ViInt32 bufferSize,
              ViChar _VI_FAR RGBString[]);
ViStatus _VI_FUNC rsupv_SetLipSyncAnalysisAudioTriggerThreshold
             (ViSession instrumentHandle, ViReal64 low, ViInt32 units);
ViStatus _VI_FUNC rsupv_GetLipSyncAnalysisAudioTriggerThreshold
             (ViSession instrumentHandle, ViPReal64 low, ViPInt32 units);
ViStatus _VI_FUNC rsupv_ConfigureLPorHPFilter (ViSession instrumentHandle,
                                               ViInt32 filterNumber,
                                               ViInt32 filterOrder,
                                               ViReal64 passband,
                                               ViReal64 filterAttenuation);
ViStatus _VI_FUNC rsupv_ConfigureBPorBSFilter (ViSession instrumentHandle,
                                               ViInt32 filterNumber,
                                               ViReal64 passbLow, ViReal64 passbUpp,
                                               ViReal64 attenuation);
ViStatus _VI_FUNC rsupv_ConfigureNotchFilter (ViSession instrumentHandle,
                                              ViInt32 filterNumber,
                                              ViReal64 centerFreq,
                                              ViReal64 filterWidth,
                                              ViReal64 filterAttenuation);
ViStatus _VI_FUNC rsupv_ConfigureOctaveFilter (ViSession instrumentHandle,
                                               ViInt32 filterNumber,
                                               ViReal64 centerFreq,
                                               ViReal64 filterAttenuation);
ViStatus _VI_FUNC rsupv_ConfigureFileDefinedFilter (ViSession instrumentHandle,
                                                    ViInt32 filterNumber,
                                                    ViString fileDefinedFilter,
                                                    ViReal64 filterDelay);
ViStatus _VI_FUNC rsupv_SetFilterType (ViSession instrumentHandle,
                                       ViInt32 filterNumber, ViInt32 filterType);
ViStatus _VI_FUNC rsupv_GetFilterType (ViSession instrumentHandle,
                                       ViInt32 filterNumber, ViPInt32 filterType);
ViStatus _VI_FUNC rsupv_SetFilterAttenuation (ViSession instrumentHandle,
                                              ViInt32 filterNumber,
                                              ViReal64 filterAttenuation);
ViStatus _VI_FUNC rsupv_GetFilterAttenuation (ViSession instrumentHandle,
                                              ViInt32 filterNumber,
                                              ViPReal64 filterAttenuation);
ViStatus _VI_FUNC rsupv_SetFilterOrder (ViSession instrumentHandle,
                                        ViInt32 filterNumber, ViInt32 filterOrder);
ViStatus _VI_FUNC rsupv_GetFilterOrder (ViSession instrumentHandle,
                                        ViInt32 filterNumber, ViPInt32 filterOrder);
ViStatus _VI_FUNC rsupv_SetFilterPassband (ViSession instrumentHandle,
                                           ViInt32 filterNumber, ViReal64 passband);
ViStatus _VI_FUNC rsupv_GetFilterPassband (ViSession instrumentHandle,
                                           ViInt32 filterNumber,
                                           ViPReal64 passband);
ViStatus _VI_FUNC rsupv_GetFilterStopband (ViSession instrumentHandle,
                                           ViInt32 filterNumber,
                                           ViPReal64 stopband);
ViStatus _VI_FUNC rsupv_SetFilterPassbandLow (ViSession instrumentHandle,
                                              ViInt32 filterNumber,
                                              ViReal64 passbandLow);
ViStatus _VI_FUNC rsupv_GetFilterPassbandLow (ViSession instrumentHandle,
                                              ViInt32 filterNumber,
                                              ViPReal64 passbandLow);
ViStatus _VI_FUNC rsupv_SetFilterPassbandUpp (ViSession instrumentHandle,
                                              ViInt32 filterNumber,
                                              ViReal64 passbandUpp);
ViStatus _VI_FUNC rsupv_GetFilterPassbandUpp (ViSession instrumentHandle,
                                              ViInt32 filterNumber,
                                              ViPReal64 passbandUpp);
ViStatus _VI_FUNC rsupv_GetFilterStopbandLow (ViSession instrumentHandle,
                                              ViInt32 filterNumber,
                                              ViPReal64 stopbandLow);
ViStatus _VI_FUNC rsupv_GetFilterStopbandUpp (ViSession instrumentHandle,
                                              ViInt32 filterNumber,
                                              ViPReal64 stopbandUpp);
ViStatus _VI_FUNC rsupv_SetFilterCenterFreq (ViSession instrumentHandle,
                                             ViInt32 filterNumber,
                                             ViReal64 centerFreq);
ViStatus _VI_FUNC rsupv_GetFilterCenterFreq (ViSession instrumentHandle,
                                             ViInt32 filterNumber,
                                             ViPReal64 centerFreq);
ViStatus _VI_FUNC rsupv_SetFilterWidth (ViSession instrumentHandle,
                                        ViInt32 filterNumber, ViReal64 filterWidth);
ViStatus _VI_FUNC rsupv_GetFilterWidth (ViSession instrumentHandle,
                                        ViInt32 filterNumber,
                                        ViPReal64 filterWidth);
ViStatus _VI_FUNC rsupv_SetFilterDelay (ViSession instrumentHandle,
                                        ViInt32 filterNumber, ViReal64 filterDelay);
ViStatus _VI_FUNC rsupv_GetFilterDelay (ViSession instrumentHandle,
                                        ViInt32 filterNumber,
                                        ViPReal64 filterDelay);
ViStatus _VI_FUNC rsupv_SetFilterFileDefined (ViSession instrumentHandle,
                                              ViInt32 filterNumber,
                                              ViString fileDefFilter);
ViStatus _VI_FUNC rsupv_ConfigureAudioMonitoring (ViSession instrumentHandle,
                                                  ViInt32 signalSource,
                                                  ViInt16 monitoringChannel,
                                                  ViBoolean speaker,
                                                  ViInt32 phoneOutput_reserved,
                                                  ViReal64 volume);
ViStatus _VI_FUNC rsupv_SetAuxAudioMonitor (ViSession instrumentHandle,
                                            ViBoolean audioMonitor);
ViStatus _VI_FUNC rsupv_GetAuxAudioMonitor (ViSession instrumentHandle,
                                            ViPBoolean audioMonitor);
ViStatus _VI_FUNC rsupv_SetAuxSpeaker (ViSession instrumentHandle,
                                       ViBoolean speaker);
ViStatus _VI_FUNC rsupv_GetAuxSpeaker (ViSession instrumentHandle,
                                       ViPBoolean speaker);
ViStatus _VI_FUNC rsupv_SetAuxSpeakerMonitor (ViSession instrumentHandle,
                                              ViInt32 monitorNumber,
                                              ViInt32 monitoredChannel);
ViStatus _VI_FUNC rsupv_GetAuxSpeakerMonitor (ViSession instrumentHandle,
                                              ViInt32 monitorNumber,
                                              ViPInt32 monitoredChannel);
ViStatus _VI_FUNC rsupv_SetAuxPhoneState (ViSession instrumentHandle,
                                          ViBoolean phoneState);
ViStatus _VI_FUNC rsupv_GetAuxPhoneState (ViSession instrumentHandle,
                                          ViPBoolean phoneState);
ViStatus _VI_FUNC rsupv_SetAuxPhonePermanentState (ViSession instrumentHandle,
                                                   ViBoolean auxPhonePermanentState);
ViStatus _VI_FUNC rsupv_GetAuxPhonePermanentState (ViSession instrumentHandle,
                                                   ViPBoolean auxPhonePermanentState);
ViStatus _VI_FUNC rsupv_SetAuxPhoneOutput (ViSession instrumentHandle,
                                           ViInt32 phoneOut);
ViStatus _VI_FUNC rsupv_GetAuxPhoneOutput (ViSession instrumentHandle,
                                           ViPInt32 phoneOutput);
ViStatus _VI_FUNC rsupv_SetAuxSignalSource (ViSession instrumentHandle,
                                            ViInt32 signalSource);
ViStatus _VI_FUNC rsupv_GetAuxSignalSource (ViSession instrumentHandle,
                                            ViPInt32 signalSource);
ViStatus _VI_FUNC rsupv_SetAuxMonitoringChannel (ViSession instrumentHandle,
                                                 ViInt32 monitoringChannel);
ViStatus _VI_FUNC rsupv_GetAuxMonitoringChannel (ViSession instrumentHandle,
                                                 ViPInt32 monitoringChannel);
ViStatus _VI_FUNC rsupv_SetAuxVolume (ViSession instrumentHandle, ViReal64 volume);
ViStatus _VI_FUNC rsupv_GetAuxVolume (ViSession instrumentHandle, ViPReal64 volume);
ViStatus _VI_FUNC rsupv_SetAuxAnalogOutput (ViSession instrumentHandle,
                                            ViInt32 analogAuxOutput);
ViStatus _VI_FUNC rsupv_GetAuxAnalogOutput (ViSession instrumentHandle,
                                            ViPInt32 analogAuxOutput);
ViStatus _VI_FUNC rsupv_SetAuxDCVoltage (ViSession instrumentHandle,
                                         ViReal64 DCValue, ViInt32 units);
ViStatus _VI_FUNC rsupv_GetAuxDCVoltage (ViSession instrumentHandle,
                                         ViPReal64 DCValue, ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetAuxTriggerInputEnable (ViSession instrumentHandle,
                                                  ViBoolean triggerInput);
ViStatus _VI_FUNC rsupv_GetAuxTriggerInputEnable (ViSession instrumentHandle,
                                                  ViPBoolean triggerInput);
ViStatus _VI_FUNC rsupv_SetAuxTriggerInputMode (ViSession instrumentHandle,
                                                ViInt32 triggerInputMode);
ViStatus _VI_FUNC rsupv_GetAuxTriggerInputMode (ViSession instrumentHandle,
                                                ViPInt32 triggerInputMode);
ViStatus _VI_FUNC rsupv_SetAuxTriggerInputEdge (ViSession instrumentHandle,
                                                ViInt32 triggerInputEdge);
ViStatus _VI_FUNC rsupv_GetAuxTriggerInputEdge (ViSession instrumentHandle,
                                                ViPInt32 triggerInputEdge);
ViStatus _VI_FUNC rsupv_SetAuxTriggerOutputEnable (ViSession instrumentHandle,
                                                   ViBoolean triggerOutput);
ViStatus _VI_FUNC rsupv_GetAuxTriggerOutputEnable (ViSession instrumentHandle,
                                                   ViPBoolean triggerOutput);
ViStatus _VI_FUNC rsupv_SetAuxTriggerOutputMode (ViSession instrumentHandle,
                                                 ViInt32 triggerOutputMode);
ViStatus _VI_FUNC rsupv_GetAuxTriggerOutputMode (ViSession instrumentHandle,
                                                 ViPInt32 triggerOutputMode);
ViStatus _VI_FUNC rsupv_SetAuxTriggerOutputFrequency (ViSession instrumentHandle,
                                                      ViReal64 triggerOutputFrequency);
ViStatus _VI_FUNC rsupv_GetAuxTriggerOutputFrequency (ViSession instrumentHandle,
                                                      ViPReal64 triggerOutputFrequency);
ViStatus _VI_FUNC rsupv_SetAuxTriggerOutputEdge (ViSession instrumentHandle,
                                                 ViInt32 triggerOutputEdge);
ViStatus _VI_FUNC rsupv_GetAuxTriggerOutputEdge (ViSession instrumentHandle,
                                                 ViPInt32 triggerOutputEdge);
ViStatus _VI_FUNC rsupv_SetSwitcherState (ViSession instrumentHandle,
                                          ViBoolean switcherState);
ViStatus _VI_FUNC rsupv_GetSwitcherState (ViSession instrumentHandle,
                                          ViPBoolean switcherState);
ViStatus _VI_FUNC rsupv_SetSwitcherTracking (ViSession instrumentHandle,
                                             ViInt32 switcherTracking);
ViStatus _VI_FUNC rsupv_GetSwitcherTracking (ViSession instrumentHandle,
                                             ViPInt32 switcherTracking);
ViStatus _VI_FUNC rsupv_SetSwitcherOffset (ViSession instrumentHandle,
                                           ViInt32 switcherOffset,
                                           ViInt32 offsetValue);
ViStatus _VI_FUNC rsupv_GetSwitcherOffset (ViSession instrumentHandle,
                                           ViInt32 switcherOffset,
                                           ViPInt32 offsetValue);
ViStatus _VI_FUNC rsupv_SetSwitcherInput (ViSession instrumentHandle,
                                          ViInt32 switcherInput,
                                          ViInt32 inputChannelNumber);
ViStatus _VI_FUNC rsupv_GetSwitcherInput (ViSession instrumentHandle,
                                          ViInt32 switcherInput,
                                          ViPInt32 inputChannelNumber);
ViStatus _VI_FUNC rsupv_SetSwitcherOutput (ViSession instrumentHandle,
                                           ViInt32 switcherOutput,
                                           ViInt32 outputChannelNumber);
ViStatus _VI_FUNC rsupv_GetSwitcherOutput (ViSession instrumentHandle,
                                           ViInt32 switcherOutput,
                                           ViPInt32 outputChannelNumber);
ViStatus _VI_FUNC rsupv_SetSwitcherConnection (ViSession instrumentHandle,
                                               ViInt32 switcherConnection);
ViStatus _VI_FUNC rsupv_GetSwitcherConnection (ViSession instrumentHandle,
                                               ViPInt32 switcherConnection);
ViStatus _VI_FUNC rsupv_SetSwitcherPort (ViSession instrumentHandle,
                                         ViInt32 comPort);
ViStatus _VI_FUNC rsupv_GetSwitcherPort (ViSession instrumentHandle,
                                         ViPInt32 comPort);
ViStatus _VI_FUNC rsupv_SetProtocolGeneratorCodingMode (ViSession instrumentHandle,
                                                        ViInt32 codingMode);
ViStatus _VI_FUNC rsupv_GetProtocolGeneratorCodingMode (ViSession instrumentHandle,
                                                        ViPInt32 codingMode);
ViStatus _VI_FUNC rsupv_SetProtocolGeneratorCodingFile (ViSession instrumentHandle,
                                                        ViString protocolFile);
ViStatus _VI_FUNC rsupv_SetProtocolGeneratorCRC (ViSession instrumentHandle,
                                                 ViBoolean CRC);
ViStatus _VI_FUNC rsupv_GetProtocolGeneratorCRC (ViSession instrumentHandle,
                                                 ViPBoolean CRC);
ViStatus _VI_FUNC rsupv_SetProtocolGeneratorValidity (ViSession instrumentHandle,
                                                      ViInt32 validity);
ViStatus _VI_FUNC rsupv_GetProtocolGeneratorValidity (ViSession instrumentHandle,
                                                      ViPInt32 validity);
ViStatus _VI_FUNC rsupv_SetProtocolGeneratorAllBitsToZero
             (ViSession instrumentHandle);
ViStatus _VI_FUNC rsupv_SetProtocolGeneratorChannelByte (ViSession instrumentHandle,
                                                         ViInt32 channel,
                                                         ViInt32 byteValue,
                                                         ViInt32 value);
ViStatus _VI_FUNC rsupv_GetProtocolGeneratorChannelByte (ViSession instrumentHandle,
                                                         ViInt32 channel,
                                                         ViInt32 byteValue,
                                                         ViPInt32 value);
ViStatus _VI_FUNC rsupv_SetProtocolGeneratorChannels (ViSession instrumentHandle,
                                                      ViInt32 channels);
ViStatus _VI_FUNC rsupv_GetProtocolGeneratorChannels (ViSession instrumentHandle,
                                                      ViPInt32 channels);
ViStatus _VI_FUNC rsupv_SetDisplayScreen (ViSession instrumentHandle,
                                          ViInt32 screenNumber);
ViStatus _VI_FUNC rsupv_GetDisplayScreen (ViSession instrumentHandle,
                                          ViPInt32 screenNumber);
ViStatus _VI_FUNC rsupv_SetDisplayChannel (ViSession instrumentHandle,
                                           ViInt32 subsystemNumber,
                                           ViInt32 subsystem, ViInt32 trace,
                                           ViInt32 channelNumber);
ViStatus _VI_FUNC rsupv_GetDisplayChannel (ViSession instrumentHandle,
                                           ViInt32 subsystemNumber,
                                           ViInt32 subsystem, ViInt32 trace,
                                           ViPInt32 channelNumber);
ViStatus _VI_FUNC rsupv_SetDisplayShowMinMax (ViSession instrumentHandle,
                                              ViInt32 subsystem,
                                              ViInt32 subsystemNumber,
                                              ViBoolean showMinMax);
ViStatus _VI_FUNC rsupv_GetDisplayShowMinMax (ViSession instrumentHandle,
                                              ViInt32 subsystem,
                                              ViInt32 subsystemNumber,
                                              ViPBoolean showMinMax);
ViStatus _VI_FUNC rsupv_SetDisplayDataListFilter (ViSession instrumentHandle,
                                                  ViInt32 subsystem,
                                                  ViInt32 subsystemNumber,
                                                  ViInt32 dataListFilterType);
ViStatus _VI_FUNC rsupv_GetDisplayDataListFilter (ViSession instrumentHandle,
                                                  ViInt32 subsystem,
                                                  ViInt32 subsystemNumber,
                                                  ViPInt32 dataListFilterType);
ViStatus _VI_FUNC rsupv_SetDisplayScanOffset (ViSession instrumentHandle,
                                              ViInt32 subsystem,
                                              ViInt32 subsystemNumber,
                                              ViInt32 scanOffset);
ViStatus _VI_FUNC rsupv_GetDisplayScanOffset (ViSession instrumentHandle,
                                              ViInt32 subsystem,
                                              ViInt32 subsystemNumber,
                                              ViPInt32 scanOffset);
ViStatus _VI_FUNC rsupv_SetDisplayMaxChannels (ViSession instrumentHandle,
                                               ViInt32 maxChannelsDisplay);
ViStatus _VI_FUNC rsupv_GetDisplayMaxChannels (ViSession instrumentHandle,
                                               ViPInt32 maxChannelsDisplay);
ViStatus _VI_FUNC rsupv_SetDisplaySweepYSource (ViSession instrumentHandle,
                                                ViInt32 subsystemNumber,
                                                ViInt32 trace, ViInt32 ySource);
ViStatus _VI_FUNC rsupv_GetDisplaySweepYSource (ViSession instrumentHandle,
                                                ViInt32 subsystemNumber,
                                                ViInt32 trace, ViPInt32 ySource);
ViStatus _VI_FUNC rsupv_SetDisplaySweepMultichannelYSource
             (ViSession instrumentHandle, ViInt32 subsystemNumber, ViInt32 trace,
              ViInt32 ySource);
ViStatus _VI_FUNC rsupv_GetDisplaySweepMultichannelYSource
             (ViSession instrumentHandle, ViInt32 subsystemNumber, ViInt32 trace,
              ViPInt32 ySource);
ViStatus _VI_FUNC rsupv_SetDisplayFFTGraphYSource (ViSession instrumentHandle,
                                                   ViInt32 subsystemNumber,
                                                   ViInt32 trace, ViInt32 ySource);
ViStatus _VI_FUNC rsupv_GetDisplayFFTGraphYSource (ViSession instrumentHandle,
                                                   ViInt32 subsystemNumber,
                                                   ViInt32 trace, ViPInt32 ySource);
ViStatus _VI_FUNC rsupv_SetDisplayFFTGraphMultichannelYSource
             (ViSession instrumentHandle, ViInt32 subsystemNumber, ViInt32 trace,
              ViInt32 ySource);
ViStatus _VI_FUNC rsupv_GetDisplayFFTGraphMultichannelYSource
             (ViSession instrumentHandle, ViInt32 subsystemNumber, ViInt32 trace,
              ViPInt32 ySource);
ViStatus _VI_FUNC rsupv_SetDisplayWaveformYSource (ViSession instrumentHandle,
                                                   ViInt32 trace, ViInt32 ySource);
ViStatus _VI_FUNC rsupv_GetDisplayWaveformYSource (ViSession instrumentHandle,
                                                   ViInt32 trace, ViPInt32 ySource);
ViStatus _VI_FUNC rsupv_SetDisplayWaveformMultichannelYSource
             (ViSession instrumentHandle, ViInt32 trace, ViInt32 ySource);
ViStatus _VI_FUNC rsupv_GetDisplayWaveformMultichannelYSource
             (ViSession instrumentHandle, ViInt32 trace, ViPInt32 ySource);
ViStatus _VI_FUNC rsupv_SetDisplayBargraphYSource (ViSession instrumentHandle,
                                                   ViInt32 subsystemNumber,
                                                   ViInt32 trace, ViInt32 ySource);
ViStatus _VI_FUNC rsupv_GetDisplayBargraphYSource (ViSession instrumentHandle,
                                                   ViInt32 subsystemNumber,
                                                   ViInt32 trace, ViPInt32 ySource);
ViStatus _VI_FUNC rsupv_SetDisplayBargraphMultichannelYSource
             (ViSession instrumentHandle, ViInt32 subsystemNumber, ViInt32 trace,
              ViInt32 ySource);
ViStatus _VI_FUNC rsupv_GetDisplayBargraphMultichannelYSource
             (ViSession instrumentHandle, ViInt32 subsystemNumber, ViInt32 trace,
              ViPInt32 ySource);
ViStatus _VI_FUNC rsupv_SetDisplayPESQYSource (ViSession instrumentHandle,
                                               ViInt32 subsystemNumber,
                                               ViInt32 trace, ViInt32 ySource);
ViStatus _VI_FUNC rsupv_GetDisplayPESQYSource (ViSession instrumentHandle,
                                               ViInt32 subsystemNumber,
                                               ViInt32 trace, ViPInt32 ySource);
ViStatus _VI_FUNC rsupv_SetDisplayYSourceFile (ViSession instrumentHandle,
                                               ViInt32 subsystem,
                                               ViInt32 subsystemNumber,
                                               ViInt32 trace, ViString ySourceFile);
ViStatus _VI_FUNC rsupv_SetDisplayTraceUpdate (ViSession instrumentHandle,
                                               ViInt32 subsystem,
                                               ViInt32 subsystemNumber,
                                               ViInt32 trace,
                                               ViInt32 traceUpdateType);
ViStatus _VI_FUNC rsupv_GetDisplayTraceUpdate (ViSession instrumentHandle,
                                               ViInt32 subsystem,
                                               ViInt32 subsystemNumber,
                                               ViInt32 trace,
                                               ViPInt32 traceUpdateType);
ViStatus _VI_FUNC rsupv_SetDisplayReference (ViSession instrumentHandle,
                                             ViInt32 subsystem,
                                             ViInt32 subsystemNumber, ViInt32 trace,
                                             ViInt32 reference);
ViStatus _VI_FUNC rsupv_GetDisplayReference (ViSession instrumentHandle,
                                             ViInt32 subsystem,
                                             ViInt32 subsystemNumber, ViInt32 trace,
                                             ViPInt32 reference);
ViStatus _VI_FUNC rsupv_SetDisplayReferenceValue (ViSession instrumentHandle,
                                                  ViInt32 subsystem,
                                                  ViInt32 subsystemNumber,
                                                  ViInt32 trace,
                                                  ViReal64 referenceValue,
                                                  ViInt32 units);
ViStatus _VI_FUNC rsupv_GetDisplayReferenceValue (ViSession instrumentHandle,
                                                  ViInt32 subsystem,
                                                  ViInt32 subsystemNumber,
                                                  ViInt32 trace,
                                                  ViPReal64 referenceValue,
                                                  ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetDisplayReferenceFile (ViSession instrumentHandle,
                                                 ViInt32 subsystem,
                                                 ViInt32 subsystemNumber,
                                                 ViInt32 trace,
                                                 ViString referenceFile);
ViStatus _VI_FUNC rsupv_SetDisplayNormalization (ViSession instrumentHandle,
                                                 ViInt32 subsystem,
                                                 ViInt32 subsystemNumber,
                                                 ViInt32 trace,
                                                 ViInt32 normalization);
ViStatus _VI_FUNC rsupv_GetDisplayNormalization (ViSession instrumentHandle,
                                                 ViInt32 subsystem,
                                                 ViInt32 subsystemNumber,
                                                 ViInt32 trace,
                                                 ViPInt32 normalization);
ViStatus _VI_FUNC rsupv_SetDisplayNormalizeValue (ViSession instrumentHandle,
                                                  ViInt32 subsystem,
                                                  ViInt32 subsystemNumber,
                                                  ViInt32 trace,
                                                  ViReal64 normalizeValue);
ViStatus _VI_FUNC rsupv_GetDisplayNormalizeValue (ViSession instrumentHandle,
                                                  ViInt32 subsystem,
                                                  ViInt32 subsystemNumber,
                                                  ViInt32 trace,
                                                  ViPReal64 normalizeValue);
ViStatus _VI_FUNC rsupv_SetDisplayCopyReferenceSettings (ViSession instrumentHandle,
                                                         ViInt32 subsystem,
                                                         ViInt32 subsystemNumber,
                                                         ViBoolean copyReferenceSettings);
ViStatus _VI_FUNC rsupv_GetDisplayCopyReferenceSettings (ViSession instrumentHandle,
                                                         ViInt32 subsystem,
                                                         ViInt32 subsystemNumber,
                                                         ViPBoolean copyReferenceSettings);
ViStatus _VI_FUNC rsupv_SetDisplayCopyScalingSettings (ViSession instrumentHandle,
                                                       ViInt32 subsystem,
                                                       ViInt32 subsystemNumber,
                                                       ViBoolean copyScalingSettings);
ViStatus _VI_FUNC rsupv_GetDisplayCopyScalingSettings (ViSession instrumentHandle,
                                                       ViInt32 subsystem,
                                                       ViInt32 subsystemNumber,
                                                       ViPBoolean copyScalingSettings);
ViStatus _VI_FUNC rsupv_SetDisplayUnitFunctionTrack (ViSession instrumentHandle,
                                                     ViInt32 subsystem,
                                                     ViInt32 subsystemNumber,
                                                     ViInt32 trace,
                                                     ViBoolean unitFunctionTrack);
ViStatus _VI_FUNC rsupv_GetDisplayUnitFunctionTrack (ViSession instrumentHandle,
                                                     ViInt32 subsystem,
                                                     ViInt32 subsystemNumber,
                                                     ViInt32 trace,
                                                     ViPBoolean unitFunctionTrack);
ViStatus _VI_FUNC rsupv_SetDisplayUnit (ViSession instrumentHandle,
                                        ViInt32 subsystem, ViInt32 subsystemNumber,
                                        ViInt32 trace, ViInt32 units);
ViStatus _VI_FUNC rsupv_GetDisplayUnit (ViSession instrumentHandle,
                                        ViInt32 subsystem, ViInt32 subsystemNumber,
                                        ViInt32 trace, ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetDisplayYAxisSpacing (ViSession instrumentHandle,
                                                ViInt32 subsystem,
                                                ViInt32 subsystemNumber,
                                                ViInt32 trace, ViInt32 spacing);
ViStatus _VI_FUNC rsupv_GetDisplayYAxisSpacing (ViSession instrumentHandle,
                                                ViInt32 subsystem,
                                                ViInt32 subsystemNumber,
                                                ViInt32 trace, ViPInt32 spacing);
ViStatus _VI_FUNC rsupv_SetDisplayYAxisTop (ViSession instrumentHandle,
                                            ViInt32 subsystem,
                                            ViInt32 subsystemNumber, ViInt32 trace,
                                            ViReal64 top, ViInt32 units);
ViStatus _VI_FUNC rsupv_GetDisplayYAxisTop (ViSession instrumentHandle,
                                            ViInt32 subsystem,
                                            ViInt32 subsystemNumber, ViInt32 trace,
                                            ViPReal64 top, ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetDisplayYAxisBottom (ViSession instrumentHandle,
                                               ViInt32 subsystem,
                                               ViInt32 subsystemNumber,
                                               ViInt32 trace, ViReal64 bottom,
                                               ViInt32 units);
ViStatus _VI_FUNC rsupv_GetDisplayYAxisBottom (ViSession instrumentHandle,
                                               ViInt32 subsystem,
                                               ViInt32 subsystemNumber,
                                               ViInt32 trace, ViPReal64 bottom,
                                               ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetDisplayUnitAuto (ViSession instrumentHandle,
                                            ViInt32 subsystem,
                                            ViInt32 subsystemNumber, ViInt32 trace,
                                            ViBoolean unitAuto);
ViStatus _VI_FUNC rsupv_GetDisplayUnitAuto (ViSession instrumentHandle,
                                            ViInt32 subsystem,
                                            ViInt32 subsystemNumber, ViInt32 trace,
                                            ViPBoolean unitAuto);
ViStatus _VI_FUNC rsupv_SetDisplayUnitUserString (ViSession instrumentHandle,
                                                  ViInt32 subsystem,
                                                  ViInt32 subsystemNumber,
                                                  ViInt32 trace,
                                                  ViString unitUserString);
ViStatus _VI_FUNC rsupv_GetDisplayUnitUserString (ViSession instrumentHandle,
                                                  ViInt32 subsystem,
                                                  ViInt32 subsystemNumber,
                                                  ViInt32 trace, ViInt32 bufferSize,
                                                  ViChar _VI_FAR unitUserString[]);
ViStatus _VI_FUNC rsupv_SetDisplayAxisLabelAuto (ViSession instrumentHandle,
                                                 ViInt32 subsystem,
                                                 ViInt32 subsystemNumber,
                                                 ViInt32 trace,
                                                 ViBoolean axisLabelAuto);
ViStatus _VI_FUNC rsupv_GetDisplayAxisLabelAuto (ViSession instrumentHandle,
                                                 ViInt32 subsystem,
                                                 ViInt32 subsystemNumber,
                                                 ViInt32 trace,
                                                 ViPBoolean axisLabelAuto);
ViStatus _VI_FUNC rsupv_SetDisplayAxisLabelUserString (ViSession instrumentHandle,
                                                       ViInt32 subsystem,
                                                       ViInt32 subsystemNumber,
                                                       ViInt32 trace,
                                                       ViString axisLabelUserString);
ViStatus _VI_FUNC rsupv_GetDisplayAxisLabelUserString (ViSession instrumentHandle,
                                                       ViInt32 subsystem,
                                                       ViInt32 subsystemNumber,
                                                       ViInt32 trace,
                                                       ViInt32 bufferSize,
                                                       ViChar _VI_FAR axisLabelUserString[]);
ViStatus _VI_FUNC rsupv_SetDisplayLegendState (ViSession instrumentHandle,
                                               ViInt32 subsystem,
                                               ViInt32 subsystemNumber,
                                               ViInt32 trace, ViBoolean legend);
ViStatus _VI_FUNC rsupv_GetDisplayLegendState (ViSession instrumentHandle,
                                               ViInt32 subsystem,
                                               ViInt32 subsystemNumber,
                                               ViInt32 trace, ViPBoolean legend);
ViStatus _VI_FUNC rsupv_SetDisplayLegend (ViSession instrumentHandle,
                                          ViInt32 subsystem,
                                          ViInt32 subsystemNumber, ViInt32 trace,
                                          ViString legendString);
ViStatus _VI_FUNC rsupv_GetDisplayLegend (ViSession instrumentHandle,
                                          ViInt32 subsystem,
                                          ViInt32 subsystemNumber, ViInt32 trace,
                                          ViInt32 bufferSize,
                                          ViChar _VI_FAR legend[]);
ViStatus _VI_FUNC rsupv_SetDisplayCopyLimitSettings (ViSession instrumentHandle,
                                                     ViInt32 subsystem,
                                                     ViInt32 subsystemNumber,
                                                     ViBoolean copyLimitSettings);
ViStatus _VI_FUNC rsupv_GetDisplayCopyLimitSettings (ViSession instrumentHandle,
                                                     ViInt32 subsystem,
                                                     ViInt32 subsystemNumber,
                                                     ViPBoolean copyLimitSettings);
ViStatus _VI_FUNC rsupv_SetDisplayLimitState (ViSession instrumentHandle,
                                              ViInt32 subsystem,
                                              ViInt32 subsystemNumber,
                                              ViInt32 trace, ViInt32 limitType,
                                              ViBoolean limitState);
ViStatus _VI_FUNC rsupv_GetDisplayLimitState (ViSession instrumentHandle,
                                              ViInt32 subsystem,
                                              ViInt32 subsystemNumber,
                                              ViInt32 trace, ViInt32 limitType,
                                              ViPBoolean limitState);
ViStatus _VI_FUNC rsupv_SetDisplayLimitSource (ViSession instrumentHandle,
                                               ViInt32 subsystem,
                                               ViInt32 subsystemNumber,
                                               ViInt32 trace, ViInt32 limitType,
                                               ViInt32 limitSource);
ViStatus _VI_FUNC rsupv_GetDisplayLimitSource (ViSession instrumentHandle,
                                               ViInt32 subsystem,
                                               ViInt32 subsystemNumber,
                                               ViInt32 trace, ViInt32 limitType,
                                               ViPInt32 limitSource);
ViStatus _VI_FUNC rsupv_SetDisplayLimitSourceValue (ViSession instrumentHandle,
                                                    ViInt32 subsystem,
                                                    ViInt32 subsystemNumber,
                                                    ViInt32 trace,
                                                    ViInt32 limitType,
                                                    ViReal64 limitSourceValue,
                                                    ViInt32 units);
ViStatus _VI_FUNC rsupv_GetDisplayLimitSourceValue (ViSession instrumentHandle,
                                                    ViInt32 subsystem,
                                                    ViInt32 subsystemNumber,
                                                    ViInt32 trace,
                                                    ViInt32 limitType,
                                                    ViPReal64 limitSourceValue,
                                                    ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetDisplayLimitSourceFilename (ViSession instrumentHandle,
                                                       ViInt32 subsystem,
                                                       ViInt32 subsystemNumber,
                                                       ViInt32 trace,
                                                       ViInt32 limitType,
                                                       ViString limitSourceFilename);
ViStatus _VI_FUNC rsupv_GetDisplayLimitSourceFilename (ViSession instrumentHandle,
                                                       ViInt32 subsystem,
                                                       ViInt32 subsystemNumber,
                                                       ViInt32 trace,
                                                       ViInt32 limitType,
                                                       ViInt32 bufferSize,
                                                       ViChar _VI_FAR limitSourceFilename[]);
ViStatus _VI_FUNC rsupv_SetDisplayLimitShift (ViSession instrumentHandle,
                                              ViInt32 subsystem,
                                              ViInt32 subsystemNumber,
                                              ViInt32 trace, ViBoolean limitShift);
ViStatus _VI_FUNC rsupv_GetDisplayLimitShift (ViSession instrumentHandle,
                                              ViInt32 subsystem,
                                              ViInt32 subsystemNumber,
                                              ViInt32 trace, ViPBoolean limitShift);
ViStatus _VI_FUNC rsupv_SetDisplayLimitShiftParallel (ViSession instrumentHandle,
                                                      ViInt32 subsystem,
                                                      ViInt32 subsystemNumber,
                                                      ViInt32 trace,
                                                      ViReal64 limitShiftParallel,
                                                      ViInt32 units);
ViStatus _VI_FUNC rsupv_GetDisplayLimitShiftParallel (ViSession instrumentHandle,
                                                      ViInt32 subsystem,
                                                      ViInt32 subsystemNumber,
                                                      ViInt32 trace,
                                                      ViPReal64 limitShiftParallel,
                                                      ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetDisplayLimitShiftSymmetrical (ViSession instrumentHandle,
                                                         ViInt32 subsystem,
                                                         ViInt32 subsystemNumber,
                                                         ViInt32 trace,
                                                         ViReal64 limitShiftSymmetrical,
                                                         ViInt32 units);
ViStatus _VI_FUNC rsupv_GetDisplayLimitShiftSymmetrical (ViSession instrumentHandle,
                                                         ViInt32 subsystem,
                                                         ViInt32 subsystemNumber,
                                                         ViInt32 trace,
                                                         ViPReal64 limitShiftSymmetrical,
                                                         ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetDisplaySweepGraphXSource (ViSession instrumentHandle,
                                                     ViInt32 sweepGraphNumber,
                                                     ViInt32 xSource);
ViStatus _VI_FUNC rsupv_GetDisplaySweepGraphXSource (ViSession instrumentHandle,
                                                     ViInt32 sweepGraphNumber,
                                                     ViPInt32 xSource);
ViStatus _VI_FUNC rsupv_SetDisplaySweepGraphXAxis (ViSession instrumentHandle,
                                                   ViInt32 sweepGraphNumber,
                                                   ViInt32 xAxis);
ViStatus _VI_FUNC rsupv_GetDisplaySweepGraphXAxis (ViSession instrumentHandle,
                                                   ViInt32 sweepGraphNumber,
                                                   ViPInt32 xAxis);
ViStatus _VI_FUNC rsupv_SetDisplayXAxisReferenceValue (ViSession instrumentHandle,
                                                       ViInt32 subsystem,
                                                       ViInt32 subsystemNumber,
                                                       ViReal64 referenceValue,
                                                       ViInt32 units);
ViStatus _VI_FUNC rsupv_GetDisplayXAxisReferenceValue (ViSession instrumentHandle,
                                                       ViInt32 subsystem,
                                                       ViInt32 subsystemNumber,
                                                       ViPReal64 referenceValue,
                                                       ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetDisplayXAxisScaling (ViSession instrumentHandle,
                                                ViInt32 subsystem,
                                                ViInt32 subsystemNumber,
                                                ViInt32 scaling);
ViStatus _VI_FUNC rsupv_GetDisplayXAxisScaling (ViSession instrumentHandle,
                                                ViInt32 subsystem,
                                                ViInt32 subsystemNumber,
                                                ViPInt32 scaling);
ViStatus _VI_FUNC rsupv_SetDisplayXAxisSpacing (ViSession instrumentHandle,
                                                ViInt32 subsystem,
                                                ViInt32 subsystemNumber,
                                                ViInt32 spacing);
ViStatus _VI_FUNC rsupv_GetDisplayXAxisSpacing (ViSession instrumentHandle,
                                                ViInt32 subsystem,
                                                ViInt32 subsystemNumber,
                                                ViPInt32 spacing);
ViStatus _VI_FUNC rsupv_SetDisplayXAxisLeft (ViSession instrumentHandle,
                                             ViInt32 subsystem,
                                             ViInt32 subsystemNumber, ViReal64 left,
                                             ViInt32 units);
ViStatus _VI_FUNC rsupv_GetDisplayXAxisLeft (ViSession instrumentHandle,
                                             ViInt32 subsystem,
                                             ViInt32 subsystemNumber,
                                             ViPReal64 left, ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetDisplayXAxisRight (ViSession instrumentHandle,
                                              ViInt32 subsystem,
                                              ViInt32 subsystemNumber,
                                              ViReal64 right, ViInt32 units);
ViStatus _VI_FUNC rsupv_GetDisplayXAxisRight (ViSession instrumentHandle,
                                              ViInt32 subsystem,
                                              ViInt32 subsystemNumber,
                                              ViPReal64 right, ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetDisplayCursorState (ViSession instrumentHandle,
                                               ViInt32 subsystem,
                                               ViInt32 subsystemNumber,
                                               ViInt32 cursorType,
                                               ViInt32 cursorState);
ViStatus _VI_FUNC rsupv_GetDisplayCursorState (ViSession instrumentHandle,
                                               ViInt32 subsystem,
                                               ViInt32 subsystemNumber,
                                               ViInt32 cursorType,
                                               ViPInt32 cursorState);
ViStatus _VI_FUNC rsupv_SetDisplayCursorMode (ViSession instrumentHandle,
                                              ViInt32 subsystem,
                                              ViInt32 subsystemNumber,
                                              ViInt32 cursorType,
                                              ViInt32 cursorMode);
ViStatus _VI_FUNC rsupv_GetDisplayCursorMode (ViSession instrumentHandle,
                                              ViInt32 subsystem,
                                              ViInt32 subsystemNumber,
                                              ViInt32 cursorType,
                                              ViPInt32 cursorMode);
ViStatus _VI_FUNC rsupv_GetDisplayCursorAmplitude (ViSession instrumentHandle,
                                                   ViInt32 subsystem,
                                                   ViInt32 subsystemNumber,
                                                   ViInt32 cursorType,
                                                   ViPReal64 cursorAmplitude);
ViStatus _VI_FUNC rsupv_SetDisplayCursorMoveTo (ViSession instrumentHandle,
                                                ViInt32 subsystem,
                                                ViInt32 subsystemNumber,
                                                ViInt32 cursorType,
                                                ViInt32 setCursorTo);
ViStatus _VI_FUNC rsupv_SetDisplayCursorXPosition (ViSession instrumentHandle,
                                                   ViInt32 subsystem,
                                                   ViInt32 subsystemNumber,
                                                   ViInt32 cursorType,
                                                   ViReal64 cursorXPosition,
                                                   ViInt32 units);
ViStatus _VI_FUNC rsupv_GetDisplayCursorXPosition (ViSession instrumentHandle,
                                                   ViInt32 subsystem,
                                                   ViInt32 subsystemNumber,
                                                   ViInt32 cursorType,
                                                   ViPReal64 cursorXPosition,
                                                   ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetDisplayCursorYPosition (ViSession instrumentHandle,
                                                   ViInt32 subsystem,
                                                   ViInt32 subsystemNumber,
                                                   ViInt32 cursorType,
                                                   ViReal64 cursorYPosition,
                                                   ViInt32 units);
ViStatus _VI_FUNC rsupv_GetDisplayCursorYPosition (ViSession instrumentHandle,
                                                   ViInt32 subsystem,
                                                   ViInt32 subsystemNumber,
                                                   ViInt32 cursorType,
                                                   ViPReal64 cursorYPosition,
                                                   ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetDisplayCursorMovement (ViSession instrumentHandle,
                                                  ViInt32 subsystem,
                                                  ViInt32 subsystemNumber,
                                                  ViInt32 cursorType,
                                                  ViInt32 cursorPositionMode);
ViStatus _VI_FUNC rsupv_GetDisplayCursorMovement (ViSession instrumentHandle,
                                                  ViInt32 subsystem,
                                                  ViInt32 subsystemNumber,
                                                  ViInt32 cursorType,
                                                  ViPInt32 cursorPositionMode);
ViStatus _VI_FUNC rsupv_SetDisplayMarkerMode (ViSession instrumentHandle,
                                              ViInt32 subsystem,
                                              ViInt32 subsystemNumber,
                                              ViInt32 trace, ViInt32 markerMode);
ViStatus _VI_FUNC rsupv_GetDisplayMarkerMode (ViSession instrumentHandle,
                                              ViInt32 subsystem,
                                              ViInt32 subsystemNumber,
                                              ViInt32 trace, ViPInt32 markerMode);
ViStatus _VI_FUNC rsupv_SetDisplayMarkerHarmonics (ViSession instrumentHandle,
                                                   ViInt32 subsystem,
                                                   ViInt32 subsystemNumber,
                                                   ViInt32 trace,
                                                   ViBoolean harmonics);
ViStatus _VI_FUNC rsupv_GetDisplayMarkerHarmonics (ViSession instrumentHandle,
                                                   ViInt32 subsystem,
                                                   ViInt32 subsystemNumber,
                                                   ViInt32 trace,
                                                   ViPBoolean harmonics);
ViStatus _VI_FUNC rsupv_SetDisplayMarkerMoveTo (ViSession instrumentHandle,
                                                ViInt32 subsystem,
                                                ViInt32 subsystemNumber,
                                                ViInt32 trace, ViInt32 moveTo);
ViStatus _VI_FUNC rsupv_SetDisplayMarkerXPosition (ViSession instrumentHandle,
                                                   ViInt32 subsystem,
                                                   ViInt32 subsystemNumber,
                                                   ViInt32 trace,
                                                   ViReal64 markerXPosition,
                                                   ViInt32 units);
ViStatus _VI_FUNC rsupv_GetDisplayMarkerXPosition (ViSession instrumentHandle,
                                                   ViInt32 subsystem,
                                                   ViInt32 subsystemNumber,
                                                   ViInt32 trace,
                                                   ViPReal64 markerXPosition,
                                                   ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetDisplayStoreTraceAs (ViSession instrumentHandle,
                                                ViInt32 subsystem,
                                                ViInt32 subsystemNumber,
                                                ViInt32 storeTraceAs);
ViStatus _VI_FUNC rsupv_GetDisplayStoreTraceAs (ViSession instrumentHandle,
                                                ViInt32 subsystem,
                                                ViInt32 subsystemNumber,
                                                ViPInt32 storeTraceAs);
ViStatus _VI_FUNC rsupv_SetDisplayTraceSelect (ViSession instrumentHandle,
                                               ViInt32 subsystem,
                                               ViInt32 subsystemNumber,
                                               ViInt32 trace);
ViStatus _VI_FUNC rsupv_GetDisplayTraceSelect (ViSession instrumentHandle,
                                               ViInt32 subsystem,
                                               ViInt32 subsystemNumber,
                                               ViPInt32 trace);
ViStatus _VI_FUNC rsupv_SetDisplayNormalizationFrequency (ViSession instrumentHandle,
                                                          ViInt32 subsystem,
                                                          ViInt32 subsystemNumber,
                                                          ViReal64 normalizationFrequency,
                                                          ViInt32 units);
ViStatus _VI_FUNC rsupv_GetDisplayNormalizationFrequency (ViSession instrumentHandle,
                                                          ViInt32 subsystem,
                                                          ViInt32 subsystemNumber,
                                                          ViPReal64 normalizationFrequency,
                                                          ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetDisplayModifyEqu (ViSession instrumentHandle,
                                             ViInt32 subsystem,
                                             ViInt32 subsystemNumber,
                                             ViBoolean modifyEqulization);
ViStatus _VI_FUNC rsupv_GetDisplayModifyEqu (ViSession instrumentHandle,
                                             ViInt32 subsystem,
                                             ViInt32 subsystemNumber,
                                             ViPBoolean modifyEqulization);
ViStatus _VI_FUNC rsupv_SetDisplayInvertEqu (ViSession instrumentHandle,
                                             ViInt32 subsystem,
                                             ViInt32 subsystemNumber,
                                             ViBoolean invertEqualization);
ViStatus _VI_FUNC rsupv_GetDisplayInvertEqu (ViSession instrumentHandle,
                                             ViInt32 subsystem,
                                             ViInt32 subsystemNumber,
                                             ViPBoolean invertEqualization);
ViStatus _VI_FUNC rsupv_SetDisplayLimitOffset (ViSession instrumentHandle,
                                               ViInt32 subsystem,
                                               ViInt32 subsystemNumber,
                                               ViBoolean limitOffset);
ViStatus _VI_FUNC rsupv_GetDisplayLimitOffset (ViSession instrumentHandle,
                                               ViInt32 subsystem,
                                               ViInt32 subsystemNumber,
                                               ViPBoolean limitOffset);
ViStatus _VI_FUNC rsupv_SetDisplayLimitOffsetValue (ViSession instrumentHandle,
                                                    ViInt32 subsystem,
                                                    ViInt32 subsystemNumber,
                                                    ViReal64 limitOffsetValue);
ViStatus _VI_FUNC rsupv_GetDisplayLimitOffsetValue (ViSession instrumentHandle,
                                                    ViInt32 subsystem,
                                                    ViInt32 subsystemNumber,
                                                    ViPReal64 limitOffsetValue);
ViStatus _VI_FUNC rsupv_SetDisplayStoreTraceToFile (ViSession instrumentHandle,
                                                    ViInt32 subsystem,
                                                    ViInt32 subsystemNumber,
                                                    ViString storeTraceToFile);
ViStatus _VI_FUNC rsupv_GetDisplayStoreTraceToFile (ViSession instrumentHandle,
                                                    ViInt32 subsystem,
                                                    ViInt32 subsystemNumber,
                                                    ViInt32 bufferSize,
                                                    ViChar _VI_FAR storeTraceToFile[]);
ViStatus _VI_FUNC rsupv_SetMeasurementMode (ViSession instrumentHandle,
                                            ViInt32 measurementMode);
ViStatus _VI_FUNC rsupv_GetMeasurementMode (ViSession instrumentHandle,
                                            ViPInt32 measurementMode);
ViStatus _VI_FUNC rsupv_SetMeasurementTimeout (ViSession instrumentHandle,
                                               ViReal64 measurementTimeout);
ViStatus _VI_FUNC rsupv_GetMeasurementTimeout (ViSession instrumentHandle,
                                               ViPReal64 measurementTimeout);
ViStatus _VI_FUNC rsupv_StartMeasurement (ViSession instrumentHandle);
ViStatus _VI_FUNC rsupv_StartMeasurementWaitOPC (ViSession instrumentHandle,
                                                 ViInt32 timeout);
ViStatus _VI_FUNC rsupv_MeasurementControl (ViSession instrumentHandle,
                                            ViInt32 measurement);
ViStatus _VI_FUNC rsupv_SetAnalyzerUnit (ViSession instrumentHandle,
                                         ViInt32 channel, ViInt32 measurement,
                                         ViInt32 units);
ViStatus _VI_FUNC rsupv_GetAnalyzerUnit (ViSession instrumentHandle,
                                         ViInt32 channel, ViInt32 measurement,
                                         ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetAnalyzerUnitAuto (ViSession instrumentHandle,
                                             ViInt32 channel, ViInt32 measurement,
                                             ViBoolean unitAuto);
ViStatus _VI_FUNC rsupv_GetAnalyzerUnitAuto (ViSession instrumentHandle,
                                             ViInt32 channel, ViInt32 measurement,
                                             ViPBoolean unitAuto);
ViStatus _VI_FUNC rsupv_SetAnalyzerUserUnit (ViSession instrumentHandle,
                                             ViInt32 channel, ViInt32 measurement,
                                             ViString userUnit);
ViStatus _VI_FUNC rsupv_GetAnalyzerUserUnit (ViSession instrumentHandle,
                                             ViInt32 channel, ViInt32 measurement,
                                             ViChar _VI_FAR userUnit[]);
ViStatus _VI_FUNC rsupv_SetAnalyzerReference (ViSession instrumentHandle,
                                              ViInt32 channel, ViInt32 measurement,
                                              ViInt32 reference);
ViStatus _VI_FUNC rsupv_GetAnalyzerReference (ViSession instrumentHandle,
                                              ViInt32 channel, ViInt32 measurement,
                                              ViPInt32 reference);
ViStatus _VI_FUNC rsupv_SetAnalyzerReferenceValue (ViSession instrumentHandle,
                                                   ViInt32 channel,
                                                   ViInt32 measurement,
                                                   ViReal64 referenceValue,
                                                   ViInt32 units);
ViStatus _VI_FUNC rsupv_GetAnalyzerReferenceValue (ViSession instrumentHandle,
                                                   ViInt32 channel,
                                                   ViInt32 measurement,
                                                   ViPReal64 referenceValue,
                                                   ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetAnalyzerFrequencyUnit (ViSession instrumentHandle,
                                                  ViInt32 channel, ViInt32 units);
ViStatus _VI_FUNC rsupv_GetAnalyzerFrequencyUnit (ViSession instrumentHandle,
                                                  ViInt32 channel, ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetAnalyzerPhaseUnit (ViSession instrumentHandle,
                                              ViInt32 units);
ViStatus _VI_FUNC rsupv_GetAnalyzerPhaseUnit (ViSession instrumentHandle,
                                              ViPInt32 units);
ViStatus _VI_FUNC rsupv_SetAnalyzerFrequencyPhaseUnitAuto
             (ViSession instrumentHandle, ViInt32 channel,
              ViBoolean frequencyUnitAuto, ViBoolean phaseUnitAuto);
ViStatus _VI_FUNC rsupv_GetAnalyzerFrequencyPhaseUnitAuto
             (ViSession instrumentHandle, ViInt32 channel,
              ViPBoolean frequencyUnitAuto, ViPBoolean phaseUnitAuto);
ViStatus _VI_FUNC rsupv_SetAnalyzerFrequencyPhaseUserUnit
             (ViSession instrumentHandle, ViInt32 channel,
              ViString frequencyUserUnit, ViString phaseUserUnit);
ViStatus _VI_FUNC rsupv_GetAnalyzerFrequencyPhaseUserUnit
             (ViSession instrumentHandle, ViInt32 channel,
              ViChar _VI_FAR frequencyUserUnit[], ViChar _VI_FAR phaseUserUnit[]);
ViStatus _VI_FUNC rsupv_SetAnalyzerFrequencyPhaseReference
             (ViSession instrumentHandle, ViInt32 refFrequency, ViInt32 refPhase);
ViStatus _VI_FUNC rsupv_GetAnalyzerFrequencyPhaseReference
             (ViSession instrumentHandle, ViPInt32 refFrequency, ViPInt32 refPhase);
ViStatus _VI_FUNC rsupv_SetAnalyzerFrequencyPhaseReferenceValue
             (ViSession instrumentHandle, ViReal64 refFrequencyValue,
              ViInt32 frequencyUnits, ViReal64 refPhaseValue, ViInt32 phaseUnits,
              ViReal64 groupDelayRefValue, ViInt32 groupDelayUnits);
ViStatus _VI_FUNC rsupv_GetAnalyzerFrequencyPhaseReferenceValue
             (ViSession instrumentHandle, ViPReal64 refFrequencyValue,
              ViPInt32 frequencyUnits, ViPReal64 refPhaseValue, ViPInt32 phaseUnits,
              ViPReal64 groupDelayRefValue, ViPInt32 groupDelayUnits);
ViStatus _VI_FUNC rsupv_ReadMeasurementResult (ViSession instrumentHandle,
                                               ViInt32 channel, ViInt32 measurement,
                                               ViPReal64 measurementResult,
                                               ViChar _VI_FAR units[]);
ViStatus _VI_FUNC rsupv_ReadMeasurementResultMinMax (ViSession instrumentHandle,
                                                     ViInt32 channel,
                                                     ViInt32 measurement,
                                                     ViInt32 modifier,
                                                     ViPReal64 measurementResult,
                                                     ViChar _VI_FAR units[]);
ViStatus _VI_FUNC rsupv_ReadTraceDataSets (ViSession instrumentHandle,
                                           ViInt32 subsystem,
                                           ViInt32 subsystemNumber, ViInt32 dataSet,
                                           ViInt32 numberOfResults,
                                           ViReal64 _VI_FAR output[]);
ViStatus _VI_FUNC rsupv_WriteTraceDataSets (ViSession instrumentHandle,
                                            ViInt32 subsystem,
                                            ViInt32 subsystemNumber,
                                            ViInt32 dataSet,
                                            ViInt32 numberOfDataSets,
                                            ViReal64 _VI_FAR dataSets[]);
ViStatus _VI_FUNC rsupv_ReadTraceDataSetCount (ViSession instrumentHandle,
                                               ViInt32 subsystem,
                                               ViInt32 subsystemNumber,
                                               ViInt32 dataSet,
                                               ViPInt32 outputCount);
ViStatus _VI_FUNC rsupv_ReadTraceDataList (ViSession instrumentHandle,
                                           ViInt32 subsystem,
                                           ViInt32 subsystemNumber,
                                           ViInt32 dataList,
                                           ViInt32 numberOfResults,
                                           ViReal64 _VI_FAR output[]);
ViStatus _VI_FUNC rsupv_ReadTraceDataListCount (ViSession instrumentHandle,
                                                ViInt32 subsystem,
                                                ViInt32 subsystemNumber,
                                                ViInt32 dataList,
                                                ViPInt32 outputCount);
ViStatus _VI_FUNC rsupv_ReadAxisData (ViSession instrumentHandle, ViInt32 subsystem,
                                      ViInt32 subsystemNumber, ViInt32 axis,
                                      ViInt32 channel, ViInt32 numberOfResults,
                                      ViReal64 _VI_FAR output[]);
ViStatus _VI_FUNC rsupv_ReadAxisDataCount (ViSession instrumentHandle,
                                           ViInt32 subsystem,
                                           ViInt32 subsystemNumber, ViInt32 axis,
                                           ViInt32 channel, ViPInt32 outputCount);
ViStatus _VI_FUNC rsupv_setTimeOut (ViSession instrumentHandle, ViInt32 timeout);
ViStatus _VI_FUNC rsupv_getTimeOut (ViSession instrumentHandle, ViPInt32 timeout);
ViStatus _VI_FUNC rsupv_SetHardcopySource (ViSession instrumentHandle,
                                           ViInt32 source);
ViStatus _VI_FUNC rsupv_GetHardcopySource (ViSession instrumentHandle,
                                           ViPInt32 source);
ViStatus _VI_FUNC rsupv_SetHardcopyDestination (ViSession instrumentHandle,
                                                ViInt32 destination);
ViStatus _VI_FUNC rsupv_GetHardcopyDestination (ViSession instrumentHandle,
                                                ViPInt32 destination);
ViStatus _VI_FUNC rsupv_SetHardcopyOrientation (ViSession instrumentHandle,
                                                ViInt32 orientation);
ViStatus _VI_FUNC rsupv_GetHardcopyOrientation (ViSession instrumentHandle,
                                                ViPInt32 orientation);
ViStatus _VI_FUNC rsupv_SetHardcopyStoreMode (ViSession instrumentHandle,
                                              ViInt32 storeMode);
ViStatus _VI_FUNC rsupv_GetHardcopyStoreMode (ViSession instrumentHandle,
                                              ViPInt32 storeMode);
ViStatus _VI_FUNC rsupv_SetHardcopyFileName (ViSession instrumentHandle,
                                             ViString fileName);
ViStatus _VI_FUNC rsupv_GetHardcopyFileName (ViSession instrumentHandle,
                                             ViInt32 bufferSize,
                                             ViChar _VI_FAR fileName[]);
ViStatus _VI_FUNC rsupv_SetHardcopyHeaderFooterState (ViSession instrumentHandle,
                                                      ViBoolean headerFooter);
ViStatus _VI_FUNC rsupv_GetHardcopyHeaderFooterState (ViSession instrumentHandle,
                                                      ViPBoolean headerFooter);
ViStatus _VI_FUNC rsupv_SetHardcopyDefineHeader (ViSession instrumentHandle,
                                                 ViString defineHeader);
ViStatus _VI_FUNC rsupv_GetHardcopyDefineHeader (ViSession instrumentHandle,
                                                 ViInt32 bufferSize,
                                                 ViChar _VI_FAR defineHeader[]);
ViStatus _VI_FUNC rsupv_SetHardcopyDefineFooter (ViSession instrumentHandle,
                                                 ViString defineFooter);
ViStatus _VI_FUNC rsupv_GetHardcopyDefineFooter (ViSession instrumentHandle,
                                                 ViInt32 bufferSize,
                                                 ViChar _VI_FAR defineFooter[]);
ViStatus _VI_FUNC rsupv_SetHardcopySize (ViSession instrumentHandle, ViString size);
ViStatus _VI_FUNC rsupv_GetHardcopySize (ViSession instrumentHandle,
                                         ViInt32 bufferSize, ViChar _VI_FAR size[]);
ViStatus _VI_FUNC rsupv_HardcopyImmediate (ViSession instrumentHandle);
ViStatus _VI_FUNC rsupv_SetWindowStyle (ViSession instrumentHandle,
                                        ViInt32 fileSelectorWindowStyle);
ViStatus _VI_FUNC rsupv_GetWindowStyle (ViSession instrumentHandle,
                                        ViPInt32 fileSelectorWindowStyle);
ViStatus _VI_FUNC rsupv_SetMemoryString (ViSession instrumentHandle,
                                         ViInt32 stringNumber, ViString string);
ViStatus _VI_FUNC rsupv_GetMemoryString (ViSession instrumentHandle,
                                         ViInt32 stringNumber, ViInt32 bufferSize,
                                         ViChar _VI_FAR string[]);
ViStatus _VI_FUNC rsupv_StoreMemoryDataNumeric (ViSession instrumentHandle,
                                                ViInt32 stringNumber,
                                                ViInt32 numberOfData,
                                                ViReal64 _VI_FAR data[]);
ViStatus _VI_FUNC rsupv_StoreMemoryDataBinary (ViSession instrumentHandle,
                                               ViInt32 stringNumber,
                                               ViInt32 binaryLength,
                                               ViChar _VI_FAR binaryBlockData[]);
ViStatus _VI_FUNC rsupv_ResetMemoryBuffers (ViSession instrumentHandle,
                                            ViInt32 freeBuffers);
ViStatus _VI_FUNC rsupv_SystemShutdown (ViSession instrumentHandle, ViInt32 time);
ViStatus _VI_FUNC rsupv_LoadSetup (ViSession instrumentHandle, ViString setup);
ViStatus _VI_FUNC rsupv_SaveSetup (ViSession instrumentHandle, ViString setup);
ViStatus _VI_FUNC rsupv_SetGPIBAddress (ViSession instrumentHandle,
                                        ViInt32 GPIBAddress);
ViStatus _VI_FUNC rsupv_errorCheckState (ViSession instrumentHandle,
                                         ViBoolean stateChecking);
ViStatus _VI_FUNC rsupv_optionCheckState(ViSession instrumentHandle,
										ViBoolean state);
ViStatus _VI_FUNC rsupv_readToFile (ViSession instrumentHandle, ViString source,
                                    ViString destination);
ViStatus _VI_FUNC rsupv_writeFromFile (ViSession instrumentHandle, ViString source,
                                       ViString destination);
ViStatus _VI_FUNC rsupv_writeHugeFileStart (ViSession instrumentHandle,
                                            ViString source, ViString destination,
                                             ViUInt64* fileHandle);
ViStatus _VI_FUNC rsupv_contHugeFile (ViSession instrumentHandle,
                                      ViUInt64 fileHandle, ViUInt32 offset,
                                      ViUInt32 blockLength, ViPBoolean endofFile);
ViStatus _VI_FUNC rsupv_writeInstrData (ViSession instrumentHandle,
                                        ViString writeBuffer);
ViStatus _VI_FUNC rsupv_readInstrData (ViSession instrumentHandle,
                                       ViInt32 numberBytesToRead,
                                       ViChar _VI_FAR readBuffer[],
                                       ViPInt32 numBytesRead);
ViStatus _VI_FUNC rsupv_reset (ViSession instrumentHandle);
ViStatus _VI_FUNC rsupv_self_test (ViSession instrumentHandle,
                                   ViPInt16 selfTestResult,
                                   ViChar _VI_FAR selfTestMessage[]);
ViStatus _VI_FUNC rsupv_error_query (ViSession instrumentHandle, ViPInt32 errorCode,
                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC rsupv_error_message (ViSession instrumentHandle,
                                       ViStatus statusCode,
                                       ViChar _VI_FAR message[]);
ViStatus _VI_FUNC rsupv_revision_query (ViSession instrumentHandle,
                                        ViChar _VI_FAR instrumentDriverRevision[],
                                        ViChar _VI_FAR firmwareRevision[]);
ViStatus _VI_FUNC rsupv_setStatusRegister (ViSession instrumentHandle,
                                           ViInt32 registerOperation,
                                           ViInt32 questionableRegister,
                                           ViInt32 enable, ViInt32 PTransition,
                                           ViInt32 NTransition);
ViStatus _VI_FUNC rsupv_getStatusRegister (ViSession instrumentHandle,
                                           ViInt32 statusRegistersQuery,
                                           ViPInt32 registerValue);
ViStatus _VI_FUNC rsupv_close (ViSession instrumentHandle);


#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif

/*****************************************************************************/
/*=== END INCLUDE FILE ======================================================*/
/*****************************************************************************/

#endif
